# coding: utf-8

from django.conf import settings

from tionix_dashboard.clients.base import TNXBaseNovaClient
from tionix_dashboard.clients.helpers import expected_402_404
from tionix_dashboard.dashboards.license import LicenseController


class TNXBackupSystemsClient(TNXBaseNovaClient):
    """Client for backup systems"""

    resource = 'tnx_backup_systems'

    # pylint: disable=arguments-differ
    # noinspection PyMethodOverriding
    @classmethod
    @expected_402_404(
        redirect=settings.WEBROOT, lic_type=LicenseController.MONITOR)
    def get(cls, request, identifier):
        return super(TNXBackupSystemsClient, cls).get(request,
                                                      identifier)

    @classmethod
    @expected_402_404(
        redirect=settings.WEBROOT, lic_type=LicenseController.MONITOR)
    def list(cls, request, **kwargs):
        return super(TNXBackupSystemsClient, cls).list(request, **kwargs)

    @classmethod
    @expected_402_404(
        redirect=settings.WEBROOT, lic_type=LicenseController.MONITOR)
    def create(cls, request, domain_id, **kwargs):
        return cls.get_resource(request).create(domain_id, **kwargs)

    @classmethod
    @expected_402_404(
        redirect=settings.WEBROOT, lic_type=LicenseController.MONITOR)
    def update(cls, request, identifier, **kwargs):
        return cls.get_resource(request).update(identifier, **kwargs)

    @classmethod
    @expected_402_404(
        redirect=settings.WEBROOT, lic_type=LicenseController.MONITOR)
    def delete(cls, request, identifier):
        return cls.get_resource(request).delete(identifier)

    @classmethod
    @expected_402_404(
        redirect=settings.WEBROOT, lic_type=LicenseController.MONITOR)
    def get_system_params(cls, request, domain_id, backup_system):
        return cls.get_resource(request).get_system_params(domain_id,
                                                           backup_system)

    @classmethod
    @expected_402_404(
        redirect=settings.WEBROOT, lic_type=LicenseController.MONITOR)
    def get_director_name(cls, request, domain_id, backup_system):
        return cls.get_resource(request).get_director_name(domain_id,
                                                           backup_system)
