# coding: utf-8
# pylint: disable=no-member

import functools
import logging

from novaclient.exceptions import ClientException

from tionix_dashboard.clients.exceptions import UrlNotAvailableError

logger = logging.getLogger(__name__)


SSH_DEVICE_PROTOCOL_TYPE = 'ssh'


def encode_search_opts(search_opts):
    return {k: v.encode('utf-8') if hasattr(v, 'encode') else v
            for k, v in search_opts.iteritems()}


def expected_402_404(lic_type, redirect=None):
    def decorator(f):
        @functools.wraps(f)
        def wrapped(*args, **kwargs):
            try:
                return f(*args, **kwargs)
            except Exception as exc:
                if isinstance(exc, ClientException):
                    if exc.code == 402 or (exc.code == 404 and
                                           exc.message == 'Not found'):
                        raise UrlNotAvailableError(
                            redirect_to=redirect, lic_type=lic_type)
                elif isinstance(exc, UrlNotAvailableError):
                    exc.redirect_to = redirect
                    exc.lic_type = lic_type
                    raise exc
                raise

        return wrapped

    return decorator
