# coding: utf-8

from django.conf import settings
from django.core.exceptions import ObjectDoesNotExist

from openstack_dashboard.api import base

from tionix_dashboard.clients.base import TNXBaseNovaClient
from tionix_dashboard.clients.helpers import expected_402_404
from tionix_dashboard.dashboards.license import LicenseController


class HostClassType(object):

    def __init__(self, obj_id, name, host_class_id):
        self.id = obj_id
        self.name = name
        self.host_class_id = host_class_id


class TNXHostClassesClient(TNXBaseNovaClient):
    """Client for tnx host classes"""

    resource = 'tnx_host_classes'

    @classmethod
    @expected_402_404(
        redirect=settings.WEBROOT, lic_type=LicenseController.NODE_CONTROL)
    def get(cls, request, identifier):
        host_class = super(TNXHostClassesClient, cls).get(request, identifier)
        return HostCLass(host_class, request)

    @classmethod
    @expected_402_404(
        redirect=settings.WEBROOT, lic_type=LicenseController.NODE_CONTROL)
    def list(cls, request, **kwargs):
        host_class_list = super(TNXHostClassesClient, cls).list(request,
                                                                **kwargs)
        return [HostCLass(host_class, request)
                for host_class in host_class_list]

    @classmethod
    @expected_402_404(
        redirect=settings.WEBROOT, lic_type=LicenseController.NODE_CONTROL)
    def create(cls, request, **kwargs):
        return cls.get_resource(request).create(**kwargs)

    @classmethod
    @expected_402_404(
        redirect=settings.WEBROOT, lic_type=LicenseController.NODE_CONTROL)
    def delete(cls, request, identifier):
        return cls.get_resource(request).delete(identifier)

    @classmethod
    @expected_402_404(
        redirect=settings.WEBROOT, lic_type=LicenseController.NODE_CONTROL)
    def create_host_type(cls, request, identifier, **kwargs):
        return cls.get_resource(request).create_host_type(identifier, **kwargs)

    @classmethod
    @expected_402_404(
        redirect=settings.WEBROOT, lic_type=LicenseController.NODE_CONTROL)
    def update_host_type(cls, request, identifier, host_type_id, **kwargs):
        return cls.get_resource(request).update_host_type(identifier,
                                                          host_type_id,
                                                          **kwargs)

    @classmethod
    @expected_402_404(
        redirect=settings.WEBROOT, lic_type=LicenseController.NODE_CONTROL)
    def delete_host_type(cls, request, identifier, host_type_id):
        return cls.get_resource(request).delete_host_type(identifier,
                                                          host_type_id)


class HostCLass(base.APIResourceWrapper):
    _attrs = [
        'id', 'name', 'host_types', 'is_default'
    ]

    def __init__(self, apiresource, request):
        super(HostCLass, self).__init__(apiresource)
        self.request = request

    def get_host_type(self, host_type_id):
        for obj in self.host_types:
            if str(obj.id) == str(host_type_id):
                host_type = obj
                break
        else:
            raise ObjectDoesNotExist()
        return host_type

    @property
    def host_types(self):
        return [HostClassType(host_type['id'], host_type['name'], self.id)
                for host_type in self._apiresource.host_types]
