# coding: utf-8

from django.core.urlresolvers import reverse_lazy
from django.utils.functional import cached_property

from openstack_dashboard.api import base
from tionix_dashboard.clients.base import TNXBaseNovaClient
from tionix_dashboard.clients.helpers import (
    expected_402_404, SSH_DEVICE_PROTOCOL_TYPE)
from tionix_dashboard.dashboards.admin.hypervisors.helpers import (
    ConnectedDevice)
from tionix_dashboard.dashboards.license import LicenseController
from tionix_dashboard.helpers.enums import ConditionTypes
from tionix_dashboard.url_resolve_map import (
    HYPERVISORS_INDEX, INFRASTRUCTURE_INDEX)


class TNXHypervisorsClient(TNXBaseNovaClient):
    """Client for tnx hypervisors"""

    resource = 'tnx_hypervisors'

    @classmethod
    @expected_402_404(
        redirect=reverse_lazy(HYPERVISORS_INDEX),
        lic_type=LicenseController.NODE_CONTROL)
    def count(cls, request, **kwargs):
        return super(TNXHypervisorsClient, cls).count(request, **kwargs)

    @classmethod
    @expected_402_404(
        redirect=reverse_lazy(HYPERVISORS_INDEX),
        lic_type=LicenseController.NODE_CONTROL)
    def get(cls, request, identifier, project_id=None):
        return TnxHypervisor(super(TNXHypervisorsClient, cls).get(
            request, identifier, project_id=project_id))

    @classmethod
    @expected_402_404(
        redirect=reverse_lazy(HYPERVISORS_INDEX),
        lic_type=LicenseController.NODE_CONTROL)
    def list(cls, request, **kwargs):
        return [
            TnxHypervisor(hypervisor)
            for hypervisor in super(TNXHypervisorsClient, cls).list(request,
                                                                    **kwargs)
        ]

    @classmethod
    @expected_402_404(
        redirect=reverse_lazy(HYPERVISORS_INDEX),
        lic_type=LicenseController.NODE_CONTROL)
    def update(cls, request, identifier, **kwargs):
        return super(TNXHypervisorsClient, cls).update(
            request, identifier, **kwargs)

    @classmethod
    @expected_402_404(
        redirect=reverse_lazy(HYPERVISORS_INDEX),
        lic_type=LicenseController.NODE_CONTROL)
    def search(cls, request, query, servers=True):
        return cls.get_resource(request).search(query, servers)

    @classmethod
    @expected_402_404(
        redirect=reverse_lazy(HYPERVISORS_INDEX),
        lic_type=LicenseController.NODE_CONTROL)
    def set_default_power_device_for_node(
            cls, request, node_id, power_device_id):
        return cls.get_resource(request).set_default_power_device_for_node(
            node_id, power_device_id)

    @classmethod
    @expected_402_404(
        redirect=reverse_lazy(HYPERVISORS_INDEX),
        lic_type=LicenseController.NODE_CONTROL)
    def set_power_device_port_for_node(
            cls, request, node_id, power_device_id, power_device_port):
        return cls.get_resource(request).set_power_device_port_for_node(
            node_id, power_device_id, power_device_port)

    @classmethod
    @expected_402_404(
        redirect=reverse_lazy(HYPERVISORS_INDEX),
        lic_type=LicenseController.NODE_CONTROL)
    def shut_down_hypervisor(
            cls, request, node_id, allow_off_vm=False, allow_evacuate=False):
        return cls.get_client(request).hosts.shutdown(
            node_id, allow_off_vm, allow_evacuate)

    @classmethod
    @expected_402_404(
        redirect=reverse_lazy(HYPERVISORS_INDEX),
        lic_type=LicenseController.NODE_CONTROL)
    def assign_hypervisor_image(cls, request, node_id, image_id):
        return cls.get_resource(request).assign_node_image(node_id, image_id)

    @classmethod
    @expected_402_404(
        redirect=reverse_lazy(HYPERVISORS_INDEX),
        lic_type=LicenseController.NODE_CONTROL)
    def set_reserved_flag_hypervisor(cls, request, node_id, flag):
        return cls.get_resource(request).set_node_reserved_flag(node_id, flag)

    @classmethod
    @expected_402_404(
        redirect=reverse_lazy(HYPERVISORS_INDEX),
        lic_type=LicenseController.NODE_CONTROL)
    def reset_hypervisor(cls, request, identifier):
        return cls.get_resource(request).reset(identifier)

    @classmethod
    @expected_402_404(
        redirect=reverse_lazy(HYPERVISORS_INDEX),
        lic_type=LicenseController.NODE_CONTROL)
    def power_on_hypervisor(cls, request, identifier):
        return cls.get_resource(request).power_on(identifier)

    @classmethod
    @expected_402_404(
        redirect=reverse_lazy(HYPERVISORS_INDEX),
        lic_type=LicenseController.NODE_CONTROL)
    def power_off_hypervisor(cls, request, identifier):
        return cls.get_resource(request).power_off(identifier)

    @classmethod
    @expected_402_404(
        redirect=reverse_lazy(HYPERVISORS_INDEX),
        lic_type=LicenseController.NODE_CONTROL)
    def reset(cls, request, identifier):
        return cls.get_resource(request).reset(identifier)

    @classmethod
    @expected_402_404(
        redirect=reverse_lazy(HYPERVISORS_INDEX),
        lic_type=LicenseController.NODE_CONTROL)
    def reset_all(cls, request, hypervisor_ids):
        return cls.get_resource(request).reset_all(hypervisor_ids)

    @classmethod
    @expected_402_404(
        redirect=reverse_lazy(HYPERVISORS_INDEX),
        lic_type=LicenseController.NODE_CONTROL)
    def get_power_actions(cls, request, identifier):
        return cls.get_resource(request).get_power_actions(identifier)

    @classmethod
    @expected_402_404(
        redirect=reverse_lazy(HYPERVISORS_INDEX),
        lic_type=LicenseController.NODE_CONTROL)
    def assign_power_device(cls, request, identifier, power_device_id,
                            node_port, **kwargs):
        return cls.get_resource(request).assign_power_device(identifier,
                                                             power_device_id,
                                                             node_port,
                                                             **kwargs)

    @classmethod
    @expected_402_404(
        redirect=reverse_lazy(HYPERVISORS_INDEX),
        lic_type=LicenseController.NODE_CONTROL)
    def unassign_power_device(cls, request, identifier, power_device_id):
        return cls.get_resource(request).unassign_power_device(identifier,
                                                               power_device_id)

    @classmethod
    @expected_402_404(
        redirect=reverse_lazy(INFRASTRUCTURE_INDEX),
        lic_type=LicenseController.NODE_CONTROL)
    def create(cls, request, **kwargs):
        return cls.get_resource(request).create(**kwargs)

    @classmethod
    @expected_402_404(
        redirect=reverse_lazy(INFRASTRUCTURE_INDEX),
        lic_type=LicenseController.NODE_CONTROL)
    def delete(cls, request, identifier):
        return cls.get_resource(request).delete(identifier)


class TnxHypervisor(base.APIResourceWrapper):

    _attrs = ['id', 'NAME_ATTR', 'hypervisor_hostname', 'state', 'port',
              'hypervisor_type', 'host_ip', 'current_workload', 'free_disk_gb',
              'disk_available_least', 'hypervisor_version', 'memory_mb',
              'free_ram_mb', 'memory_mb_used', 'vcpus', 'vcpus_used', 'status',
              'running_vms', 'cpu_info', 'service', 'local_gb',
              'local_gb_used', 'tnx_image_name', 'tnx_node_title',
              'tnx_power_state', 'tnx_is_reserved', 'tnx_devices',
              'tnx_dtc_number', 'tnx_row_number', 'tnx_rack_number',
              'tnx_unit_number', 'tnx_inventory_code', 'tnx_ip_addresses',
              'tnx_host_class', 'tnx_description', 'tnx_node_id',
              'tnx_node_name', 'tnx_host_type', 'tnx_created_at', 'tnx_owner',
              'tnx_active', 'tnx_hdd_gb', 'tnx_ram_mb', 'tnx_cpu_amount',
              'tnx_controller_id', 'tnx_condition']

    @cached_property
    def devices(self):
        return ([ConnectedDevice(self.id, *device)
                 for device in self.tnx_devices]
                if self.tnx_devices is not None else [])

    @cached_property
    def is_initialized(self):
        return any(device.is_initialized for device in self.devices)

    @cached_property
    def tnx_condition_label(self):
        return ConditionTypes.values.get(self.tnx_condition)

    @cached_property
    def has_default_ssh_device(self):
        return any(device.protocol_type == SSH_DEVICE_PROTOCOL_TYPE
                   and device.is_default
                   for device in self.devices)
