# coding: utf-8

import logging

from novaclient.exceptions import Unauthorized, NotFound
from requests.exceptions import ConnectionError

from tionix_dashboard.clients.base import TNXBaseNovaClient


logger = logging.getLogger(__name__)


class TNXLicensesClient(TNXBaseNovaClient):
    """Client for tnx licenses"""

    @classmethod
    def get_monitor_license(cls, request):
        result = {}
        try:
            result = cls.get_client(
                request).monitor_licenses.get_monitor_info()
        except (Unauthorized, ConnectionError) as err:
            raise err
        except NotFound:
            pass
        except Exception as e:
            logger.critical(e)

        return result

    @classmethod
    def get_cloud_control_license(cls, request):
        result = {}
        try:
            result = (
                cls.get_client(request).cc_licenses.get_cloud_control_info())
        except (Unauthorized, ConnectionError) as err:
            raise err
        except NotFound:
            pass
        except Exception as e:
            logger.critical(e)

        return result

    @classmethod
    def get_node_control_license(cls, request):
        result = {}
        try:
            result = cls.get_client(
                request).nc_licenses.get_node_control_info()
        except (Unauthorized, ConnectionError) as err:
            raise err
        except NotFound:
            pass
        except Exception as e:
            logger.critical(e)

        return result

    @classmethod
    def get_vdi_server_license(cls, request):
        result = {}
        try:
            result = cls.get_client(
                request).vdi_server_licenses.get_vdi_server_info()
        except (Unauthorized, ConnectionError) as err:
            raise err
        except NotFound:
            pass
        except Exception as e:
            logger.critical(e)

        return result
