# coding: utf-8
from django.conf import settings

from tionix_dashboard.clients.base import TNXBaseClient, novaclient
from tionix_dashboard.clients.helpers import expected_402_404
from tionix_dashboard.dashboards.license import LicenseController


class TNXZabbixClient(TNXBaseClient):
    """Client for zabbix"""

    resource = 'tnx_zabbix'

    # pylint: disable=arguments-differ
    @classmethod
    def get_resource(cls, request, project_id=None):
        return getattr(cls.get_client(request, project_id), cls.resource)

    # pylint: disable=arguments-differ
    @classmethod
    def get_client(cls, request, project_id=None):
        return novaclient(request, project_id=project_id)

    @classmethod
    @expected_402_404(
        redirect=settings.WEBROOT, lic_type=LicenseController.MONITOR)
    def setup_monitoring(cls, request, project_id, zabbix_user_login,
                         zabbix_user_password):
        return cls.get_resource(request).setup_monitoring(project_id,
                                                          zabbix_user_login,
                                                          zabbix_user_password)

    @classmethod
    @expected_402_404(
        redirect=settings.WEBROOT, lic_type=LicenseController.MONITOR)
    def get_templates(cls, request, project_id):
        return cls.get_resource(request).get_templates(project_id)

    @classmethod
    @expected_402_404(
        redirect=settings.WEBROOT, lic_type=LicenseController.MONITOR)
    def create_host(cls, request, instance_id, templates, project_id=None):
        return cls.get_resource(request, project_id).create_host(instance_id,
                                                                 templates)

    @classmethod
    @expected_402_404(
        redirect=settings.WEBROOT, lic_type=LicenseController.MONITOR)
    def delete_host(cls, request, instance_id, project_id=None):
        return cls.get_resource(request, project_id).delete_host(instance_id)

    @classmethod
    @expected_402_404(
        redirect=settings.WEBROOT, lic_type=LicenseController.MONITOR)
    def update_host(cls, request, instance_id, templates, project_id=None):
        return cls.get_resource(request, project_id).update_host(instance_id,
                                                                 templates)

    @classmethod
    @expected_402_404(
        redirect=settings.WEBROOT, lic_type=LicenseController.MONITOR)
    def get_host(cls, request, instance_id):
        return cls.get_resource(request).get_host(instance_id)
