# coding: utf-8

import os

from tionix_client.cmd.configure import process_dir, ConfigureException

from tionix_dashboard import BASE_DIR
from tionix_dashboard.helpers.i18 import ugettext as _


CONF_DIR = os.path.join(BASE_DIR, 'conf')

CONFIG_STRING = """
try:
    from tionix_dashboard.settings import *
except ImportError:
    pass
"""

HORIZON_CONFIG = '/etc/openstack-dashboard/local_settings.py'


def process_config(config_path):

    if os.path.isfile(config_path) and os.access(config_path, os.W_OK):
        try:
            with open(config_path, 'r+') as fh:
                data = fh.read()

                if CONFIG_STRING not in data:
                    fh.write(CONFIG_STRING)
        except EnvironmentError as err:
            raise ConfigureException(_(
                u'Unable to update horizon configuration file: {0}').format(
                    unicode(err)))


def configure(verbose=False):
    try:
        process_dir(CONF_DIR)
        process_config(HORIZON_CONFIG)
    except ConfigureException as err:
        result = os.EX_SOFTWARE, err.message
    except Exception as ex:
        if verbose:
            msg = _(u'Error while configuring module: {0}').format(unicode(ex))
        else:
            msg = _(u'Unknown error. Please contact your administrator.')
        result = os.EX_SOFTWARE, msg
    else:
        result = os.EX_OK, u''

    return result
