# coding: utf-8
import logging


from django.core.urlresolvers import reverse
from django.utils.translation import ugettext_lazy as _

from horizon import tables, exceptions

from openstack_dashboard.dashboards.admin.aggregates.constants import (
    AGGREGATES_INDEX_URL)

from tionix_dashboard.clients.aggregates import TNXAggregatesClient
from tionix_dashboard.clients.exceptions import UrlNotAvailableError


logger = logging.getLogger(__name__)


class TnxAggregateUpdateRow(tables.Row):
    """ Action update aggregate row in grid. """
    ajax = True

    def get_data(self, request, obj_id):
        aggregate = None
        try:
            aggregate = TNXAggregatesClient.get(request, obj_id)
        except UrlNotAvailableError:
            raise
        except Exception as err:
            logger.critical(err)
            exceptions.handle(
                request,
                _('Unable to get host aggregate.'),
                redirect=reverse(AGGREGATES_INDEX_URL))
        return aggregate


class TnxAggregateBalancingUpdateCell(tables.UpdateAction):
    """ Action update host aggregate balancing """

    def update_cell(self, request, datum, obj_id, cell_name, new_cell_value):
        """
        Update cell
        """
        TNXAggregatesClient.set_balancing(request, obj_id, new_cell_value)
