# coding: utf-8

from django.forms import BooleanField
from django.template import defaultfilters as filters
from django.template.loader import render_to_string
from django.utils.translation import ugettext_lazy as _

from horizon import tables
from horizon.tables.base import Cell

from openstack_dashboard.dashboards.admin.aggregates import (
    tables as os_project_tables)

from tionix_dashboard.dashboards.admin.aggregates import actions


class TnxAggregatesCell(Cell):
    def render(self):
        return render_to_string("aggregates/_data_table_cell.html",
                                {"cell": self})


class HostAggregatesTable(os_project_tables.HostAggregatesTable):
    balancing = tables.Column(
        'tnx_allow_balancing',
        verbose_name=_("Balancing"),
        filters=(filters.yesno, filters.capfirst),
        form_field=BooleanField(label=_('Balancing'), required=False,
                                initial=True),
        update_action=actions.TnxAggregateBalancingUpdateCell)

    class Meta(os_project_tables.HostAggregatesTable.Meta):
        columns = ('name', 'availability_zone', 'hosts', 'balancing',
                   'metadata')
        row_class = actions.TnxAggregateUpdateRow
        cell_class = TnxAggregatesCell
