# coding: utf-8
# pylint: disable=no-member

import mock

from django.core.urlresolvers import reverse
from django.utils.http import urlencode

from openstack_dashboard.test.helpers import BaseAdminViewTests
from tionix_dashboard.clients.aggregates import TNXAggregatesClient

from tionix_dashboard.dashboards.admin.aggregates import forms, tables


INDEX_URL = "horizon:admin:aggregates:index"


class TnxAdminAggregatesFormsTest(BaseAdminViewTests):

    def test_update_aggregate_az_valid(self):

        data = {'availability_zone': 'test zone',
                'name': 'test name'}

        form = forms.UpdateAggregateForm(self.request, data=data)

        self.assertTrue(form.is_valid())

    def test_update_aggregate_az_invalid(self):

        data = {'availability_zone': u'тестовая зона',
                'name': 'test name'}

        form = forms.UpdateAggregateForm(self.request, data=data)

        self.assertFalse(form.is_valid())


class TnxAdminAggregatesTablesTest(BaseAdminViewTests):
    def test_tnx_aggregates_columns(self):

        table = tables.HostAggregatesTable(self.request)

        self.assertListEqual(
            sorted(table.columns.keys()),
            sorted(['multi_select', 'name', 'availability_zone', 'hosts',
                    'balancing', 'metadata', 'actions'])
        )


class TnxAdminAggregatesActionsTest(BaseAdminViewTests):
    @mock.patch.object(TNXAggregatesClient, 'get')
    @mock.patch.object(TNXAggregatesClient, 'set_balancing')
    def test_update_balancing(self, set_balancing, get):
        aggregate = self.aggregates.first()

        get.return_value = aggregate

        url = '?'.join([reverse(INDEX_URL),
                        urlencode({'action': 'cell_update',
                                   'table': 'host_aggregates',
                                   'cell_name': 'balancing',
                                   'obj_id': aggregate.id,
                                   'inline_edit_mod': 'false'})])
        self.client.post(url)

        self.assertTrue(set_balancing.called)
