# coding: utf-8

from django.utils.translation import ugettext_lazy as _

from horizon import forms
from horizon.utils.validators import validate_printable_ascii

from openstack_dashboard.dashboards.admin.aggregates import workflows

from tionix_dashboard.helpers.fields import AutoGenNameCharField


class SetAggregateInfoAction(workflows.SetAggregateInfoAction):
    name = AutoGenNameCharField(label=_("Name"), max_length=255)
    availability_zone = forms.CharField(label=_("Availability Zone"),
                                        required=False,
                                        max_length=255,
                                        validators=[validate_printable_ascii])

    class Meta(object):
        name = _("Host Aggregate Information")
        help_text = _("Host aggregates divide an availability zone into "
                      "logical units by grouping together hosts. Create a "
                      "host aggregate then select the hosts contained in it.")
        slug = "set_aggregate_info"


class SetAggregateInfoStep(workflows.SetAggregateInfoStep):
    action_class = SetAggregateInfoAction


class CreateAggregateWorkflow(workflows.CreateAggregateWorkflow):
    default_steps = (SetAggregateInfoStep, workflows.AddHostsToAggregateStep)
