# coding: utf-8
# pylint: disable=method-hidden

"""Hypervisor images actions"""

from django.utils.translation import ugettext_lazy as _, ungettext_lazy

from horizon import tables

from tionix_dashboard.clients.pxe_images import TNXPXEImagesClient
from tionix_dashboard.helpers.actions import TnxBatchActionMixin


class CreateHypervisorImageAction(tables.LinkAction):
    """Create image action"""

    name = 'create'
    verbose_name = _('Create image')
    url = 'horizon:admin:hypervisors:images:create'
    classes = ("ajax-modal", )
    policy_rules = (('identity', 'admin_required'), )


class DeleteHypervisorImageAction(TnxBatchActionMixin, tables.DeleteAction):
    """Delete hypervisor image action"""

    @staticmethod
    def action_present(count):
        return ungettext_lazy(
            u"Delete Image",
            u"Delete Images",
            count
        )

    @staticmethod
    def action_past(count):
        return ungettext_lazy(
            u"Deleted Image",
            u"Deleted Images",
            count
        )

    def delete(self, request, obj_id):
        TNXPXEImagesClient.delete(request, obj_id)


class ExtraHypervisorImageAction(tables.LinkAction):
    """Show hypervisor image details action"""

    name = 'image_extra'
    verbose_name = _('More')
    url = 'horizon:admin:hypervisors:images:extra'
    classes = ("ajax-modal", )
    policy_rules = (('identity', 'admin_required'), )
