# coding: utf-8

"""Hypervisor images forms"""

import logging

from django.utils.translation import ugettext_lazy as _

from horizon import exceptions, forms

from tionix_dashboard.clients.pxe_images import TNXPXEImagesClient
from tionix_dashboard.helpers.fields import AutoGenNameCharField

logger = logging.getLogger(__name__)


class HypervisorImageCreateForm(forms.SelfHandlingForm):
    """Hypervisor image creation form"""

    image_name = AutoGenNameCharField(label=_('Image name'), max_length=35)
    file_data = forms.CharField(
        label=_('Image content'),
        max_length=511,
        widget=forms.Textarea())

    def handle(self, request, data):
        result = True
        try:
            TNXPXEImagesClient.create(request, **data)
        except Exception as err:
            result = False
            logger.error(unicode(err))
            exceptions.handle(request, _('Unable to create hypervisor image.'))

        return result


class HypervisorImageExtraForm(forms.SelfHandlingForm):
    """Hypervisor image show form"""

    file_data = forms.CharField(
        label=_('Image content'),
        max_length=511,
        widget=forms.Textarea(attrs={'disabled': 'disabled'}),
        required=False
    )

    def handle(self, request, data):
        pass
