# coding: utf-8

"""Hypervisor images tabs"""

import logging

from django.utils.translation import ugettext_lazy as _

from horizon import exceptions
from horizon import tabs

from tionix_dashboard.clients.exceptions import UrlNotAvailableError
from tionix_dashboard.clients.pxe_images import TNXPXEImagesClient
from tionix_dashboard.dashboards.admin.hypervisors.images import tables


logger = logging.getLogger(__name__)


class HypervisorImagesTab(tabs.TableTab):
    """Hypervisor images tab"""

    table_classes = (tables.AdminHypervisorImagesTable,)
    name = _("Hypervisor images")
    slug = "images_tab"
    template_name = "horizon/common/_detail_table.html"

    def get_hypervisor_images_data(self):
        """Hypervisor images data"""
        images_list = []
        try:
            images_list = TNXPXEImagesClient.list(self.request)
        except UrlNotAvailableError:
            raise
        except Exception as err:
            logger.error(unicode(err))
            exceptions.handle(self.request,
                              _('Unable to get hypervisor images list.'))
        return images_list
