# coding: utf-8

"""Hypervisor images views"""

import logging

from django.core.urlresolvers import reverse_lazy
from django.utils.translation import ugettext_lazy as _

from horizon import exceptions, forms

from tionix_dashboard.clients.pxe_images import TNXPXEImagesClient
from tionix_dashboard.dashboards.admin.hypervisors.images import (
    forms as images_forms)


logger = logging.getLogger(__name__)


class HypervisorImageCreateView(forms.ModalFormView):
    """Hypervisor image create view"""
    form_class = images_forms.HypervisorImageCreateForm
    form_id = 'create_hypervisor_image_form_id'
    modal_header = _('Create hypervisor image')
    modal_id = 'create_hypervisor_image_modal_id'
    template_name = 'hypervisors/images/create.html'
    submit_label = _('Create image')
    submit_url = reverse_lazy('horizon:admin:hypervisors:images:create')
    success_url = reverse_lazy('horizon:admin:hypervisors:images_tab')
    page_title = _('Create hypervisor image')


class HypervisorImageExtraView(forms.ModalFormView):
    """Hypervisor image create view"""
    form_class = images_forms.HypervisorImageExtraForm
    modal_header = _('Hypervisor image details')
    modal_id = 'show_hypervisor_image_id'
    template_name = 'hypervisors/images/extra.html'
    page_title = _('Hypervisor image details')
    cancel_label = _('Close')

    def get_initial(self):
        initial = {}
        try:
            initial = TNXPXEImagesClient.get(self.request,
                                             self.kwargs['image_id']).to_dict()
        except Exception as err:
            logger.error(unicode(err))
            exceptions.handle(self.request,
                              _('Unable to get hypervisor image.'))

        return initial
