# coding: utf-8

"""Hypervisor images tabs"""

import logging

from django.utils.translation import ugettext_lazy as _

from horizon import exceptions
from horizon import tabs
from tionix_dashboard.clients import TNXHypervisorsClient

from tionix_dashboard.dashboards.admin.hypervisors.resources import tables
from tionix_dashboard.helpers.views import (
    ServerFilterTabMixin, DTVTnxPaginationMixin)

logger = logging.getLogger(__name__)


# noinspection PyAbstractClass
class TnxResourcesTab(ServerFilterTabMixin,
                      DTVTnxPaginationMixin,
                      tabs.TableTab):
    table_classes = (tables.TnxAdminResourcesTable,)
    name = _("Resources")
    slug = "resources"
    template_name = "horizon/common/_detail_table.html"
    preload = False

    def get_resources_data(self):
        resources = []
        offset, limit = self.get_offset_limit()
        try:
            self.table.total_count = TNXHypervisorsClient.count(self.request)
            resources = TNXHypervisorsClient.list(self.request,
                                                  offset=offset,
                                                  limit=limit + 1)
        except Exception as err:
            logger.error(unicode(err))
            exceptions.handle(self.request,
                              _('Unable to retrieve resources list.'))
        else:
            total = len(resources)
            if offset == 0:
                self._prev = False
            if total <= limit:
                self._more = False
            else:
                resources.pop()

            self.table.first_marker, self.table.last_marker = (
                0, self.calc_last_marker(self.table.total_count, limit)
            )

        return resources
