/**
 * Created by user on 08.09.17.
 */
(function () {
  'use strict';

  var push = Array.prototype.push;

  /**
   * @ngdoc controller
   * @name SelectPowerDevicePortController
   * @description
   * The `SelectPowerDevicePortController` controller to manage host
   * aggregate in project.
   */
  angular.module('horizon.admin.hypervisors')
    .controller('SelectPowerDevicePortController',
      SelectPowerDevicePortController);

  SelectPowerDevicePortController.$inject = [
    '$scope',
    '$element',
    '$filter',
    'horizon.framework.widgets.modal.notify-modal.service',
    'horizon.app.core.openstack-service-api.tnx'
  ];

  function SelectPowerDevicePortController(
    $scope, $element, $filter, notifyModalService, tnxAPI
  ) {
    var ctrl = this,
      isLoaded = false,
      available = [],
      allocated = [],
      $form = $element.closest('form'),
      form = $form[0],
      powerDevicePortField = $form.find('#id_power_device_port');

    powerDevicePortField.closest('.form-group').hide();

    $scope.powerDevicePort = powerDevicePortField.val();

    ctrl.model = form.model = {
      available: available,
      allocated: allocated
    };

    ctrl.columns = [
      {attrName: "port", headerName: gettext("Port number")},
      {attrName: "tnx_node_name", headerName: gettext("Connected hypervisor"),
        filter: $filter('noValue')},
      {attrName: "is_default", headerName: gettext("Default"),
        filter: portFilter},
      {attrName: "is_initialized", headerName: gettext("Initialized"),
        filter: portFilter}
    ];

    ctrl.allocate = allocate;
    ctrl.deallocate = function (trCtrl, powerdevicePort) {
      powerdevicePort.in_use = false;
      return trCtrl.deallocate(powerdevicePort)
    };

    $scope.$watch('ctrl.model.allocated', setPowerDevicePort, true);

    $(document).off('power-device-changed')
      .on('power-device-changed', function(event, powerDeviceId) {
        return getPowerDevices(powerDeviceId)
      });

    function getPowerDevices(powerDeviceId) {
      tnxAPI.getPowerDevicePorts(powerDeviceId).then(onGetPowerDevicePorts);
    }

    function onGetPowerDevicePorts(data) {
      var activateTab, allocatedPort;

      ctrl.model.available.length = 0;
      ctrl.model.allocated.length = 0;

      push.apply(available, data.data.available);

      available.map(function (port) {port.in_use = port.tnx_node_name !== ''});

      allocatedPort = findPortToAllocate(data.data.available);

      if (allocatedPort) {
        allocated.push(allocatedPort);
      }

      activateTab = available.length === 1 && !!allocatedPort;

      activatePowerDevicePortTab(!activateTab);

      if (!isLoaded) {
        isLoaded = true;
      }

    }

    function setPowerDevicePort(newVal) {
      powerDevicePortField.val(newVal.length ? newVal[0].id : null);
    }

    function activatePowerDevicePortTab(flag) {
      var $powerDevicePortTab = $(".nav-pills a[data-target='" +
            "#assign_power_device__selectpowerdeviceportaction']");

      flag ? $powerDevicePortTab.show() : $powerDevicePortTab.hide();
    }

    function portFilter(value) {
      return value === null
        ? $filter('noValue')(value)
        : $filter('yesno')(value);
    }

    function findPortToAllocate(available) {
      var port = null;
      if ($scope.powerDevicePort) {
        port = available.filter(function (item) {
          return item.port === $scope.powerDevicePort.toString();
        })[0];
      } else if (available.length === 1 && canAddItem(available[0])) {
        port = available[0];
      }
      return port;
    }

    function allocate(trCtrl, powerControlPort) {
      if (!canAddItem(powerControlPort)) {
        var options = {
          title: gettext('Attention.'),
          body: gettext('Power control port is already used.')
        };
        return notifyModalService.modal(options);
      }
      powerControlPort.in_use = true;
      return trCtrl.allocate(powerControlPort);
    }


    function canAddItem(port) {
      return !port.in_use;
    }

  }
})();
