/**
 * Created by user on 08.09.17.
 */
(function () {
  'use strict';

  var push = Array.prototype.push;

  /**
   * @ngdoc controller
   * @name SelectPowerDeviceController
   * @description
   * The `SelectPowerDeviceController` controller to manage host
   * aggregate in project.
   */
  angular.module('horizon.admin.hypervisors')
    .controller('SelectPowerDeviceController', SelectPowerDeviceController);

  SelectPowerDeviceController.$inject = [
    '$scope',
    '$element',
    'horizon.framework.widgets.modal.notify-modal.service'
  ];

  function SelectPowerDeviceController($scope, $element, notifyModalService) {
    var ctrl = this,
      available = [],
      allocated = [],
      $form = $element.closest('form'),
      form = $form[0],
      powerDeviceField = $form.find('#id_power_device');

    powerDeviceField.closest('.form-group').hide();

    ctrl.model = form.model = {
      available: available,
      allocated: allocated
    };

    ctrl.columns = [
      {attrName: "id", headerName: gettext("ID")},
      {attrName: "title", headerName: gettext("Control title")},
      {attrName: "device_name", headerName: gettext("Control type")},
      {attrName: "protocol_type", headerName: gettext("Protocol type")},
      {attrName: "coils_count", headerName: gettext("Ports")},
      {attrName: "used_coils_count", headerName: gettext("Used ports")}
    ];

    ctrl.allocate = allocate;
    ctrl.deallocate = deallocate;

    getPowerDevices();

    $scope.$watch('ctrl.model.allocated', setPowerDevice, true);

    function getPowerDevices() {

      var powerDeviceVal = powerDeviceField.val();

      powerDeviceField.find('option').each(function(index, option){
        var data = $(option).data();
        if (data.id) {
          available.push(data);
        }
       });

      if (powerDeviceVal) {
        push.apply(allocated, available.filter(function(i) {
          return i.id === parseInt(powerDeviceVal);
        }));
      }
    }

    function setPowerDevice(newVal){
      var newId = null;
      if (newVal.length) {
        var newPowerDevice = newVal[0];
        newId = newPowerDevice.id;
      }

      powerDeviceField.val(newId);
      $(document).trigger('power-device-changed', [newId]);
    }

    function allocate(trCtrl, powerDevice) {
      if (powerDevice.coils_count === powerDevice.used_coils_count) {
        var options = {
          title: gettext('Attention.'),
          body: gettext('Power control does not have available ports.')
        };
        return notifyModalService.modal(options);
      }
      powerDevice.used_coils_count += 1;
      return trCtrl.allocate(powerDevice);
    }

    function deallocate(trCtrl, powerDevice) {
      powerDevice.used_coils_count -= 1;
      return trCtrl.deallocate(powerDevice)
    }
  }
})();
