# coding: utf-8

from django.utils.translation import ungettext_lazy

from openstack_dashboard.dashboards.admin.images.tables import (
    AdminImageFilterAction)
from openstack_dashboard.dashboards.project.images.images.tables import (
    ImagesTable)

from tionix_dashboard.helpers.actions import TnxFilterAction, LinkBatchAction


def get_status_by_name(value):
    """Return found status from display value"""
    if value is not None:
        value = unicode(value).lower()
        for actual_value, translation in ImagesTable.STATUS_DISPLAY_CHOICES:
            if unicode(translation).lower().startswith(value):
                return actual_value


# noinspection PyAbstractClass
class TnxAdminImageFilterAction(TnxFilterAction, AdminImageFilterAction):

    filter_string_modifiers = {
        'status': get_status_by_name,
    }


# noinspection PyAbstractClass
class ImageEditAction(LinkBatchAction):
    name = 'multi_edit'
    multiple_next_view_name = "horizon:admin:images:multi_edit"
    policy_rules = (('identity', 'admin_required'),)

    def action_present(self, count):
        return (
            ungettext_lazy(
                u"Edit Image",
                u"Edit Images",
                count
            )
        )

    def action_past(self, count):
        return (
            ungettext_lazy(
                u"Edited Image",
                u"Edited Images",
                count
            )
        )
