# coding: utf-8

import logging

from django.utils.translation import ugettext_lazy as _

from horizon import forms, messages

from openstack_dashboard import api
from tionix_dashboard.dashboards.project.project_images import (
    forms as tnx_project_forms)
from tionix_dashboard.helpers.constants import SCSI_PROPERTIES

logger = logging.getLogger(__name__)


# noinspection PyAbstractClass
class MultiImageEditForm(forms.SelfHandlingForm):
    description = forms.CharField(
        max_length=255,
        widget=forms.Textarea(attrs={'rows': 4}),
        label=_("Description"),
        required=False)
    is_public = forms.BooleanField(label=_("Public"), required=False)
    protected = forms.BooleanField(label=_("Protected"), required=False)
    direct_scsi = forms.BooleanField(label="Direct SCSI", required=False)

    def handle(self, request, data):
        success_images, failure_images = [], []
        if 'description' in data:
            data['properties'] = {}
            data['properties']['description'] = data.pop('description')
        is_scsi = data.pop('direct_scsi', None)
        for image in self.initial['images']:
            try:
                image = api.glance.image_update(request, image.id, **data)

                if is_scsi:
                    api.glance.image_update_properties(
                        request, image.id, **SCSI_PROPERTIES
                    )
            except Exception as err:
                logger.error(err)
                failure_images.append(image.name)
            else:
                success_images.append(image.name)

        if failure_images:
            msg = _('Failed to update images: "{0}"')
            messages.error(request, msg.format(u'", "'.join(failure_images)))

        if success_images:
            msg = _('Successfully updated images: "{0}"')
            messages.success(request, msg.format(u'", "'.join(success_images)))

        return True


# noinspection PyClassHasNoInit
class AdminCreateImageForm(tnx_project_forms.CreateImageForm):
    pass


# noinspection PyClassHasNoInit
class AdminUpdateImageForm(tnx_project_forms.UpdateImageForm):
    pass
