# coding: utf-8
import logging

from django.utils.translation import ugettext_lazy as _

from horizon import exceptions

from openstack_dashboard.api.keystone import tenant_list, is_cloud_admin

from tionix_dashboard.clients import TNXServersClient
from tionix_dashboard.clients.base import cinderclient
from tionix_dashboard.dashboards.utils import update_instances_list


logger = logging.getLogger(__name__)


def get_instances_for_admin(request, sort_dir='desc', search_opts=None):
    search_opts = search_opts or {}

    instances = []
    # Gather our tenants to correlate against IDs
    try:
        tenants, _has_more_data = tenant_list(request)
    except Exception as err:
        logger.error(unicode(err))
        tenants = []
        msg = _('Unable to retrieve instance project information.')
        exceptions.handle(request, msg)

    current_domain = not is_cloud_admin(request)
    try:
        instances, _more, _prev, _total_count = (
            TNXServersClient.get_paginator(
                request,
                search_opts=search_opts,
                all_tenants=True,
                sort_dir=sort_dir)
        )
    except Exception as err:
        logger.error(unicode(err))
        exceptions.handle(request,
                          _('Unable to retrieve instance list.'))

    instances = update_instances_list(request, instances, tenants=tenants,
                                      filter_by_current_domain=current_domain)

    return instances


def get_admin_volumes(request):
    volumes = []
    try:
        volumes = cinderclient(request).volumes.list(
            search_opts={'all_tenants': True}
        )
    except Exception as err:
        logger.error(unicode(err))
    return volumes
