# coding: utf-8

import logging

from django.http.response import JsonResponse

from keystoneclient import exceptions as keystone_exceptions

from novaclient import exceptions as nova_exceptions

from openstack_dashboard.api.rest import (
    urls as rest_urls, nova)

from tionix_client.os_clients.nova_client import get_nova_client


logger = logging.getLogger(__name__)


@rest_urls.register
class TnxRepairAction(nova.Server):
    """Extended server api.
    """
    url_regex = r'tnx/server/repair$'

    # pylint: disable=arguments-differ
    def get(self, request):

        server_id = request.GET.get('server_id')

        success = True
        message = None
        status = 202

        params = {
            'token': request.GET.get('token'),
            'username': request.GET.get('username'),
            'password': request.GET.get('password'),
            'tenant': request.GET.get('tenant'),
            'tenant_id': request.GET.get('tenant_id'),
            'project_domain_name': request.GET.get('project_domain_name'),
            'user_domain_name': request.GET.get('user_domain_name'),
        }

        try:
            nova_client = get_nova_client(**params)
        except (nova_exceptions.Unauthorized,
                keystone_exceptions.Unauthorized, AttributeError) as err:
            success = False
            message = unicode(err.message)
            status = 401
            logger.error(unicode(err))
        else:
            try:
                nova_client.tnx_servers.repair(server_id)
            except nova_exceptions.NotFound:
                message = u'Instance with id "{0}" not found.'.format(
                    server_id)
                success = False
                status = 404
            except Exception as err:
                success = False
                status = 500
                message = unicode(err.message)
                logger.error(unicode(err))

        data = {
            'success': success,
            'message': message,
        }
        return JsonResponse(data=data, status=status)
