# coding: utf-8
from mock import mock

from tionix_dashboard.clients.base import novaclient
from tionix_dashboard.clients.servers import TnxServer
from tionix_dashboard.dashboards.tionix.scheduler.actions import (
    InstanceSchedulerAction)
from tionix_dashboard.dashboards.tionix.scheduler.helpers import (
    SchedulingPreChecker
)
from tionix_dashboard.helpers.vm_constants import ERROR
from tionix_dashboard.tests.helpers import BaseClientTestCase
from tionix_tests.nova_client.extensions.servers import (
    TnxServer as TestTnxServer)


nova_client = novaclient(None)


class AdminInstancesTestCase(BaseClientTestCase):

    _objects_map = None

    def setUp(self):
        super(AdminInstancesTestCase, self).setUp()
        self._objects_map = SchedulingPreChecker.schedulable_servers_map
        self._objects_map[TestTnxServer] = self._objects_map[TnxServer]

    def tearDown(self):
        super(AdminInstancesTestCase, self).tearDown()
        self._objects_map.pop(TestTnxServer, None)

    @mock.patch.object(SchedulingPreChecker, 'is_actions_not_empty',
                       mock.Mock(return_value=True))
    def test_schedule_action(self):

        servers = nova_client.tnx_servers.list()

        schedule_action = InstanceSchedulerAction()

        for server in servers:
            if server.status.lower() == ERROR:
                self.assertFalse(
                    schedule_action.allowed(request=None, datum=server))
            else:
                self.assertTrue(
                    schedule_action.allowed(request=None, datum=server))

    @mock.patch.object(SchedulingPreChecker, 'is_actions_not_empty',
                       mock.Mock(return_value=True))
    def test_schedule_action_allowed(self):
        server = self.tnx_servers.list()[0]
        schedule_action = InstanceSchedulerAction()

        self.assertTrue(
            schedule_action.allowed(request=self.request, datum=server))
