# coding: utf-8

from django.core.urlresolvers import reverse
from django.utils.translation import ugettext_lazy as _

from openstack_dashboard.dashboards.admin.networks import (
    views as networks_views)
from openstack_dashboard.dashboards.admin.networks.ports import (
    views as ports_views)
from openstack_dashboard.dashboards.admin.networks.subnets import (
    views as subnets_views)

from tionix_dashboard.dashboards.admin.networks import forms, workflows, tabs
from tionix_dashboard.dashboards.admin.networks.forms import CreateNetwork
from tionix_dashboard.dashboards.project.project_networks.forms import (
    UpdateNetwork)


# noinspection PyClassHasNoInit
class CreateView(networks_views.CreateView):
    form_class = CreateNetwork


# noinspection PyClassHasNoInit
class UpdateView(networks_views.UpdateView):
    form_class = UpdateNetwork


# noinspection PyClassHasNoInit
class SubnetCreateView(subnets_views.CreateView):
    workflow_class = workflows.CreateSubnet


# noinspection PyClassHasNoInit
class PortCreateView(ports_views.CreateView):
    form_class = forms.CreatePort


# noinspection PyClassHasNoInit
class SubnetUpdateView(subnets_views.UpdateView):
    workflow_class = workflows.UpdateSubnet


# noinspection PyClassHasNoInit
class PortUpdateView(ports_views.UpdateView):
    form_class = forms.UpdatePort


class SubnetDetailView(subnets_views.DetailView):
    tab_group_class = tabs.SubnetDetailTabs

    def get_context_data(self, **kwargs):
        context = super(SubnetDetailView, self).get_context_data(**kwargs)
        subnet = context["subnet"]
        network_nav = subnet.network_name or subnet.network_id
        context["custom_breadcrumb"] = [
            (_("Networks"), self.get_redirect_url()),
            (network_nav, reverse('horizon:admin:networks:detail',
                                  args=(subnet.network_id,))),
            (_("Subnets"),)]

        return context
