# coding: utf-8

from django.template.defaultfilters import floatformat  # noqa
from django.utils.translation import ugettext_lazy as _

from horizon import tables

from openstack_dashboard.usage import tables as openstack_tables


class GlobalUsageTable(openstack_tables.GlobalUsageTable):
    project = tables.Column('project_name', verbose_name=_("Project Name"))
    vcpu_hours = tables.Column('vcpu_hours', verbose_name=_("VCPU Hours"),
                               help_text=_("Total VCPU usage (Number of "
                                           "VCPU in instance * Hours Used) "
                                           "for the project"),
                               filters=(lambda v: floatformat(v, 2),))
    disk_hours = tables.Column('disk_gb_hours',
                               verbose_name=_("Disk GB Hours"),
                               help_text=_("Total disk usage (GB * "
                                           "Hours Used) for the project"),
                               filters=(lambda v: floatformat(v, 2),))
    memory_hours = tables.Column('memory_mb_hours',
                                 verbose_name=_("Memory MB Hours"),
                                 help_text=_("Total memory usage (MB * "
                                             "Hours Used) for the project"),
                                 filters=(lambda v: floatformat(v, 2),))

    class Meta(object):
        name = "global_usage"
        hidden_title = False
        verbose_name = _("Usage")
        columns = ("project", "vcpus", "disk", "memory",
                   "vcpu_hours", "disk_hours", "memory_hours")
        table_actions = (openstack_tables.CSVSummary,)
        multi_select = False
