# coding: utf-8

from django.core import urlresolvers
from django.utils.translation import ugettext_lazy as _

from horizon import tables

from openstack_dashboard.dashboards.admin.volumes.snapshots import (
    tables as snapshots_tables)
from openstack_dashboard.dashboards.project.volumes.snapshots import (
    tables as project_snapshots_tables)

from tionix_dashboard.dashboards.admin.volumes.snapshots import actions
from tionix_dashboard.helpers.actions import TnxBatchActionMixin
from tionix_dashboard.helpers.tables import TnxLocalPaginationTabDataTable
from tionix_dashboard.url_resolve_map import IDENTITY_PROJECT_DETAIL


def get_snap_vol_url_for_project(datum):
    obj_id = getattr(datum, "os-extended-snapshot-attributes:project_id")
    return urlresolvers.reverse(IDENTITY_PROJECT_DETAIL, args=(obj_id,))


class DeleteVolumeSnapshot(TnxBatchActionMixin,
                           project_snapshots_tables.DeleteVolumeSnapshot):
    pass


class TnxVolumeSnapshotsTable(TnxLocalPaginationTabDataTable,
                              snapshots_tables.VolumeSnapshotsTable):
    tenant = tables.Column("tenant_name",
                           link=get_snap_vol_url_for_project,
                           verbose_name=_("Project"))
    host = tables.Column("host_name", verbose_name=_("Storage host"))

    class Meta(snapshots_tables.VolumeSnapshotsTable.Meta):
        table_actions = (actions.VolumeSnapshotsFilterAction,
                         DeleteVolumeSnapshot,)
