# coding: utf-8
import logging

from collections import OrderedDict

from django.utils.translation import ugettext_lazy as _

from horizon import exceptions

from openstack_dashboard.api import cinder, keystone
from openstack_dashboard.dashboards.admin.volumes.tabs import (
    VolumeTypesTab, VolumesGroupTabs)

from tionix_dashboard.dashboards.admin.volumes.snapshots.tables import (
    TnxVolumeSnapshotsTable)
from tionix_dashboard.dashboards.admin.volumes.volumes.tables import (
    TnxVolumesTable)
from tionix_dashboard.dashboards.project.project_volumes import (
    tabs as tnx_volumes_tabs)


logger = logging.getLogger(__name__)


class TnxVolumeTab(tnx_volumes_tabs.TnxVolumeTab):
    table_classes = (TnxVolumesTable,)

    def get_volumes_data(self):
        search_opts = {'all_tenants': True}
        volumes = self._get_volumes(search_opts=search_opts)
        attached_instance_ids = self._get_attached_instance_ids(volumes)
        instances = self._get_instances(search_opts=search_opts,
                                        instance_ids=attached_instance_ids)
        volume_ids_with_snapshots = self._get_volumes_ids_with_snapshots(
            search_opts=search_opts)
        self._set_volume_attributes(
            volumes, instances, volume_ids_with_snapshots)

        # Gather our tenants to correlate against IDs
        try:
            tenants, has_more = keystone.tenant_list(self.request)
        except Exception as err:
            logger.error(unicode(err))
            tenants = []
            msg = _('Unable to retrieve volume project information.')
            exceptions.handle(self.request, msg)

        tenant_dict = OrderedDict([(t.id, t) for t in tenants])
        for volume in volumes:
            tenant_id = getattr(volume, "os-vol-tenant-attr:tenant_id", None)
            tenant = tenant_dict.get(tenant_id, None)
            volume.tenant_name = getattr(tenant, "name", None)

        return volumes


class TnxVolumeSnapshotTab(tnx_volumes_tabs.SnapshotTab):
    table_classes = (TnxVolumeSnapshotsTable,)

    def get_volume_snapshots_data(self):
        snapshots = []
        if cinder.is_volume_service_enabled(self.request):
            search_opts = {'all_tenants': True}
            snapshots = self._get_snapshots(search_opts)
            if snapshots:
                try:
                    volumes = cinder.volume_list(self.request,
                                                 search_opts=search_opts)
                    volumes = dict((v.id, v) for v in volumes)
                except Exception as err:
                    logger.error(unicode(err))
                    volumes = {}
                    exceptions.handle(self.request, _("Unable to retrieve "
                                                      "snapshot volumes."))

                # Gather our tenants to correlate against volume IDs
                try:
                    tenants, has_more = keystone.tenant_list(self.request)
                except Exception as err:
                    logger.error(unicode(err))
                    tenants = []
                    msg = _('Unable to retrieve volume project information.')
                    exceptions.handle(self.request, msg)

                tenant_dict = {t.id: t for t in tenants}
                for snapshot in snapshots:
                    volume = volumes.get(snapshot.volume_id)
                    tenant_id = getattr(volume,
                                        'os-vol-tenant-attr:tenant_id', None)
                    tenant = tenant_dict.get(tenant_id, None)
                    snapshot._volume = volume
                    snapshot.tenant_name = getattr(tenant, "name", None)
                    snapshot.host_name = getattr(
                        volume, 'os-vol-host-attr:host', None)

        return snapshots


class TnxVolumesGroupTabs(VolumesGroupTabs):
    tabs = (TnxVolumeTab,
            VolumeTypesTab,
            TnxVolumeSnapshotTab,
            tnx_volumes_tabs.BackupsTab)
