# coding: utf-8

from django.core import urlresolvers
from django.utils.translation import ugettext_lazy as _

from horizon import tables

from openstack_dashboard.dashboards.admin.volumes.volumes import (
    tables as admin_tables)
from openstack_dashboard.dashboards.project.volumes.volumes import (
    tables as project_tables)

from tionix_dashboard.dashboards.admin.volumes.volumes.actions import (
    TnxCreateBackup, VolumeFilterAction)
from tionix_dashboard.dashboards.project.project_volumes.volumes import (
    actions, tables as tnx_project_tables)
from tionix_dashboard.dashboards.tionix.scheduler.actions import (
    VolumeSchedulerAction)
from tionix_dashboard.url_resolve_map import IDENTITY_PROJECT_DETAIL


def get_vol_url_for_project(datum):
    obj_id = getattr(datum, "os-vol-tenant-attr:tenant_id")
    return urlresolvers.reverse(IDENTITY_PROJECT_DETAIL, args=(obj_id,))


class TnxVolumesTable(tnx_project_tables.TnxVolumesTableBase):
    name = tables.Column("name",
                         verbose_name=_("Name"),
                         link="horizon:admin:volumes:volumes:detail")
    host = tables.Column("os-vol-host-attr:host",
                         verbose_name=_("Storage Host"))
    tenant = tables.Column("tenant_name",
                           link=get_vol_url_for_project,
                           verbose_name=_("Project"))

    class Meta(object):
        name = "volumes"
        verbose_name = _("Volumes")
        status_columns = ["status"]
        row_class = project_tables.UpdateRow
        table_actions = (admin_tables.ManageVolumeAction,
                         VolumeFilterAction)
        row_actions = (actions.TnxDeleteVolume,
                       admin_tables.UpdateVolumeStatusAction,
                       admin_tables.UnmanageVolumeAction,
                       admin_tables.MigrateVolume,
                       TnxCreateBackup,
                       VolumeSchedulerAction)
        table_actions_menu = (actions.TnxDeleteVolume,
                              TnxCreateBackup,
                              VolumeSchedulerAction)
        columns = ('tenant', 'host', 'name', 'size', 'status', 'volume_type',
                   'attachments', 'bootable', 'encryption',)
