# coding: utf-8
# pylint: disable=no-member

import mock

from django.core.urlresolvers import reverse

from horizon import exceptions

from openstack_dashboard import api
from openstack_dashboard.api import cinder
from openstack_dashboard.test.helpers import BaseAdminViewTests
from openstack_dashboard.usage import quotas

from tionix_dashboard.dashboards.admin.volumes.volumes import tables
from tionix_dashboard.dashboards.tionix.scheduler.helpers import (
    SchedulingPreChecker)

CREATE_SNAPSHOT_URL = 'horizon:admin:volumes:volumes:create_snapshot'


class TnxAdminVolumesTablesTest(BaseAdminViewTests):

    def test_tnx_admin_volumes_table_columns(self):

        table = tables.TnxVolumesTable(self.request)

        self.assertListEqual(
            sorted(table.columns.keys()),
            sorted(
                ['tenant', 'host', 'name', 'size', 'status', 'volume_type',
                 'attachments', 'bootable', 'encryption', 'multi_select',
                 'actions']
            )
        )

    @mock.patch.object(api.nova,
                       'extension_supported',
                       mock.Mock(return_value=None))
    @mock.patch.object(exceptions, 'handle', mock.Mock(return_value=None))
    @mock.patch.object(cinder, 'tenant_absolute_limits')
    @mock.patch.object(SchedulingPreChecker, 'is_actions_not_empty',
                       mock.Mock(return_value=True))
    def test_tnx_admin_volumes_table_actions(self, tenant_absolute_limits):
        volumes = self.volumes.list()

        tenant_absolute_limits.return_value = self.limits['absolute']

        table = tables.TnxVolumesTable(self.request, data=volumes)

        self.assertListEqual(
            [action.name for action in table.get_table_actions()],
            ['manage', 'filter', 'delete', 'backup', 'volume_schedule']
        )

    @mock.patch.object(SchedulingPreChecker, 'is_actions_not_empty',
                       mock.Mock(return_value=True))
    def test_tnx_admin_volumes_table_row_actions(self):
        table = tables.TnxVolumesTable(self.request)

        volume = self.volumes.first()
        self.assertListEqual(
            [action.name for action in table.get_row_actions(volume)],
            ['delete', 'update_status', 'unmanage', 'migrate', 'backup',
             'volume_schedule']
        )

    @mock.patch.object(quotas, 'tenant_limit_usages')
    @mock.patch.object(cinder, 'volume_get')
    def test_tnx_create_snapshot_view(self, volume_get, tenant_limit_usages):
        volume = self.volumes.first()

        usage_limit = {
            'maxTotalVolumeGigabytes': 250,
            'gigabytesUsed': 20,
            'snapshotsUsed': len(self.cinder_volume_snapshots.list()),
            'maxTotalSnapshots': 6
        }
        tenant_limit_usages.return_value = usage_limit
        volume_get.return_value = volume

        url = reverse(CREATE_SNAPSHOT_URL)

        res = self.client.get(url)

        self.assertEqual(
            res.context_data['view'].get_success_url(),
            u'/admin/volumes/?tab=volumes_group_tabs__snapshots_tab'
        )
