# coding: utf-8

import logging

from keystoneclient.exceptions import NotFound

from horizon.utils import memoized
from tionix_dashboard.clients.backup_systems import TNXBackupSystemsClient

from tionix_dashboard.clients.domain_config import TNXDomainConfigClient


logger = logging.getLogger()


@memoized.memoized
def get_domain_configuration(request, domain_id):
    """Return domain configuration or None"""
    config = None
    try:
        config = TNXDomainConfigClient.get(request, domain_id)
    except NotFound:
        pass
    except Exception as err:
        logger.error(unicode(err))
    return config


@memoized.memoized
def get_backup_system_by_domain(request, domain_id):
    """Return domain backup setup info or None"""
    backup_system = None
    try:
        backup_systems = TNXBackupSystemsClient.list(request,
                                                     domain_id=domain_id)
    except Exception as err:
        logger.error(unicode(err))
    else:
        if backup_systems:
            backup_system = backup_systems[0]
    return backup_system
