# coding: utf-8

"""Tionix domains table"""

import logging

from django.forms.fields import BooleanField
from django.template import defaultfilters as filters
from django.utils.translation import pgettext_lazy, ugettext_lazy as _

from horizon import tables, messages
from keystoneclient import exceptions

from openstack_dashboard import api
from openstack_dashboard.dashboards.identity.domains import (
    tables as domains_tables)
from tionix_dashboard.dashboards.identity.domains import actions
from tionix_dashboard.helpers.actions import TnxBatchActionMixin

logger = logging.getLogger(__name__)


# noinspection PyAbstractClass
class EnableDomainsAction(TnxBatchActionMixin,
                          domains_tables.EnableDomainsAction):
    pass


# noinspection PyAbstractClass
class DisableDomainsAction(TnxBatchActionMixin,
                           domains_tables.DisableDomainsAction):
    pass


class DeleteDomainsAction(TnxBatchActionMixin,
                          domains_tables.DeleteDomainsAction):
    def action(self, request, obj_id):
        domain = self.table.get_object_by_id(obj_id)
        if domain.enabled:
            msg = _(
                'Domain "{0}" must be disabled before it can be deleted.'
                ''.format(domain.name)
            )
            messages.error(request, msg)
            raise exceptions.Conflict(message=msg)
        else:
            logger.info(u'Deleting domain "{0}".'.format(obj_id))
            api.keystone.domain_delete(request, obj_id)

    def allowed(self, request, datum):
        allowed = super(DeleteDomainsAction, self).allowed(request, datum)
        if datum:
            allowed &= datum.id != api.keystone.get_default_domain(
                request, False).get('id')
        return allowed


# noinspection PyClassHasNoInit
class DomainsTable(domains_tables.DomainsTable):
    """Domain table"""
    enabled = tables.Column(
        'enabled',
        verbose_name=pgettext_lazy("Enabled field for domains", u"Enabled"),
        status=True,
        filters=(filters.yesno, filters.capfirst),
        form_field=BooleanField(
            label=pgettext_lazy("Enabled field for domains", u"Enabled"),
            required=False),
        update_action=actions.DomainEnabledAction)

    class Meta(domains_tables.DomainsTable.Meta):

        row_class = actions.UpdateRow

        table_actions_menu = (EnableDomainsAction,
                              DisableDomainsAction,
                              actions.DeleteDomainConfigurationAction)

        row_actions = (domains_tables.SetDomainContext,
                       domains_tables.UpdateUsersLink,
                       domains_tables.UpdateGroupsLink,
                       actions.EditDomainLink,
                       EnableDomainsAction,
                       DisableDomainsAction,
                       DeleteDomainsAction,
                       actions.EditConfigurationAction,
                       actions.AddConfigurationAction,
                       actions.DeleteDomainConfigurationAction,
                       actions.SetUpBackupAction)
