# coding: utf-8

from django.utils.translation import ugettext_lazy as _

from openstack_dashboard import api
from openstack_dashboard.dashboards.identity.domains import (
    workflows as domain_workflows)

from tionix_dashboard.dashboards.identity.domains import actions
from tionix_dashboard.helpers.fields import AutoGenNameRegexField


class CreateDomainInfoAction(domain_workflows.CreateDomainInfoAction):
    name = AutoGenNameRegexField(
        label=_("Name"),
        regex=r'^[\x00-\x7F]+$',
        error_messages={'invalid': _('The string may only contain ASCII '
                                     'printable characters.')})

    class Meta(object):
        name = _("Domain Information")
        slug = "create_domain"
        help_text = _("Domains provide separation between users and "
                      "infrastructure used by different organizations.")


class CreateDomainInfo(domain_workflows.CreateDomainInfo):
    action_class = CreateDomainInfoAction


class UpdateDomainInfoAction(CreateDomainInfoAction):

    def __init__(self, request, context, *args, **kwargs):
        super(UpdateDomainInfoAction, self).__init__(
            request, context, *args, **kwargs)
        if context['domain_id'] == api.keystone.get_default_domain(
                request, False).get('id'):
            self.fields['name'].widget.attrs.update({'readonly': 'readonly'})

    class Meta(object):
        name = _("Domain Information")
        slug = 'update_domain'
        help_text = _("Domains provide separation between users and "
                      "infrastructure used by different organizations. "
                      "Edit the domain details to add or remove "
                      "groups in the domain.")


class UpdateDomainInfo(domain_workflows.UpdateDomainInfo):
    action_class = UpdateDomainInfoAction


class UpdateDomainUsers(domain_workflows.UpdateDomainUsers):
    action_class = actions.UpdateDomainUsersAction


class UpdateDomain(domain_workflows.UpdateDomain):
    default_steps = (UpdateDomainInfo,
                     UpdateDomainUsers,
                     domain_workflows.UpdateDomainGroups)

    def handle(self, request, data):
        data['description'] = data.get('description', '').strip()
        return super(UpdateDomain, self).handle(request, data)


class CreateDomain(domain_workflows.CreateDomain):
    default_steps = (CreateDomainInfo, )

    def handle(self, request, data):
        data['description'] = data.get('description', '').strip()
        return super(CreateDomain, self).handle(request, data)
