# coding: utf-8

"""Identity groups actions"""
from copy import copy

from django.utils.translation import (
    ugettext_lazy as _, ungettext_lazy, npgettext_lazy)

from horizon import tables

from tionix_dashboard.clients.base import novaclient
from tionix_dashboard.helpers.actions import TnxBatchActionMixin
from tionix_dashboard.dashboards.identity.projects import actions


# noinspection PyAbstractClass
class UnassignGroupAction(TnxBatchActionMixin, tables.BatchAction):
    """Unassign group from instance"""
    name = 'unassign'
    verbose_name = _('Unassign')
    classes = ("btn-danger",)
    permissions = ('openstack.roles.admin',)
    policy_rules = (("identity", "admin_and_matching_domain_id"),)

    def confirm_header(self, count):
        return npgettext_lazy(
            "Action header",
            u"Unassign",
            u"Unassign",
            count
        )

    @staticmethod
    def action_present(count):
        return ungettext_lazy(
            u"Unassign",
            u"Unassign",
            count
        )

    @staticmethod
    def action_past(count):
        return ungettext_lazy(
            u"Unassigned",
            u"Unassigned",
            count
        )

    def action(self, request, datum_id):
        novaclient(request).tnx_servers.remove_user_group(
            datum_id, self.table.kwargs['group_id']
        )


# noinspection PyAbstractClass
class TnxGroupTenantsFilterAction(actions.TnxTenantFilterAction):
    """Tenants filter with vdi"""
    filter_choices = copy(actions.TnxTenantFilterAction.filter_choices)

    filter_choices.append(('roles', _("Roles"), False))
