# coding: utf-8

from django.utils.translation import ugettext_lazy as _, pgettext_lazy
from django.template import defaultfilters

from horizon import tables

from openstack_dashboard import api
from openstack_dashboard.dashboards.identity.groups import (
    tables as dash_tables)

from tionix_dashboard.dashboards.identity.groups import (
    actions as actions)
from tionix_dashboard.dashboards.identity.groups.constants import GROUP_DETAIL
from tionix_dashboard.dashboards.identity.projects import (
    tables as project_tables)
from tionix_dashboard.dashboards.tionix.vdi.instances import (
    actions as vdi_actions, tables as vdi_tables)
from tionix_dashboard.helpers.tables import TnxLocalPaginationTabDataTable
from tionix_dashboard.url_resolve_map import IDENTITY_PROJECT_DETAIL


# noinspection PyClassHasNoInit
class GroupNonMembersTable(dash_tables.GroupNonMembersTable):

    email = tables.Column('email', verbose_name=_('Email'),
                          filters=[lambda v: defaultfilters
                                   .default_if_none(v, ""),
                                   defaultfilters.escape,
                                   defaultfilters.urlize])

    class Meta(object):
        name = "group_non_members"
        verbose_name = _("Non-Members")
        table_actions = (dash_tables.UserFilterAction, dash_tables.AddMembers)


# noinspection PyClassHasNoInit
class TnxGroupsTable(dash_tables.GroupsTable):
    name = tables.Column('name', verbose_name=_('Name'), link=GROUP_DETAIL)

    def __init__(self, request, data=None, needs_form_wrapper=None, **kwargs):
        super(TnxGroupsTable, self).__init__(
            request, data=data, needs_form_wrapper=needs_form_wrapper, **kwargs
        )

        if not api.keystone.is_domain_admin(request):
            self.columns['name'].link = None
        else:
            self.columns['name'].link = GROUP_DETAIL

    class Meta(dash_tables.GroupsTable.Meta):
        pass


# noinspection PyClassHasNoInit
class UserVDIInstancesTable(vdi_tables.BaseVDIInstancesTable):
    """User's vdi instances table for groups table"""

    name = tables.Column(
        "name",
        verbose_name=_("Name"),
        link=vdi_tables.get_url_for_details,
    )

    class Meta(object):
        name = "user_vdi_instances"
        verbose_name = _("Associated VDI instances")
        table_actions = (vdi_actions.VDIInstanceFilterAction,
                         actions.UnassignGroupAction)
        row_actions = (actions.UnassignGroupAction,)


# noinspection PyClassHasNoInit
class ProjectsTable(TnxLocalPaginationTabDataTable,
                    project_tables.TnxTenantsTable):
    name = tables.Column(
        'name',
        verbose_name=_('Name'),
        link=IDENTITY_PROJECT_DETAIL)
    description = tables.Column(
        lambda obj: getattr(obj, 'description', None),
        verbose_name=_('Description'))
    enabled = tables.Column(
        'enabled',
        verbose_name=pgettext_lazy("Enabled field for project", u"Enabled"),
        status=True,
        filters=(defaultfilters.yesno, defaultfilters.capfirst))
    roles = tables.Column('roles',
                          verbose_name=_('Roles'),
                          wrap_list=True,
                          filters=(defaultfilters.unordered_list,))

    class Meta(object):
        name = "projects"
        verbose_name = _("Projects")
        table_actions = (actions.TnxGroupTenantsFilterAction,)
        multi_select = False
