# coding: utf-8
# pylint: disable=no-member

"""Identity groups tests"""
import mock

from openstack_dashboard import api

from tionix_tests.helpers import Empty

from tionix_dashboard.dashboards.identity.groups import tables, tabs
from tionix_dashboard.tests.helpers import BaseAdminClientTestCase


@mock.patch('tionix_dashboard.dashboards.utils.is_domain_supported',
            mock.Mock(return_value=True))
class TnxGroupsTablesTestCase(BaseAdminClientTestCase):

    def test_projects_table(self):

        table = tables.ProjectsTable(self.request)

        self.assertListEqual(
            sorted(table.columns.keys()),
            sorted(['name', 'tnx_project_type', 'description', 'id', 'enabled',
                    'domain_name', 'roles'])
        )


class TnxGroupsTabsTestCase(BaseAdminClientTestCase):

    def test_group_details_tabs(self):
        group = self.groups.first()

        tab_group = tabs.GroupDetailTabs(
            self.request, group_id=group.id
        )

        self.assertListEqual(
            sorted([tab.slug for tab in tab_group.get_tabs()]),
            sorted(['overview', 'instances_tab', 'projects_tab'])
        )

    @mock.patch('tionix_dashboard.dashboards.identity.groups.tabs.'
                'get_projects_assignments_roles_by_group')
    @mock.patch.object(api.keystone, 'role_list')
    def test_project_group_data(self, role_list, role_assignments_list):
        group = self.groups.first()
        roles = self.roles.list()
        project = self.tnx_tenants.list()[0]

        role_list.return_value = roles
        role_assignments_list.return_value = [
            Empty(
                scope={'project': {'id': project.id}},
                role={'id': role.id})
            for role in roles]

        tab_group = tabs.GroupDetailTabs(
            self.request, group_id=group.id
        )

        tab = tabs.ProjectsTab(tab_group=tab_group,
                               request=self.request)

        self.assertEqual(len(tab.get_projects_data()), 1)
