# Copyright 2013 Hewlett-Packard Development Company, L.P.
#
#    Licensed under the Apache License, Version 2.0 (the "License"); you may
#    not use this file except in compliance with the License. You may obtain
#    a copy of the License at
#
#         http://www.apache.org/licenses/LICENSE-2.0
#
#    Unless required by applicable law or agreed to in writing, software
#    distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
#    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
#    License for the specific language governing permissions and limitations
#    under the License.
import logging

from django.core.urlresolvers import reverse_lazy
from django.utils.translation import ugettext_lazy as _

from horizon import tabs, exceptions
from horizon.utils import memoized

from openstack_dashboard import api
from openstack_dashboard.dashboards.identity.groups import views

from tionix_dashboard.dashboards.identity.groups import tables as tionix_tables
from tionix_dashboard.dashboards.identity.groups import forms as tionix_forms
from tionix_dashboard.dashboards.identity.groups.tabs import GroupDetailTabs
from tionix_dashboard.helpers.views import (
    ServerSortMultiSelect, ServerFilterViewMixin)


logger = logging.getLogger(__name__)


class NonMembersView(views.NonMembersView):
    table_class = tionix_tables.GroupNonMembersTable


class TnxIndexView(views.IndexView):
    table_class = tionix_tables.TnxGroupsTable


class DetailView(ServerSortMultiSelect,
                 ServerFilterViewMixin,
                 tabs.TabbedTableView):
    """Group details view"""
    tab_group_class = GroupDetailTabs
    template_name = 'horizon/common/_detail.html'
    page_title = "{{ group.name }}"
    redirect_url = reverse_lazy('horizon:identity:groups:index')

    def get_context_data(self, **kwargs):
        """Context data"""
        context = super(DetailView, self).get_context_data(**kwargs)
        group = self.get_data()
        table = tionix_tables.TnxGroupsTable(self.request)
        context["url"] = self.redirect_url
        context["actions"] = table.render_row_actions(group)
        context["group"] = group
        return context

    @memoized.memoized_method
    def get_data(self):
        user = None
        try:
            user = api.keystone.group_get(self.request,
                                          self.kwargs['group_id'])
        except Exception as err:
            logger.error(unicode(err))
            exceptions.handle(self.request,
                              _('Unable to retrieve group details.'),
                              redirect=self.redirect_url)
        return user

    def get_tabs(self, request, **kwargs):
        kwargs['group'] = self.get_data()
        return self.tab_group_class(request, **kwargs)


class CreateView(views.CreateView):
    form_class = tionix_forms.CreateGroupForm


class UpdateView(views.UpdateView):
    form_class = tionix_forms.UpdateGroupForm
