# coding: utf-8

import logging

from django.utils.translation import ugettext_lazy as _, pgettext_lazy

from horizon import exceptions
from horizon import forms

from keystoneauth1.exceptions.http import NotFound

from openstack_dashboard import api
from openstack_dashboard.utils.identity import IdentityMixIn
from openstack_dashboard.dashboards.identity.users.forms import (
    CreateUserForm, UpdateUserForm)
from tionix_dashboard.dashboards.identity.users.helpers import (
    tenant_list_for_user)

from tionix_dashboard.helpers.fields import AutoGenNameCharField


logger = logging.getLogger(__name__)


class ProjectListMixin(object):

    @staticmethod
    def populate_projects(request, **kwargs):
        project_choices = []
        default_project_id = kwargs['initial'].get('project', None)
        user_id = kwargs['initial'].get('id', None)
        try:
            project_choices = [
                (project.id, project.name)
                for project in tenant_list_for_user(request, user=user_id)]
        except Exception as err:
            logger.error(unicode(err))

        if not project_choices:
            project_choices.insert(0, ('', _("No available projects")))
        elif len(project_choices) > 1 and default_project_id is None:
            project_choices.insert(0, ('', _("Select a project")))
        return project_choices


class TnxCreateUserForm(IdentityMixIn, ProjectListMixin, CreateUserForm):

    name = AutoGenNameCharField(max_length=255, label=_("User Name"))
    enabled = forms.BooleanField(
        label=pgettext_lazy("Enabled field for identity", u"Enabled"),
        required=False,
        initial=True)

    def __init__(self, request, *args, **kwargs):
        super(TnxCreateUserForm, self).__init__(request, *args, **kwargs)
        self.fields['project'].choices = self.populate_projects(request,
                                                                **kwargs)

    def handle(self, request, data):
        user = super(TnxCreateUserForm, self).handle(request, data)

        msg = _('Unable to add admin domain role to user.')

        domain_id = data.get('domain_id')
        role_id = data.get('role_id')

        if user and domain_id and role_id:
            try:
                role = api.keystone.role_get(request, role_id)
            except NotFound as err:
                logger.error(unicode(err))
                exceptions.handle(request, msg)
            else:
                if role.name in self.get_admin_roles():
                    try:
                        api.keystone.add_domain_user_role(request, user.id,
                                                          role_id, domain_id)
                    except Exception as err:
                        logger.error(unicode(err))
                        exceptions.handle(request, msg)
        return user


class TnxUpdateUserForm(ProjectListMixin, UpdateUserForm):

    name = AutoGenNameCharField(max_length=255, label=_("User Name"))

    def __init__(self, request, *args, **kwargs):
        super(TnxUpdateUserForm, self).__init__(request, *args, **kwargs)
        self.fields['project'].choices = self.populate_projects(request,
                                                                **kwargs)
