# coding: utf-8
import logging

from django.core.cache import cache
from django.http.response import HttpResponseRedirect
from django.template.response import TemplateResponse
from django.utils.translation import ugettext_lazy as _

from horizon import exceptions

from requests.exceptions import ConnectionError

from tionix_dashboard.clients.exceptions import UrlNotAvailableError
from tionix_dashboard.dashboards.license import LicenseController


logger = logging.getLogger(__name__)


class TionixMiddleware(object):

    def __init__(self):
        cache.set('invalid_licenses', set())

    @staticmethod
    def get_exclude_paths(request):
        exclude_paths = ('/tionix/scheduler/',)
        last_path_info = request.session.get('LAST_PATH_INFO')
        if last_path_info:
            exclude_paths = exclude_paths + (last_path_info,)
        return exclude_paths

    def process_request(self, request):
        if (getattr(request, 'user', None) and request.user.username and
                not LicenseController.first_checked):
            invalid_licenses = cache.get('invalid_licenses')
            LicenseController.first_checked = True
            unregister_panels = {}
            try:
                licenses = LicenseController.get_licenses(request,
                                                          recollect=True)
            except ConnectionError as err:
                LicenseController.first_checked = False
                logger.error(u'Licenses verification failed: {0}'.format(
                    err))
            else:
                for license_type in LicenseController.LIC_TYPES:
                    is_valid, lic = False, licenses.get(license_type)
                    if lic:
                        is_valid = lic.verified
                    is_valid = is_valid or license_type in invalid_licenses
                    unregister_panels[license_type] = is_valid
                    if not is_valid:
                        LicenseController.unregister(license_type)
                        invalid_licenses.add(license_type)

            cache.set('invalid_licenses', invalid_licenses)

    def process_response(self, request, response):
        current_path_info = request.META['PATH_INFO']
        if (isinstance(response, TemplateResponse) and
                current_path_info not in self.get_exclude_paths(request)):
            del_keys = [
                k
                for k in request.session.keys()
                if k.endswith('__q') or k.endswith('__q_field')]
            for i in del_keys:
                del request.session[i]

            request.session['LAST_PATH_INFO'] = current_path_info

        return response

    def process_exception(self, request, exception):
        if isinstance(exception, UrlNotAvailableError):
            LicenseController.unregister(exception.lic_type)
            exceptions.handle(
                request,
                _(u'Panel unavailable, license got out'))
            return HttpResponseRedirect(redirect_to=exception.redirect_to)
