# coding: utf-8

from django.utils.translation import ugettext_lazy as _
from neutronclient.common import exceptions as neutron_exc

from horizon import exceptions

from openstack_dashboard import api
from openstack_dashboard.dashboards.project.access_and_security.floating_ips \
    import workflows


class AssociateIPAction(workflows.AssociateIPAction):
    class Meta(object):
        name = _("IP Address")
        help_text = _('Select or allocate the new floating IP address that '
                      'you want to associate with the selected instance '
                      'and/or port from the list.')


class AssociateIP(workflows.AssociateIP):
    action_class = AssociateIPAction


# noinspection PyBroadException
class IPAssociationWorkflow(workflows.IPAssociationWorkflow):

    default_steps = (AssociateIP,)

    def handle(self, request, data):
        try:
            api.network.floating_ip_associate(request,
                                              data['ip_id'],
                                              data['instance_id'])
        except neutron_exc.Conflict:
            msg = _('The requested port is already associated with another '
                    'floating IP address.')
            exceptions.handle(request, msg)
            self.failure_message = msg
            return False

        except Exception:
            exceptions.handle(request)
            return False
        return True
