# coding: utf-8

from django.utils.translation import ugettext_lazy as _

from openstack_dashboard.dashboards.project.access_and_security.\
    security_groups import tables

from tionix_dashboard.helpers.actions import TnxFilterAction
from tionix_dashboard.helpers.tables import ServerFilterTableMixin


def get_in_use_by_name(value):
    # noinspection PyTypeChecker
    if isinstance(value, basestring):
        value = value.lower() == 'true'
    elif not isinstance(value, bool):
        value = bool(value)
    return value


# noinspection PyAbstractClass
class TnxSecurityGroupsFilterAction(TnxFilterAction):
    filter_type = "server"

    filter_choices = (('name', _("Name"), False),
                      ('description', _("Description"), False),
                      ('in_use', _("In use"), False),)

    filter_string_modifiers = {
        'in_use': get_in_use_by_name,
    }


class TnxSecurityGroupsTable(ServerFilterTableMixin,
                             tables.SecurityGroupsTable):
    class Meta(object):
        name = "security_groups"
        verbose_name = _("Security Groups")
        table_actions = (tables.CreateGroup, tables.DeleteGroup,
                         TnxSecurityGroupsFilterAction)
        row_actions = (tables.ManageRules, tables.EditGroup,
                       tables.DeleteGroup)
