# coding: utf-8

from horizon import tabs as hor_tabs

from openstack_dashboard.dashboards.project.access_and_security import tabs

from tionix_dashboard.dashboards.project.access_and_security.security_groups.\
    table import TnxSecurityGroupsTable
from tionix_dashboard.helpers.views import ServerFilterTabMixin
from tionix_dashboard.clients.servers import TNXServersClient
from tionix_dashboard.clients.backup_systems import TNXBackupSystemsClient
from tionix_dashboard.dashboards.identity.domains.helpers import (
    get_backup_system_by_domain)
from tionix_dashboard.dashboards.tionix.metrics.api import is_bareos_available


# noinspection PyAbstractClass
class TnxSecurityGroupsTab(ServerFilterTabMixin, tabs.SecurityGroupsTab):
    table_classes = (TnxSecurityGroupsTable,)

    def get_security_groups_data(self):
        security_groups = super(TnxSecurityGroupsTab,
                                self).get_security_groups_data()
        used_groups = set()
        servers = TNXServersClient.list(self.request, detailed=True)
        for server in servers:
            for group in getattr(server, 'security_groups', ()):
                used_groups.add(group['name'])

        for group in security_groups:
            group.in_use = group.name in used_groups
        return security_groups


# noinspection PyAbstractClass,PyClassHasNoInit
class TnxBareosTab(hor_tabs.Tab):
    name = "Bareos"
    slug = "bareos_tab"
    template_name = "project/access_and_security/bareos/data.html"

    def get_context_data(self, request, **kwargs):
        name = ""
        password = ""
        domain_id = request.user.user_domain_id
        system = get_backup_system_by_domain(request, domain_id=domain_id)

        if system:
            name = TNXBackupSystemsClient.get_director_name(
                request, domain_id, system.backup_system)['name']
            password = system.password

        return {"name": name,
                "password": password}

    def allowed(self, request):
        return is_bareos_available(request)


# noinspection PyAbstractClass
class TnxAccessAndSecurityTabs(tabs.AccessAndSecurityTabs):
    tabs = (TnxSecurityGroupsTab, tabs.KeypairsTab, tabs.FloatingIPsTab,
            tabs.APIAccessTab, TnxBareosTab)
