# coding: utf-8

import logging

from django.core.urlresolvers import reverse, reverse_lazy
from django.utils.translation import ugettext_lazy as _

from horizon import exceptions

from requests.exceptions import ConnectionError

from openstack_dashboard.dashboards.project.network_topology import (
    views as net_topology_views)

from tionix_dashboard.dashboards.project.project_networks import (
    workflows as network_workflows, views as network_views)
from tionix_dashboard.dashboards.project.project_routers import (
    views as routes_views)


logger = logging.getLogger(__name__)


class TnxNetworkTopologyView(net_topology_views.NetworkTopologyView):

    template_name = 'network_topology/index.html'

    def _quota_exceeded(self, quota):
        result = True
        try:
            result = super(TnxNetworkTopologyView, self)._quota_exceeded(quota)
        except ConnectionError as err:
            logger.error(unicode(err))
            exceptions.handle(self.request,
                              _('Failed to retrieve quota information.'))
        return result


class NTCreateNetwork(network_workflows.CreateNetwork):
    def get_success_url(self):
        return reverse("horizon:project:network_topology:index")

    def get_failure_url(self):
        return reverse("horizon:project:network_topology:index")


class NTCreateNetworkView(network_views.CreateView):
    workflow_class = NTCreateNetwork


class NTCreateRouterView(routes_views.CreateView):
    template_name = 'network_topology/create_router.html'
    success_url = reverse_lazy("horizon:project:network_topology:index")
    page_title = _("Create Router")
