# coding: utf-8

from django.core.urlresolvers import reverse
from django.utils.translation import ugettext_lazy as _
from horizon import tables
from openstack_dashboard import api
from openstack_dashboard.dashboards.project.images.images import (
    tables as project_tables)

from tionix_dashboard.helpers.actions import TnxBatchActionMixin


class DeleteImage(TnxBatchActionMixin, project_tables.DeleteImage):
    pass


# noinspection PyAbstractClass,PyClassHasNoInit
class CreateVolumeFromImage(project_tables.CreateVolumeFromImage):

    def allowed(self, request, image=None):
        if image and api.cinder.is_volume_service_enabled(request) and (
                not hasattr(image, 'container_format') or (
                    image.container_format not in
                    project_tables.NOT_LAUNCHABLE_FORMATS)):
            return image.status and image.status.lower() == "active"
        return False


# noinspection PyAbstractClass,PyClassHasNoInit
class LaunchImage(project_tables.LaunchImage):

    def allowed(self, request, image=None):
        if image and (not hasattr(image, 'container_format') or (
                image.container_format not in
                project_tables.NOT_LAUNCHABLE_FORMATS)):
            return image.status and image.status.lower() == "active"
        return False


# pylint: disable=bad-super-call
class LaunchImageNG(LaunchImage):
    name = "launch_image_ng"
    verbose_name = _("Launch")
    url = "horizon:project:images:index"
    classes = ("btn-launch",)
    ajax = False

    def __init__(self, attrs=None, **kwargs):
        kwargs['preempt'] = True
        super(LaunchImage, self).__init__(attrs, **kwargs)

    # noinspection PyMethodOverriding
    def get_link_url(self, datum):
        image_id = self.table.get_object_id(datum)
        url = reverse(self.url)
        ngclick = ("modal.openLaunchInstanceWizard({successUrl: '%s', "
                   "imageId: '%s'})" % (url, image_id))
        self.attrs.update(
            {
                "ng-controller": "LaunchInstanceModalController as modal",
                "ng-click": ngclick
            })
        return "javascript:void(0);"


# noinspection PyClassHasNoInit
class ProjectImagesTable(project_tables.ImagesTable):
    name = tables.Column("name",
                         link="horizon:project:images:images:img_detail",
                         truncate=40, verbose_name=_("Image Name"))

    # noinspection PyTypeChecker
    class Meta(object):
        name = "images"
        row_class = project_tables.UpdateRow
        status_columns = ["status"]
        verbose_name = _("Images")
        table_actions = (
            project_tables.OwnerFilter,
            project_tables.CreateImage, DeleteImage,)
        launch_actions = ()
        if getattr(project_tables.settings, 'LAUNCH_INSTANCE_LEGACY_ENABLED',
                   False):
            launch_actions = (LaunchImage,) + launch_actions
        if getattr(project_tables.settings, 'LAUNCH_INSTANCE_NG_ENABLED',
                   True):
            launch_actions = (LaunchImageNG,) + launch_actions
        row_actions = launch_actions + (CreateVolumeFromImage,
                                        project_tables.EditImage,
                                        project_tables.UpdateMetadata,
                                        DeleteImage,)
