# coding: utf-8

"""
Views for managing images.
"""

from openstack_dashboard.dashboards.project.images import views as index_view
from openstack_dashboard.dashboards.project.images.images import (
    views as images_views)
from openstack_dashboard.dashboards.project.images.snapshots import (
    views as snapshots_views)

from tionix_dashboard.dashboards.project.project_images import (
    forms, tabs, tables)
from tionix_dashboard.dashboards.project.project_images.helpers import (
    save_in_cache_image_file)


# noinspection PyClassHasNoInit
class TnxIndexView(index_view.IndexView):
    table_class = tables.ProjectImagesTable


# noinspection PyClassHasNoInit
class DetailView(images_views.DetailView):
    tab_group_class = tabs.TnxImageDetailTabs


# noinspection PyClassHasNoInit
class CreateImageView(images_views.CreateView):
    form_class = forms.CreateImageForm

    def form_invalid(self, form):
        image_file = form.cleaned_data.get('image_file')
        if image_file:
            save_in_cache_image_file(self.request, image_file)
        return super(CreateImageView, self).form_invalid(form)


# noinspection PyClassHasNoInit
class UpdateImageView(images_views.UpdateView):
    form_class = forms.UpdateImageForm

    def get_initial(self):
        data = super(UpdateImageView, self).get_initial()
        image = self.get_object()
        is_scsi = image.properties.get('hw_disk_bus') == 'scsi'
        data['direct_scsi'] = is_scsi
        return data


# noinspection PyClassHasNoInit
class CreateSnapshotView(snapshots_views.CreateView):
    form_class = forms.CreateSnapshot
