# coding: utf-8

from django.utils.translation import ugettext_lazy as _, pgettext_lazy

from openstack_dashboard.dashboards.project.instances import (
    tables as project_tables)


POWER_STATES_TRANS = (
    pgettext_lazy("Power state of an Instance", u"No State"),
    pgettext_lazy("Power state of an Instance", u"Running"),
    pgettext_lazy("Power state of an Instance", u"Blocked"),
    pgettext_lazy("Power state of an Instance", u"Shut Down"),
    pgettext_lazy("Power state of an Instance", u"Crashed"),
    pgettext_lazy("Power state of an Instance", u"Failed"),
    pgettext_lazy("Power state of an Instance", u"Building")
)

STATUSES_TRANS = (
    pgettext_lazy("Current status of an Instance", u"Active"),
    pgettext_lazy("Current status of an Instance", u"Building"),
    pgettext_lazy("Current status of an Instance", u"Error"),
    pgettext_lazy("Current status of an Instance", u"Rebuild"),
    pgettext_lazy("Current status of an Instance", u"Shelved"),
    pgettext_lazy("Current status of an Instance", u"Shelved Offloaded"),
    pgettext_lazy("Current status of an Instance", u"Suspended"),
    pgettext_lazy("Current status of an Instance", u"Shutoff"),
    pgettext_lazy("Current status of an Instance", u"Resized"),
    pgettext_lazy("Current status of an Instance",
                  u"Confirm or Revert Resize/Migrate"),
)


VM_STATUS_DISPLAY_CHOICES = (
    ("build", pgettext_lazy("Current status of an Instance", u"Building")),
    ("initialized", pgettext_lazy("Current status of an Instance",
                                  u"Initialized")),
    ("unknown", pgettext_lazy("Current status of an Instance", u"Unknown")),
) + project_tables.STATUS_DISPLAY_CHOICES


STATUS_CHOICES = (
    ("active", True),
    ("shutoff", True),
    ("suspended", True),
    ("paused", True),
    ("error", True),
    ("rescue", True),
    ("shelved", True),
    ("shelved_offloaded", True),
)


TASK_STATES_TRANS = (
    pgettext_lazy("Task status of an Instance", u"Networking"),
    pgettext_lazy("Task status of an Instance", u"Pausing"),
    pgettext_lazy("Task status of an Instance", u"Rebuilding"),
    pgettext_lazy("Task status of an Instance", u"Rescuing"),
    pgettext_lazy("Task status of an Instance", u"Resized or Migrated"),
    pgettext_lazy("Task status of an Instance", u"Shelving"),
    pgettext_lazy("Task status of an Instance", u"Spawning"),
    pgettext_lazy("Task status of an Instance", u"Unshelving"),
    pgettext_lazy("Task status of an Instance",
                  u"Finishing Resize or Migrate"),
    pgettext_lazy("Task status of an Instance", u"Resized or Migrated"),
    pgettext_lazy("Task status of an Instance", u"Unrescuing")
)

VM_TASK_DISPLAY_CHOICES = project_tables.TASK_DISPLAY_CHOICES + (
    ("force_delete", pgettext_lazy("Task status of an Instance",
                                   u"Force delete")),
)


ACTION_DISPLAY_CHOICES = (
    (
        ("assign", pgettext_lazy("Action log of an instance",
                                 'Assign user')),
        ("unassign", pgettext_lazy("Action log of an instance",
                                   'Unassign user')),
        ("shelve", pgettext_lazy("Action log of an instance",
                                 'Shelve instance')),
        ("unshelve", pgettext_lazy("Action log of an instance",
                                   'Unshelve instance')),
        ("addFloatingIp", pgettext_lazy("Action log of an instance",
                                        'Associate floating IP')),
        ("addSecurityGroup", pgettext_lazy("Action log of an instance",
                                           'Add security group')),
        ("changePassword", _('Retrieve Password')),
        ("confirmResize", _('Confirm resize/migrate')),
        ("createImage", pgettext_lazy("Action log of an instance",
                                      'Create image')),
        ("create-image", pgettext_lazy("Action log of an instance",
                                       'Create image')),
        ("create-snapshot", pgettext_lazy("Action log of an instance",
                                          'Create snapshot')),
        ("detach-interface", pgettext_lazy("Action log of an instance",
                                           'Detach interface')),
        ("attach-interface", pgettext_lazy("Action log of an instance",
                                           'Attach interface')),
        ("lock", pgettext_lazy("Action log of an instance",
                               'Lock instance')),
        ("unlock", pgettext_lazy("Action log of an instance",
                                 'Unlock instance')),
        ("removeFloatingIp", pgettext_lazy("Action log of an instance",
                                           'Disassociate floating IP')),
        ("removeSecurityGroup", pgettext_lazy("Action log of an instance",
                                              'Remove security group')),
        ("rescue", pgettext_lazy("Action log of an instance", 'Rescue')),
        ("revertResize", pgettext_lazy("Action log of an instance",
                                       'Revert resize/migrate')),
        ("os-start", pgettext_lazy("Action log of an instance",
                                   'Start instance')),
        ("os-stop", pgettext_lazy("Action log of an instance",
                                  'Shut off instance')),
        ("unrescue", pgettext_lazy("Action log of an instance",
                                   'Unrescue')),
        ("addFixedIp", pgettext_lazy("Action log of an instance",
                                     'Add fixed ip')),
        ("removeFixedIp", pgettext_lazy("Action log of an instance",
                                        'Remove fixed ip')),
        ("evacuate", pgettext_lazy("Action log of an instance",
                                   'Evacuate')),
        ("forceDelete", pgettext_lazy("Action log of an instance",
                                      'Force delete')),
        ("restore", pgettext_lazy("Action log of an instance", 'Restore')),
        ("os-getConsoleOutput", pgettext_lazy("Action log of an instance",
                                              'Get output console')),
        ("os-getRDPConsole", pgettext_lazy("Action log of an instance",
                                           'Get RDP console')),
        ("os-getSerialConsole", pgettext_lazy("Action log of an instance",
                                              'Get serial console')),
        ("os-getSPICEConsole", pgettext_lazy("Action log of an instance",
                                             'Get SPICE console')),
        ("os-getVNCConsole", pgettext_lazy("Action log of an instance",
                                           'Get VNC console')),
        ("shelveOffload", pgettext_lazy("Action log of an instance",
                                        'Shelve offload')),
        ("createBackup", pgettext_lazy("Action log of an instance",
                                       'Create backup')),
        ("injectNetworkInfo", pgettext_lazy("Action log of an instance",
                                            'Inject network info')),
        ("migrate", pgettext_lazy("Action log of an instance",
                                  'Migrate instance')),
        ("os-migrateLive", pgettext_lazy("Action log of an instance",
                                         'Live migrate instance')),
        ("resetNetwork", pgettext_lazy("Action log of an instance",
                                       'Reset network')),
        ("repair", pgettext_lazy("Action log of an instance",
                                 'Repair instance')),
        ("movable", pgettext_lazy("Action log of an instance",
                                  'Change movable flag')),
        ("os-resetState", pgettext_lazy("Action log of an instance",
                                        'Reset state')),
        ("create", pgettext_lazy("Action log of an instance",
                                 'Create instance')),
        ("delete", pgettext_lazy("Action log of an instance",
                                 'Delete instance')),
        ("recover", pgettext_lazy("Action log of an instance",
                                  'Recover instance')),
        ("reset-with-reboot", pgettext_lazy("Action log of an instance",
                                            'Reset and reboot instance')),
        ("balance", pgettext_lazy("Action log of an instance",
                                  'Balance instance')),
        ("assign-user-group", pgettext_lazy("Action log of an instance",
                                            'Assign user group')),
        ("unassign-user-group", pgettext_lazy("Action log of an instance",
                                              'Unassign user group')),
        ("zabbix-create-host", pgettext_lazy("Action log of an instance",
                                             'Create Zabbix host')),
        ("zabbix-update-host", pgettext_lazy("Action log of an instance",
                                             'Update Zabbix host')),
        ("zabbix-delete-host", pgettext_lazy("Action log of an instance",
                                             'Delete Zabbix host')),
        ("assign-backup-templates", pgettext_lazy("Action log of an instance",
                                                  'Assign backup templates')),
        ("unassign-backup-templates",
         pgettext_lazy("Action log of an instance",
                       'Unassign backup templates')),
        ("pause", pgettext_lazy("Action log of an instance",
                                'Pause instance')),
        ("unpause", pgettext_lazy("Action log of an instance",
                                  'Unpause instance')),
        ("rebuild", pgettext_lazy("Action log of an instance",
                                  'Rebuild instance')),
        ("resize", pgettext_lazy("Action log of an instance",
                                 'Resize instance')),
        ("suspend", pgettext_lazy("Action log of an instance",
                                  'Suspend instance')),
        ("resume", pgettext_lazy("Action log of an instance",
                                 'Resume instance')),
        ("reboot", pgettext_lazy("Action log of an instance",
                                 'Reboot instance')),
        ("reboot_soft", pgettext_lazy("Action log of an instance",
                                      'Soft reboot instance')),
        ("reboot_hard", pgettext_lazy("Action log of an instance",
                                      'Hard reboot instance')),
        ("edit-instance", pgettext_lazy("Action log of an instance",
                                        'Update instance info')),
        ("update-security-groups",
         pgettext_lazy("Action log of an instance",
                       'Update instance security group')),
        ("add-scsi-metadata", pgettext_lazy("Action log of an instance",
                                            'Set SCSI metadata')),
    )
)
