/**
 * Created by user on 19.03.18.
 */
(function () {
  'use strict';

  var push = Array.prototype.push;
  var noop = angular.noop;

  /**
   * @ngdoc controller
   * @name BaseInstanceAttachmentsController
   * @description
   * The `BaseInstanceAttachmentsController` controller to manage volume's attachments
   */
  angular.module('horizon.project.instances')
    .controller('BaseInstanceAttachmentsController', BaseInstanceAttachmentsController);

  BaseInstanceAttachmentsController.$inject = [
    '$element',
    'gbFilter',
    'noValueFilter',
    'horizon.app.core.openstack-service-api.tnx'
  ];

  function BaseInstanceAttachmentsController(
    $element,
    gbFilter,
    noValueFilter,
    tnxAPI
  ) {

    var ctrl = this,
      available = [],
      allocated = [];

    ctrl.getVolumes = getVolumes;
    ctrl.onGetVolumes = onGetVolumes;

    ctrl.$form = $element.closest('form');
    ctrl.$fieldInstanceId = ctrl.$form.find('#id_instance_id').val();
    ctrl.$oldAllocated = ctrl.$form.find('#id_old_allocated');
    ctrl.oldAllocatedIds = angular.fromJson(ctrl.$oldAllocated.val() || '[]');
    ctrl.$newAllocated = ctrl.$form.find('#id_new_allocated');

    ctrl.tableLimits = {
      maxAllocation: -1
    };

     ctrl.tableHelp = {
       allocTitle: gettext("Selected"),
       availHelpText: gettext('Select one or more')
    };

    ctrl.columns = [
      {attrName: "name", headerName: gettext("Name")},
      {attrName: "size", headerName: gettext("Size"), filter: gbFilter},
      {attrName: "volume_type", headerName: gettext("Type"),
        filter: noValueFilter},
      {attrName: "status_name", headerName: gettext("Status")},
      {attrName: "availability_zone", headerName: gettext("Zone")}
    ];

    ctrl.model = {
      available: available,
      allocated: allocated
    };

    ctrl.$form.submit(function() {
      ctrl.$newAllocated.val(angular.toJson(ctrl.model.allocated));
    });

    function getVolumes() {
      var params = {
        status: 'available',
        attached_instance_id: ctrl.$fieldInstanceId
      };

      available.length = 0;
      allocated.length = 0;

      tnxAPI.getTnxVolumes(params).then(onGetVolumes, noop);
    }

    function onGetVolumes(data) {
      push.apply(available, data.data.items);

      if (ctrl.oldAllocatedIds && ctrl.oldAllocatedIds.length > 0) {
        data.data.items.forEach(function(volume){
          if (ctrl.oldAllocatedIds.indexOf(volume.id) > -1) {
            allocated.push(volume);
          }
       });
      }

      return data;
    }

  }
})();
