# coding: utf-8

from django.utils.translation import ugettext_lazy as _

from openstack_dashboard.dashboards.project.networks import (
    workflows as networks_workflows)
from openstack_dashboard.dashboards.project.networks.subnets import (
    workflows as subnets_workflows)

from tionix_dashboard.helpers.fields import AutoGenNameCharField


class CreateNetworkInfoAction(networks_workflows.CreateNetworkInfoAction):
    net_name = AutoGenNameCharField(max_length=255,
                                    label=_("Network Name"))

    class Meta(object):
        name = _("Network")
        help_text = _('Create a new network. '
                      'In addition, a subnet associated with the network '
                      'can be created in the following steps of this wizard.')


class CreateNetworkInfo(networks_workflows.CreateNetworkInfo):
    action_class = CreateNetworkInfoAction


class NetworkCreateSubnetInfoAction(networks_workflows.CreateSubnetInfoAction):
    subnet_name = AutoGenNameCharField(max_length=255, label=_("Subnet Name"))

    class Meta(object):
        name = _("Subnet")
        help_text = _('Creates a subnet associated with the network.'
                      ' You need to enter a valid "Network Address"'
                      ' and "Gateway IP". If you did not enter the'
                      ' "Gateway IP", the first value of a network'
                      ' will be assigned by default. If you do not want'
                      ' gateway please check the "Disable Gateway" checkbox.'
                      ' Advanced configuration is available by clicking on'
                      ' the "Subnet Details" tab.')


class NetworkCreateSubnetInfo(networks_workflows.CreateSubnetInfo):
    action_class = NetworkCreateSubnetInfoAction


class CreateNetwork(networks_workflows.CreateNetwork):
    default_steps = (CreateNetworkInfo,
                     NetworkCreateSubnetInfo,
                     networks_workflows.CreateSubnetDetail)


class UpdateSubnetInfoAction(subnets_workflows.UpdateSubnetInfoAction):
    subnet_name = AutoGenNameCharField(max_length=255, label=_("Subnet Name"))

    class Meta(object):
        name = _("Subnet")
        help_text = _('Update a subnet associated with the network. '
                      'Advanced configuration are available at '
                      '"Subnet Details" tab.')


class UpdateSubnetInfo(subnets_workflows.UpdateSubnetInfo):
    action_class = UpdateSubnetInfoAction


class UpdateSubnet(subnets_workflows.UpdateSubnet):
    default_steps = (UpdateSubnetInfo,
                     subnets_workflows.UpdateSubnetDetail)


class CreateSubnetInfoAction(subnets_workflows.CreateSubnetInfoAction):
    subnet_name = AutoGenNameCharField(max_length=255, label=_("Subnet Name"))

    class Meta(object):
        name = _("Subnet")
        help_text = _('Create a subnet associated with the network. '
                      'Advanced configuration is available by clicking on the '
                      '"Subnet Details" tab.')


class CreateSubnetInfo(subnets_workflows.CreateSubnetInfo):
    action_class = CreateSubnetInfoAction


class CreateSubnet(subnets_workflows.CreateSubnet):
    default_steps = (CreateSubnetInfo,
                     networks_workflows.CreateSubnetDetail)
