# coding: utf-8
# pylint: disable=duplicate-code

import mock

from oslo_utils import uuidutils

from openstack_dashboard import api

from tionix_dashboard.dashboards.project.project_routers import forms
from tionix_dashboard.tests.helpers import BaseClientTestCase


class TnxProjectRoutesFormsTest(BaseClientTestCase):

    @mock.patch.object(api.neutron, 'network_list', mock.Mock(return_value=[]))
    def test_create_route_form_random_data(self):
        form = forms.CreateForm(self.request, data={})

        form.full_clean()

        self.assertTrue(uuidutils.is_uuid_like(form.cleaned_data['name']))

    @mock.patch.object(api.neutron, 'network_list', mock.Mock(return_value=[]))
    def test_create_route_form_input_name(self):
        test_route_name = 'test name'

        form = forms.CreateForm(self.request, data={'name': test_route_name})

        form.full_clean()

        self.assertEqual(test_route_name, form.cleaned_data['name'])

    @mock.patch.object(api.neutron, 'network_list', mock.Mock(return_value=[]))
    def test_update_route_form_random_name(self):
        form = forms.UpdateForm(self.request, data={})

        form.full_clean()

        self.assertTrue(uuidutils.is_uuid_like(form.cleaned_data['name']))

    @mock.patch.object(api.neutron, 'network_list', mock.Mock(return_value=[]))
    def test_update_route_form_input_name(self):
        test_route_name = 'test name'

        form = forms.UpdateForm(self.request, data={'name': test_route_name})

        form.full_clean()

        self.assertEqual(test_route_name, form.cleaned_data['name'])
