# coding: utf-8
# pylint: disable=no-member

import mock

from openstack_dashboard.test import helpers as test

from tionix_dashboard.dashboards.project.project_volumes import helpers
from tionix_dashboard.dashboards.project.project_volumes.backups import (
    tables, tabs)
from tionix_dashboard.dashboards.project.project_volumes.volumes import (
    tabs as volumes_tab)


class VolumeBackupsTablesTestCase(test.TestCase):
    def test_tnx_vol_backups_actions(self):
        backups = self.cinder_volume_backups.list()

        table = tables.BackupsTable(self.request, data=backups)

        self.assertListEqual(
            sorted([action.name for action in table.get_table_actions()]),
            sorted(['filter', 'delete'])
        )

    def test_tnx_backups_row_actions(self):
        table = tables.BackupsTable(self.request)

        backup = self.cinder_volume_backups.first()
        self.assertListEqual(
            sorted([action.name for action in table.get_row_actions(backup)]),
            sorted(['restore', 'delete'])
        )

    def test_tnx_det_backups_columns(self):
        table = tables.DetailVolumeBackupsTable(self.request)

        self.assertListEqual(
            sorted(table.columns.keys()),
            sorted(['multi_select', 'name', 'description', 'size', 'status',
                    'actions'])
        )

    def test_tnx_det_backups_actions(self):
        backups = self.cinder_volume_backups.list()

        table = tables.DetailVolumeBackupsTable(self.request, data=backups)

        self.assertListEqual(
            sorted([action.name for action in table.get_table_actions()]),
            sorted(['filter', 'delete'])
        )

    def test_tnx_det_backups_row_actions(self):
        table = tables.DetailVolumeBackupsTable(self.request)

        backup = self.cinder_volume_backups.first()
        self.assertListEqual(
            sorted([action.name for action in table.get_row_actions(backup)]),
            sorted(['restore', 'delete'])
        )


class VolumeBackupsTabsTestCase(test.TestCase):

    @mock.patch.object(helpers, 'get_cinder_backups')
    def test_data(self, get_cinder_backups):
        volume = self.cinder_volumes.first()
        backups = self.cinder_volume_backups.list()

        get_cinder_backups.return_value = [backup for backup in backups
                                           if backup.volume_id == volume.id]

        tab_group = volumes_tab.VolumeDetailTabs(
            self.request, volume=volume, volume_id=volume.id
        )
        tab = tabs.VolumeBackupsTab(tab_group=tab_group,
                                    request=self.request)
        for backup in tab.get_volume_backups_data():
            self.assertEqual(backup.volume, volume)
