# coding: utf-8

"""Tnx project volume snapshots tabs"""

import logging

from django.utils.translation import ugettext_lazy as _

from horizon import exceptions, tabs

from openstack_dashboard import api

from tionix_dashboard.dashboards.project.project_volumes.snapshots import (
    tables as snapshots_tables)
from tionix_dashboard.helpers.views import ServerFilterTabMixin


logger = logging.getLogger(__name__)


class VolumeSnapshotsTab(ServerFilterTabMixin,
                         tabs.TableTab):
    """Volume's snapshots tab"""
    table_classes = (snapshots_tables.DetailVolumeSnapshotsTable,)
    name = _("Volume Snapshots")
    slug = "snapshots_tab"
    template_name = "horizon/common/_detail_table.html"
    preload = False

    def get_volume_snapshots_data(self):
        snapshots = []
        if api.base.is_service_enabled(self.request, 'volumev2'):
            search_opts = self.get_filters(
                {'volume_id': self.tab_group.kwargs['volume_id']}
            )
            try:
                snapshots = api.cinder.volume_snapshot_list(
                    self.request,
                    search_opts=search_opts
                )
            except Exception as err:
                logger.error(err)
                exceptions.handle(self.request,
                                  _("Unable to retrieve volume snapshots."))
            else:
                volume = self.tab_group.kwargs['volume']
                for snapshot in snapshots:
                    snapshot._volume = volume

        return snapshots
