# coding: utf-8
# pylint: disable=no-member

import mock
from openstack_dashboard import api

from openstack_dashboard.test import helpers as test

from tionix_dashboard.dashboards.project.project_volumes.snapshots import (
    tables, tabs)
from tionix_dashboard.dashboards.project.project_volumes.volumes import (
    tabs as volumes_tab)


class VolumeSnapshotsTablesTestCase(test.TestCase):
    def test_tnx_snaps_actions(self):
        snapshots = self.cinder_volume_snapshots.list()

        table = tables.VolumeSnapshotsTable(self.request, data=snapshots)

        self.assertListEqual(
            sorted([action.name for action in table.get_table_actions()]),
            sorted(['filter', 'delete'])
        )

    def test_tnx_snaps_row_actions(self):
        table = tables.VolumeSnapshotsTable(self.request)

        snapshot = self.cinder_volume_snapshots.first()
        self.assertListEqual(
            sorted([action.name
                    for action in table.get_row_actions(snapshot)]),
            sorted(['create_from_snapshot', 'delete', 'edit',
                    'launch_snapshot_ng'])
        )

    def test_tnx_det_snapshots_columns(self):
        table = tables.DetailVolumeSnapshotsTable(self.request)

        self.assertListEqual(
            sorted(table.columns.keys()),
            sorted(['multi_select', 'name', 'description', 'size', 'status',
                    'actions'])
        )

    def test_tnx_det_snapshots_actions(self):
        snapshots = self.cinder_volume_snapshots.list()

        table = tables.DetailVolumeSnapshotsTable(self.request, data=snapshots)

        self.assertListEqual(
            sorted([action.name for action in table.get_table_actions()]),
            sorted(['filter', 'delete'])
        )

    def test_tnx_det_snapshots_row_actions(self):
        table = tables.DetailVolumeSnapshotsTable(self.request)

        snapshot = self.cinder_volume_snapshots.first()
        self.assertListEqual(
            sorted([action.name
                    for action in table.get_row_actions(snapshot)]),
            sorted(['create_from_snapshot', 'delete', 'edit',
                    'launch_snapshot_ng'])
        )


class VolumeBackupsTabsTestCase(test.TestCase):

    @mock.patch.object(api.cinder, 'volume_snapshot_list')
    def test_data(self, volume_snapshot_list):
        volume = self.cinder_volumes.first()
        snapshots = self.cinder_volume_snapshots.list()

        volume_snapshot_list.return_value = [snap for snap in snapshots
                                             if snap.volume_id == volume.id]

        tab_group = volumes_tab.VolumeDetailTabs(
            self.request, volume=volume, volume_id=volume.id
        )
        tab = tabs.VolumeSnapshotsTab(tab_group=tab_group,
                                      request=self.request)
        for snapshot in tab.get_volume_snapshots_data():
            self.assertEqual(snapshot._volume, volume)
