/**
 * Created by user on 31.01.18.
 */
(function () {
  'use strict';

  var push = Array.prototype.push;
  var noop = angular.noop;

  /**
   * @ngdoc controller
   * @name VolumeAttachmentsController
   * @description
   * The `VolumeAttachmentsController` controller to manage volume's attachments
   */
  angular.module('horizon.project.volumes.volumes')
    .controller('VolumeAttachmentsController', VolumeAttachmentsController);

  VolumeAttachmentsController.$inject = [
    '$element',
    '$filter',
    'horizon.app.core.openstack-service-api.tnx',
    'trustedHtmlFilter'
  ];

  function VolumeAttachmentsController(
    $element,
    $filter,
    tnxAPI,
    trustedHtmlFilter) {

    var ctrl = this,
      available = [],
      allocated = [];

    ctrl.isLoaded = false;
    ctrl.$element = $element;
    ctrl.$form = $element.closest('form');
    ctrl.$fieldInstance = ctrl.$form.find('#id_instance_id');
    ctrl.$fieldInstanceVal = ctrl.$fieldInstance.val();

    ctrl.$fieldInstance.closest('.form-group').hide();

    ctrl.tableLimits = {
      maxAllocation: 1
    };

    ctrl.tableHelp = {
      allocTitle: pgettext("Volume", "Selected"),
      availHelpText: pgettext("Volume", "Select one")
    };

    ctrl.$form.submit(function() {
      if (ctrl.model.allocated.length > 0) {
        ctrl.$fieldInstance.val(ctrl.model.allocated[0].id);
      }
    });

    ctrl.columns = [
      {attrName: "name", headerName: gettext("Name")},
      {attrName: "ip_addresses", headerName: gettext("IP Address"),
        filter: trustedHtmlFilter, isHtml: true},
      {attrName: "tnx_type_name", headerName: gettext("Type")},
      {attrName: "status_name", headerName: gettext("Status")},
      {attrName: "availability_zone", headerName: gettext("Zone")},
      {attrName: "is_direct_scsi", headerName: gettext("Direct SCSI"),
        filter: $filter('yesno')}
    ];

    ctrl.model = {
      available: available,
      allocated: allocated
    };

    getInstances();

    ctrl.$form.submit(function() {
      ctrl.$fieldInstance.val(ctrl.model.allocated.length > 0 ? ctrl.model.allocated[0].id : '');
    });

    function getInstances() {
      var searchOpts = {'status': ['active', 'shutoff', 'paused',
        'suspended']};
      tnxAPI.getTnxServers(searchOpts).then(onGetInstances, noop);
    }

    function onGetInstances(data) {
      available.lenght = 0;
      push.apply(available, data.data.items);

      allocated.length = 0;
      if (ctrl.$fieldInstanceVal) {
        data.data.items.forEach(function(instance){
          if (instance.id === ctrl.$fieldInstanceVal) {
            allocated.push(instance);
          }
       });
      }

      return data;
    }

  }
})();