# coding: utf-8
# pylint: disable=no-member

from django.conf import settings

from tionix_tests.helpers import get_fake_request

from tionix_dashboard.dashboards.settings.user import forms
from tionix_dashboard.tests.helpers import BaseClientTestCase, FakeUser


class TnxSettingsUserFormsTest(BaseClientTestCase):
    def test_edit_user_settings(self):

        request = get_fake_request(
            user=FakeUser(),
            is_ajax=True,
            session={},
            build_absolute_uri=lambda *args: '/tionix',
            horizon={
                'async_messages': []
            }
        )

        form = forms.TnxUserSettingsForm(request)

        data = {'language': 'ru',
                'timezone': settings.TIME_ZONE,
                'pagesize': 20,
                'instance_log_length': 10}

        response = form.handle(request, data=data)

        self.assertListEqual(
            sorted(response.cookies.keys()),
            sorted(['django_timezone', 'django_language', 'horizon_pagesize',
                    'instance_log_length'])
        )

        self.assertDictEqual(
            request.session,
            {'_language': data['language'],
             'django_timezone': settings.TIME_ZONE,
             'django_language': data['language'],
             'horizon_pagesize': data['pagesize'],
             'instance_log_length': data['instance_log_length']}
        )
