# coding: utf-8

"""Balancing aggregates tables"""

from django.utils.translation import ugettext_lazy as _

from horizon import tables
from openstack_dashboard.dashboards.admin.aggregates.tables import (
    get_aggregate_hosts, safe_unordered_list)

ALLOW_BALANCING_STATUS = {
    True: _('Yes'),
    False: _('No'),
    None: _('N/A')
}


class HostAggregatesTable(tables.DataTable):
    """Host aggregates table"""
    name = tables.Column('name', verbose_name=_('Name'))
    availability_zone = tables.Column('availability_zone',
                                      verbose_name=_('Availability Zone'))
    hosts = tables.Column(get_aggregate_hosts,
                          verbose_name=_("Hosts"),
                          wrap_list=True,
                          filters=(safe_unordered_list,))
    allow_balancing = tables.Column(
        lambda x: ALLOW_BALANCING_STATUS.get(
            getattr(x, 'tnx_allow_balancing', None)
        ),
        verbose_name=_('Balancing')
    )

    class Meta(object):
        name = "host_aggregates"
        verbose_name = _("Host aggregates")
