# coding: utf-8
import logging

from django.utils.translation import ugettext_lazy as _

from horizon import tables

from openstack_dashboard import policy
from openstack_dashboard.dashboards.project.instances import (
    tables as project_tables)

from tionix_dashboard.dashboards.license import LicenseController
from tionix_dashboard.helpers.actions import TnxFilterAction

logger = logging.getLogger(__name__)


# noinspection PyAbstractClass
class TnxBalanceInstance(policy.PolicyTargetMixin, tables.LinkAction):
    name = "balance"
    verbose_name = _("Balance")
    classes = ("ajax-modal", "btn-migrate", "btn-danger")
    url = "horizon:tionix:balancing:balance"
    policy_rules = (
        ("compute", "compute_extension:admin_actions:migrateLive"),)

    def allowed(self, request, datum):
        return (
            LicenseController.is_valid(
                request, LicenseController.CLOUD_CONTROL) and
            (datum.status in project_tables.ACTIVE_STATES) and
            not project_tables.is_deleting(datum)
        )


# noinspection PyAbstractClass
class ComputeHostsFilterAction(TnxFilterAction):

    name = "filter_compute_hosts"
    filter_type = "server"

    filter_choices = (
        ('hostname', _("Hostname"), False),
        ('node_title', _("Node title"), False),
        ('hypervisor_type', _("Type"), False),
        ('host_aggregates', _("Host aggregates"), False),
        ('is_reserved', _("Reserved"), False)
    )
