# coding: utf-8

"""Balancing tabs"""
import logging

from django.utils.translation import ugettext_lazy as _

from horizon import exceptions, tabs

from openstack_dashboard import api

from tionix_dashboard.dashboards.tionix.balancing.compute import (
    tables as compute_tables)
from tionix_dashboard.dashboards.tionix.balancing.aggregates import (
    tables as aggregates_tables)
from tionix_dashboard.dashboards.tionix.balancing.zones import (
    tables as zones_tables)
from tionix_dashboard.helpers.views import (
    ServerFilterTabMixin)

logger = logging.getLogger(__name__)


# noinspection PyAbstractClass
class ComputeHostsTab(ServerFilterTabMixin, tabs.TableTab):
    """Tab for balancing compute hosts"""
    table_classes = (compute_tables.ComputeHostsTable,)
    name = _('Compute hosts')
    slug = 'compute_hosts_tab'
    template_name = 'horizon/common/_detail_table.html'
    preload = False

    def get_compute_hosts_data(self):
        return compute_tables.get_compute_hosts(self.request)


# noinspection PyAbstractClass
class HostAggregatesTab(tabs.TableTab):
    """Tab for balancing compute hosts"""
    table_classes = (aggregates_tables.HostAggregatesTable,)
    name = _('Host aggregates')
    slug = 'host_aggregates_tab'
    template_name = 'horizon/common/_detail_table.html'
    preload = False

    def get_host_aggregates_data(self):
        """Get host aggregates"""
        aggregates = []
        try:
            aggregates = api.nova.aggregate_details_list(self.request)
        except Exception as err:
            logger.error(unicode(err))
            msg = _('Unable to retrieve host aggregates list.')
            exceptions.handle(self.request, msg)

        return aggregates


# noinspection PyAbstractClass
class AvailabilityZonesTab(tabs.TableTab):
    table_classes = (zones_tables.AvailabilityZonesTable, )
    name = _("Availability Zones")
    slug = 'availability_zones_tab'
    template_name = 'horizon/common/_detail_table.html'
    preload = False

    def get_availability_zones_data(self):
        request = self.request
        availability_zones = []
        try:
            availability_zones = api.nova.availability_zone_list(
                self.request, detailed=True)
        except Exception as err:
            logger.error(unicode(err))
            exceptions.handle(request,
                              _('Unable to retrieve availability zone list.'))
        availability_zones.sort(key=lambda az: az.zoneName.lower())
        return availability_zones


# noinspection PyAbstractClass
class BalancingTabs(tabs.TabGroup):
    """Tab group for balancing"""
    slug = 'balancing_tab_group'
    tabs = (ComputeHostsTab, HostAggregatesTab, AvailabilityZonesTab)
    sticky = True
