# coding: utf-8

"""Balancing views"""

import logging

from django.utils.translation import ugettext_lazy as _
from django.core.urlresolvers import reverse_lazy

from horizon import exceptions, forms, tabs

from tionix_dashboard.clients.servers import TNXServersClient
from tionix_dashboard.dashboards.tionix.balancing import tabs as balancing_tabs
from tionix_dashboard.dashboards.tionix.balancing.forms import TnxBalanceForm
from tionix_dashboard.helpers.views import RefererRedirectMixin


logger = logging.getLogger(__name__)


class IndexView(tabs.TabbedTableView):
    """Balancing view"""
    tab_group_class = balancing_tabs.BalancingTabs
    template_name = 'balancing/index.html'
    page_title = _("Balancing")


class TnxBalanceView(RefererRedirectMixin, forms.ModalFormView):
    form_class = TnxBalanceForm
    template_name = 'balancing/compute/balance_action.html'
    context_object_name = 'instance'
    page_title = _("Balance")
    modal_header = _("Balance")
    submit_label = _("Balance")
    success_url = reverse_lazy("horizon:tionix:balancing:index")
    cancel_url = reverse_lazy("horizon:tionix:balancing:index")

    def get_initial(self):
        initial = super(TnxBalanceView, self).get_initial()

        instance_id = self.kwargs["instance_id"]
        initial["instance_id"] = instance_id

        try:
            instance = TNXServersClient.get(self.request, instance_id)
        except Exception as err:
            logger.error(err.message)
            msg = _("Unable to retrieve instance details.")
            exceptions.handle(self.request, msg)
        else:
            initial["instance_name"] = instance.name

        return initial

    def get_context_data(self, **kwargs):
        context = super(TnxBalanceView, self).get_context_data(**kwargs)

        instance_id = self.kwargs["instance_id"]
        try:
            instance = TNXServersClient.get(self.request, instance_id)
        except Exception as err:
            logger.error(err.message)
            msg = _("Unable to retrieve instance details.")
            exceptions.handle(self.request, msg)
        else:
            context["instance_id"] = instance_id
            context["instance_name"] = instance.name
        return context


class BalanceView(tabs.TabbedTableView):
    """Balancing view"""
    tab_group_class = balancing_tabs.BalancingTabs
    template_name = 'balancing/index.html'
    page_title = _("Balancing")
