(function(){
    'use strict';

    var module = angular.module('horizon.app');

    module.controller('DynamicTabController', ['$scope', '$element', '$window', function($scope, $element, $window){

        var tabGroup = $('#' + $window.tabGroupId),
            plusTab = tabGroup.find('li a.fa-plus');

        tabGroup.find('li a span.remove-tab').on('click', function(e){
            removeTab(e.target);
            return false;
        });

        var tabTemplate = Hogan.compile($('#new_tab_id').html());

        plusTab.on('click', function(e){
            var id = Math.floor(Math.random() * 10000),
                total = tabGroup.children().length;

            if (total >= 10) {
                horizon.alert('info', gettext('To many tabs!'));
                return;
            }

            $(this).closest('li').before(
                    '<li id="li_tab_"><a href="?' + $window.tabGroupParamName + '=frame_' + id + '" ' +
                    'data-toggle="tab" ' +'data-target="#tab_frame_' + id + '"' +
                    'class="dynamic_tab_link"><span>' + $window.newTabName + '</span>' +
                    '<span class="fa fa-remove remove-tab"></span></a></li>');

            var params = {id: id};
            $('.tab-content').append('<div id="tab_frame_' + id + '" class="tab-pane">' + tabTemplate.render(params));

            tabGroup.find('li:nth-child(' + total + ') a span.remove-tab').on('click', function(e) {
                removeTab(e.target);
                return false;
            });

            tabGroup.find('li:nth-child(' + total + ') a').click();

        });

        function removeTab(elem) {
            var modal, id, liElement, liTabId, data_target,
                title = gettext('Confirm delete'),
                body = gettext("Please confirm your selection. "),
                action = gettext('Delete');

            liElement = $(elem).parents('li').first();
            data_target = liElement.children('a').first().attr('data-target');
            liTabId = liElement.attr('id');

            if (liTabId) {
                id = liTabId.split('_').pop();
            }

            var tab = $(data_target),
                isActive = tab.hasClass('active');

            modal = horizon.modals.create(title, body, action);
            modal.modal();

            modal.find('.btn-primary').click(function (evt) {
                var success = true;
                if ($.isNumeric(id) && $window.deleteTabUrl) {
                    $.ajax({
                        method: 'POST',
                        url: $window.deleteTabUrl,
                        headers: {
                            'X-CSRFToken': $window.csrfToken
                        },
                        data: {id: id},
                        beforeSend: function () {
                            horizon.modals.modal_spinner(gettext("Working"));
                        },
                        complete: function() {
                            horizon.modals.spinner.modal('hide');
                        },
                        success: function(data, textStatus, jqXHR) {
                            deleteTabElement(liElement, tab, isActive);
                        },
                        error: function(jqXHR, status, errorThrown) {
                            success = false;
                        }
                    });

                } else {
                    deleteTabElement(liElement, tab, isActive);
                }
                if (success) {
                    horizon.alert('success', gettext('Frame deleted!'));
                } else {
                    horizon.alert('error', gettext('There was a problem to delete frame, please try again later!'));
                }
                modal.modal('hide');
            });
        }

        function deleteTabElement(elem, tab, isActive) {
            tab.remove();
            if (isActive) {
                var prev = elem.prev();
                if (prev.length){
                    prev.children('a').first().click();
                } else{
                    elem.next().children('a[data-target]').first().click();
                }
            }
            elem.remove();
        }
    }]);
})();