# coding: utf-8
from django.core.context_processors import csrf
from django.core.urlresolvers import reverse_lazy
from django.utils.datastructures import SortedDict
from django.utils.translation import ugettext_lazy as _

from horizon import tabs
from tionix_dashboard.dashboards.tionix.frames.forms import FrameForm

from tionix_dashboard.helpers.tabs import DynamicTabGroup
from tionix_dashboard.dashboards.tionix.frames.api import get_frames_by_user_id


class FrameTab(tabs.Tab):
    name = _("New frame")
    slug = "new_frame"
    template_name = "frames/_details.html"
    frame = None

    def __init__(self, tab_group, request=None, frame=None):
        super(FrameTab, self).__init__(tab_group, request)

        self.frame = frame

    def get_context_data(self, request, **kwargs):
        context = super(FrameTab, self).get_context_data(request, **kwargs)
        context['frame_save_url'] = reverse_lazy('horizon:tionix:frames:save')
        if self.frame is not None:
            context['frame'] = self.frame
        context['form'] = FrameForm(instance=self.frame)
        context.update(csrf(request))
        return context


class FramesTabs(DynamicTabGroup):
    slug = "frames_tab"
    tabs = tuple()
    sticky = True
    tab_class = FrameTab
    delete_url = reverse_lazy('horizon:tionix:frames:delete')

    def __init__(self, request, **kwargs):
        super(FramesTabs, self).__init__(request, **kwargs)

        tab_instances = []
        for frame in get_frames_by_user_id(request.user.id):
            tab = self.tab_class(self, request, frame)
            tab.slug = 'frame_{0}'.format(frame.id)
            tab_instances.append((tab.slug, tab))

        self._tabs = SortedDict(tab_instances)

