# coding: utf-8
# pylint: disable=no-member

import json

from django.core.urlresolvers import reverse

from openstack_dashboard.test import helpers as test

from tionix_dashboard.dashboards.tionix.frames.models import Frame
from tionix_dashboard.dashboards.tionix.frames.tabs import FramesTabs


FRAMES_SAVE_URL = reverse('horizon:tionix:frames:save')

FRAMES_DELETE_URL = reverse('horizon:tionix:frames:delete')


class FramesTest(test.TestCase):

    test_data = []

    def setUp(self):
        super(FramesTest, self).setUp()

        self.test_data = [
            {'user_id': self.request.user.id,
             'name': u'Name 1',
             'url': u'http://localhost'},
            {'user_id': self.request.user.id,
             'name': u'Name 2',
             'url': u'http://localhost'},
            {'user_id': self.request.user.id,
             'name': u'Name 2',
             'url': u''}
        ]

    def test_frames_tab_group(self):

        data = self.test_data[:2]

        _new_frames = [Frame.objects.create(**d) for d in data]

        tab_group = FramesTabs(self.request)

        self.assertEqual(len(tab_group.get_tabs()), len(data))

    def test_save_frame_view(self):

        data = self.test_data[0]

        res = self.client.post(FRAMES_SAVE_URL, data)

        self.assertEqual(res.status_code, 200)

        content = json.loads(res.content)

        self.assertEqual(content['result'], True)

        data = self.test_data[2]

        res = self.client.post(FRAMES_SAVE_URL, data)

        self.assertEqual(res.status_code, 200)

        self.assertContains(res, "* url\\n  * This field is required.")

    def test_delete_frame_view(self):

        obj = Frame.objects.create(**self.test_data[0])

        self.client.post(FRAMES_DELETE_URL, {'id': obj.id})

        self.assertEqual(Frame.objects.filter(id=obj.id).count(), 0)
