# coding: utf-8

import logging

from django.core.urlresolvers import reverse
from django.utils.translation import ugettext_lazy as _

from horizon import exceptions, forms
from novaclient.exceptions import Conflict

from tionix_dashboard.clients.host_classes import TNXHostClassesClient
from tionix_dashboard.dashboards.tionix.infrastructure import constants

logger = logging.getLogger(__name__)


# noinspection PyAbstractClass
class CreateHostClassTypeForm(forms.SelfHandlingForm):
    name = forms.CharField(label=_("Name"), required=False, max_length=50)

    def handle(self, request, data):
        result = True
        try:
            TNXHostClassesClient.create_host_type(
                request, self.initial['host_class_id'], **data)
        except Conflict as err:
            logger.error(unicode(err))
            result = False
            name = data.get('name', '')
            exceptions.handle(
                request,
                _('Host type with name "{0}" already exists.').format(name))
        except Exception as err:
            logger.error(unicode(err))
            result = False
            exceptions.handle(
                request,
                _('Unable to create host type.'),
                redirect=reverse(constants.INFRASTRUCTURE_HOST_CLASS_DETAIL,
                                 args=(self.initial['host_class_id'],))
            )
        return result


# noinspection PyAbstractClass
class UpdateHostClassTypeForm(CreateHostClassTypeForm):

    def handle(self, request, data):
        result = True
        try:
            TNXHostClassesClient.update_host_type(
                request,
                self.initial['host_class_id'],
                self.initial['host_type_id'],
                **data)
        except Conflict as err:
            logger.error(unicode(err))
            result = False
            name = data.get('name', '')
            exceptions.handle(
                request,
                _('Host type with name "{0}" already exists.').format(name))
        except Exception as err:
            logger.error(unicode(err))
            result = False
            exceptions.handle(
                request,
                _('Unable to update host type.'),
                redirect=reverse(constants.INFRASTRUCTURE_HOST_CLASS_DETAIL,
                                 args=(self.initial['host_class_id'],))
            )
        return result


# noinspection PyAbstractClass
class CreateHostClassForm(forms.SelfHandlingForm):
    name = forms.CharField(label=_("Class Name"), max_length=25)

    # noinspection PyMethodMayBeStatic
    def handle(self, request, data):
        result = True
        try:
            TNXHostClassesClient.create(request, **data)
        except Conflict as err:
            logger.error(unicode(err))
            result = False
            name = data.get('name', '')
            exceptions.handle(
                request,
                _('Host class with name "{0}" already exists.').format(name))
        except Exception as err:
            logger.error(unicode(err))
            result = False
            exceptions.handle(request, _('Unable to create host class.'))
        return result


# noinspection PyAbstractClass
class UpdateHostClassForm(CreateHostClassForm):

    def handle(self, request, data):
        result = True
        try:
            TNXHostClassesClient.update(request, self.initial['host_class_id'],
                                        **data)
        except Conflict as err:
            logger.error(unicode(err))
            result = False
            name = data.get('name', '')
            exceptions.handle(
                request,
                _('Host class with name "{0}" already exists.').format(name))
        except Exception as err:
            logger.error(unicode(err))
            result = False
            exceptions.handle(request, _('Unable to update host class.'))
        return result
