# coding: utf-8

from django.template import defaultfilters as filters
from django.utils.translation import ugettext_lazy as _

from horizon import tables

from tionix_dashboard.dashboards.tionix.infrastructure.constants import (
    INFRASTRUCTURE_HOST_CLASS_DETAIL)
from tionix_dashboard.dashboards.tionix.infrastructure.host_classes import (
    actions)
from tionix_dashboard.helpers.fields import EmptyCharField
from tionix_dashboard.templatetags.tionix_tags import (
    empty_string_to_nbsp_in_list)


def get_host_types(host_class):
    return (sorted([host_type.name for host_type in host_class.host_types]) or
            None)


class HostClassesTable(tables.DataTable):
    host_class_id = tables.Column("id", verbose_name=_("ID"))
    name = tables.Column("name",
                         verbose_name=_("Class name"),
                         link=INFRASTRUCTURE_HOST_CLASS_DETAIL,
                         form_field=EmptyCharField(max_length=25),
                         update_action=actions.HostClassUpdateCell)
    host_types = tables.Column(
        get_host_types,
        verbose_name=_("Types"),
        wrap_list=True,
        filters=(empty_string_to_nbsp_in_list, filters.unordered_list,)
    )

    class Meta(object):
        name = 'host_classes'
        verbose_name = _('Classes and types')
        table_actions = (actions.HostClassesFilterAction,
                         actions.CreateHostClassAction,
                         actions.DeleteHostClassAction)
        row_actions = (actions.EditHostClassAction,
                       actions.DeleteHostClassAction)
        row_class = actions.HostClassUpdateRow


class HostClassTypesTable(tables.DataTable):
    host_type_id = tables.Column("id", verbose_name=_("ID"))
    name = tables.Column("name",
                         verbose_name=_("Type name"),
                         form_field=EmptyCharField(max_length=50),
                         update_action=actions.HostTypeUpdateCell)

    class Meta(object):
        name = 'host_class_types'
        verbose_name = _('Host class types')
        row_class = actions.HostTypeUpdateRow
        table_actions = (actions.HostClassTypesFilterAction,
                         actions.CreateHostTypeAction)
        table_actions_menu = (actions.DeleteHostTypeAction,)
        row_actions = (actions.EditHostTypeAction,
                       actions.DeleteHostTypeAction)
