# coding: utf-8

import logging

from django.core.exceptions import ValidationError
from django.utils.translation import ugettext_lazy as _

from horizon import forms
from tionix_dashboard.clients import TNXHypervisorsClient

logger = logging.getLogger(__name__)


class IPAddressObject(object):
    def __init__(self, object_id, name):
        super(IPAddressObject, self).__init__()
        self.id = object_id
        self.name = name


# noinspection PyAbstractClass
class CreateIPAddressForm(forms.SelfHandlingForm):
    name = forms.IPField(label=_("Host IP"), version=forms.IPv4)

    def get_host_ips(self, host_id):
        host_ips = []
        try:
            host = TNXHypervisorsClient.get(self.request, host_id)
        except Exception as err:
            logger.error(unicode(err))
        else:
            host_ips = [addr['ip_address']
                        for addr in getattr(host, 'tnx_ip_addresses', [])]
        return host_ips

    def clean_name(self):
        ip = self.cleaned_data['name']
        host_id = self.request.GET.get('host_id')
        ip_addresses = self.request.session.get('temp_available_ips', [])
        if host_id:
            ip_addresses.extend(self.get_host_ips(host_id))
        if ip in ip_addresses:
            raise ValidationError(_('IP is already exists.'))
        return ip

    @staticmethod
    def handle(request, data):
        new_ip_object = IPAddressObject(data['name'], data['name'])
        temp_ip_addresses = request.session.get('temp_available_ips', [])
        temp_ip_addresses.append(data['name'])
        request.session['temp_available_ips'] = temp_ip_addresses
        return new_ip_object
