/**
 * Created by user on 04.08.17.
 */
(function () {
  'use strict';

  /**
   * @ngdoc controller
   * @name HostsIPAddressesController
   * @description
   * The `HostsIPAddressesController` controller to manage project's image
   */
  angular.module('horizon.tionix.infrastructure.hosts')
    .controller('HostsIPAddressesController', HostsIPAddressesController);

  HostsIPAddressesController.$inject = [
    '$scope',
    '$element'
  ];

  function HostsIPAddressesController($scope, $element) {

    var ctrl = this,
      available = [],
      allocated = [];

    ctrl.isLoaded = false;
    ctrl.$element = $element;
    ctrl.tabId = $element.closest('fieldset').attr("id");
    ctrl.$form = $element.closest('form');
    ctrl.$fieldAllocated = ctrl.$form.find('#id_tnx_ip_addresses');
    ctrl.$fieldAvailable = ctrl.$form.find('#id_available_ips');

    ctrl.$fieldAllocated.closest('.form-group').hide();
    ctrl.$fieldAvailable.closest('.form-group').hide();

    ctrl.tableLimits = {
      maxAllocation: -1
    };

    ctrl.tableHelp = {
      availHelpText: gettext('Select one or more'),
      allocTitle: gettext('Linked IP addresses')
    };

    $('a[data-toggle="tab"]').on("show.bs.tab", function(event) {
      var $a = $(event.target);
      if (getTabId($a) === ctrl.tabId) {
        load();
      }
    });

    ctrl.$form.submit(function() {
      var ids = allocated.map(function (i) {return i.id;});
      if (allocated.length) {
        ids.forEach(function(id) {
          if (!ctrl.$fieldAllocated.find("option[value='" + id + "']").length) {
            ctrl.$fieldAllocated.append("<option value='" + id + "'></option>");
            ctrl.$fieldAllocated.change();
          }
        });
        ctrl.$fieldAllocated.val(ids);
      }
    });

    ctrl.columns = [
      {attrName: "host_ip", headerName: gettext("Host IP")}
    ];

    ctrl.model = {
      available: available,
      allocated: allocated
    };

    function load() {
      if (!ctrl.isLoaded){
         allocated.length = 0;
         ctrl.$fieldAllocated.find('option').each(function(index, option){
           allocated.push({"host_ip": option.text, "id": option.value});
         });
         ctrl.isLoaded = true;
      }

      available.length = 0;

      ctrl.$fieldAvailable.find('option').each(function(index, option){
        available.push({"host_ip": option.text, "id": option.value});
      });

      $scope.$apply();

    }

    function getTabId($a) {
      return $a.attr('data-target').slice(1);
    }

    ctrl.$fieldAvailable.on('change', function(){
      load();
    });

  }
})();