# coding: utf-8

import logging

from django.utils.translation import ugettext_lazy as _

from horizon import exceptions, tabs
from tionix_dashboard.clients import TNXHypervisorsClient
from tionix_dashboard.clients.host_classes import TNXHostClassesClient

from tionix_dashboard.dashboards.tionix.infrastructure.hosts import (
    tables as hosts_tables)
from tionix_dashboard.dashboards.tionix.infrastructure.host_classes import (
    tables as host_classes_tables)
from tionix_dashboard.helpers.views import (
    ServerFilterTabMixin, DTVTnxPaginationMixin)

logger = logging.getLogger(__name__)


# noinspection PyAbstractClass
class HostsTab(ServerFilterTabMixin, DTVTnxPaginationMixin, tabs.TableTab):
    """Tab for hosts"""
    table_classes = (hosts_tables.HostsTable,)
    name = _('Hosts')
    slug = 'hosts_tab'
    template_name = 'horizon/common/_detail_table.html'
    preload = False

    def get_hosts_data(self):

        hypervisors = []
        offset, limit = self.get_offset_limit()
        filters = {'only_compute_nodes': False}
        try:
            self.table.total_count = TNXHypervisorsClient.count(
                self.request, **filters
            )
            hypervisors = TNXHypervisorsClient.list(
                self.request, offset=offset, limit=limit + 1, **filters)
        except Exception as err:
            logger.error(unicode(err))
            exceptions.handle(self.request,
                              _('Unable to retrieve hosts list.'))
        else:
            total = len(hypervisors)
            if offset == 0:
                self._prev = False
            if total <= limit:
                self._more = False
            else:
                hypervisors.pop()

            self.table.first_marker, self.table.last_marker = (
                0, self.calc_last_marker(self.table.total_count, limit)
            )

        return hypervisors


# noinspection PyAbstractClass
class HostClassesTab(ServerFilterTabMixin, tabs.TableTab):
    """Tab for classes and types"""
    table_classes = (host_classes_tables.HostClassesTable,)
    name = _('Classes and types')
    slug = 'host_classes_tab'
    template_name = 'horizon/common/_detail_table.html'
    preload = False

    def get_host_classes_data(self):
        host_classes = []
        try:
            host_classes = TNXHostClassesClient.list(self.request)
        except Exception as err:
            logger.error(unicode(err))
            exceptions.handle(self.request,
                              _('Unable to retrieve host classes list.'))
        return host_classes


# noinspection PyAbstractClass
class InfrastructureTabs(tabs.TabGroup):
    """Tab group for infrastructure"""
    slug = 'infrastructure_group'
    tabs = (HostsTab, HostClassesTab)
    sticky = True
