# coding: utf-8

from django.utils.translation import ugettext_lazy as _

from horizon import tables

from tionix_dashboard.dashboards.tionix.licenses import actions
from tionix_dashboard.templatetags.tionix_tags import (
    valid, format_date, filter_version)


class LicensesTable(tables.DataTable):

    STATUS_CLASSES = {
        True: 'green_color',
        False: 'red_color',
        None: ''
    }

    VERSION_CLASSES = {
        True: 'outdated',
        False: 'actual',
        None: 'unchecked',
    }

    name = tables.Column('surrogate_name', verbose_name=_('Extension'))
    version = tables.Column('version',
                            verbose_name=_('Version'),
                            filters=(filter_version, ),
                            classes=('module_version', ))
    license = tables.Column('lic_id', verbose_name=_('License'))
    created_at = tables.Column('created_at',
                               verbose_name=_('Valid from'),
                               filters=(format_date, ))
    expire_at = tables.Column('expire_at',
                              verbose_name=_('Valid till'),
                              filters=(format_date, ))
    status = tables.Column('verified',
                           verbose_name=_('License status'),
                           filters=(valid, ))

    outdated = tables.Column('outdated', hidden=True)

    class Meta(object):
        name = 'licenses'
        verbose_name = _('Licenses')
        status_columns = ['status', 'outdated']
        multi_select = False
        table_actions = (actions.RunSelfDiagnosticAction,
                         actions.DownloadSelfDiagnosticAction)
        template = 'licenses/_licenses_table.html'

    def calculate_row_status(self, statuses):
        return statuses

    def get_row_status_class(self, statuses):
        classes = []
        if 'status' in statuses:
            classes.append(self.STATUS_CLASSES.get(statuses['status'], ''))
        if 'outdated' in statuses:
            classes.append(self.VERSION_CLASSES.get(statuses['outdated'], ''))
        return ' '.join(classes)
