# coding: utf-8

import mock

from django.core.urlresolvers import reverse

from tionix_client.helpers import PACKAGES
from tionix_client.helpers.packages_info import get_tionix_modules_info

from tionix_dashboard.clients.base import novaclient
from tionix_dashboard.dashboards.tionix.licenses import tables, views
from tionix_dashboard.dashboards.tionix.licenses.api import SelfDiagnostic
from tionix_dashboard.tests.helpers import BaseClientTestCase

INDEX_URL = reverse('horizon:tionix:licenses:index')
DOWNLOAD_URL = reverse('horizon:tionix:licenses:download_self_diagnostic')


class TionixLicensesTablesTest(BaseClientTestCase):

    def test_licenses_table(self):

        table = tables.LicensesTable(self.request)

        self.assertListEqual(
            sorted(table.columns.keys()),
            sorted(['created_at', 'expire_at', 'license', 'name', 'outdated',
                    'status', 'version'])
        )

    def test_licenses_table_actions(self):

        table = tables.LicensesTable(self.request, data=[])

        self.assertListEqual(
            sorted([action.name for action in table.get_table_actions()]),
            sorted(['run_self_diagnostic', 'download_self_diagnostic'])
        )


@mock.patch('tionix_client.helpers.updates.get_actual_versions',
            mock.Mock(return_value={}))
class TionixLicensesViewsTest(BaseClientTestCase):

    # noinspection PyUnusedLocal
    def test_licenses_index_view(self):

        view = views.LicensesIndexView()
        view.request = self.request

        data = view.get_data()
        nova_client = novaclient(self.request)
        modules = get_tionix_modules_info(
            nova_client,
            exclude_modules=[PACKAGES.TIONIX_VDIClient])

        self.assertEqual(len(data), len(modules))

        _asserts = [self.assertListEqual(
            sorted(d.__dict__.keys()),
            sorted(['verified', 'created_at', 'lic_id', 'version', 'pip_name',
                    'outdated', 'actual_version', 'surrogate_name', 'id',
                    'expire_at'])
        ) for d in data]

    @mock.patch.object(SelfDiagnostic, 'report')
    def test_downloads_self_diagnostic_report(self, report):

        data = 'test data'

        report.return_value = data

        response = self.client.get(DOWNLOAD_URL)

        self.assertContains(response, data)

    @mock.patch.object(SelfDiagnostic,
                       'report',
                       mock.Mock(return_value=None))
    def test_downloads_self_diagnostic_report_error(self):

        response = self.client.get(DOWNLOAD_URL)

        self.assertRedirectsNoFollow(response, INDEX_URL)
