# coding: utf-8

import logging

from django.utils.translation import ugettext_lazy as _
from django.core.exceptions import ValidationError

from horizon import messages
from horizon.utils.memoized import memoized

from openstack_dashboard import api

from tionix_dashboard.clients.backup_systems import TNXBackupSystemsClient


logger = logging.getLogger(__name__)


@memoized
def get_bareos_system_params(request):
    domain = api.keystone.get_default_domain(request)
    domain_id = domain.get('id')
    try:
        backup_systems = TNXBackupSystemsClient.list(request,
                                                     domain_id=domain_id)
        if not backup_systems:
            msg = _('Backup system is not specified for '
                    'the domain \'{0}\'.').format(domain.get('name'))
            messages.info(request, msg)
            raise ValidationError(msg)
        params = TNXBackupSystemsClient.get_system_params(
            request, domain_id, backup_systems[0].backup_system
        )
    except ValidationError:
        raise
    except Exception as err:
        logger.error(unicode(err))
        msg = _('Unable to connect to Bareos server. Please contact your '
                'system administrator.')
        messages.error(request, msg)
        raise ValueError(msg)

    return params


def get_bareos_jobdefs(request):
    return get_bareos_system_params(request).get('job_defs', [])


def get_bareos_filesets(request):
    return get_bareos_system_params(request).get('file_set', [])


def get_bareos_schedules(request):
    return get_bareos_system_params(request).get('schedule', [])
