# coding: utf-8

from django.utils.translation import ugettext_lazy as _, pgettext_lazy

from horizon import tables

from tionix_dashboard.dashboards.tionix.metrics.bareos_templates import actions
from tionix_dashboard.dashboards.tionix.metrics.enums import LevelTypes
from tionix_dashboard.helpers.tables import ServerFilterTabTableMixin


class BareosTemplatesTable(ServerFilterTabTableMixin, tables.DataTable):
    name = tables.Column(
        'name',
        verbose_name=_('Name')
    )
    description = tables.Column(
        'description',
        verbose_name=_('Description')
    )
    level = tables.Column(
        lambda x: str(x.level),
        verbose_name=_('Level'),
        display_choices=LevelTypes.get_choices()
    )
    job_defs = tables.Column(
        'job_defs',
        verbose_name=_('JobDefs')
    )
    file_set = tables.Column(
        'file_set',
        verbose_name=_('FileSet')
    )
    schedule = tables.Column(
        'schedule',
        verbose_name=pgettext_lazy("Bareos templates", u"Schedule")
    )

    class Meta(object):
        name = "bareos_templates"
        verbose_name = _("Bareos Templates")
        table_actions = (actions.TnxMetricsBareosTemplatesFilterAction,
                         actions.CreateBareosTemplateAction,
                         actions.DeleteBareosTemplateAction)
        row_actions = (actions.DeleteBareosTemplateAction,
                       actions.UnassignInstancesAction)
        no_data_message = _('No items to display.')
