# coding: utf-8
# pylint: disable=no-member

from openstack_dashboard.test import helpers as test

from tionix_tests.helpers import Empty

from tionix_dashboard.dashboards.tionix.metrics.bareos_templates import (
    actions, tables)
from tionix_dashboard.tests.helpers import BaseClientTestCase


class TionixBareosTemplatesActionsTest(test.TestCase):

    def test_bareos_templates_filter(self):

        filter_action = actions.TnxMetricsBareosTemplatesFilterAction()

        self.assertListEqual(
            sorted(zip(*filter_action.filter_choices)[0]),
            sorted(['name', 'description', 'job_defs', 'file_set', 'level',
                    'schedule'])
        )


class TionixBareosTemplatesTablesTest(BaseClientTestCase):

    def test_bareos_templates_table(self):

        table = tables.BareosTemplatesTable(self.request)

        self.assertListEqual(
            sorted(table.columns.keys()),
            sorted(['multi_select', 'name', 'description', 'job_defs',
                    'file_set', 'level', 'schedule', 'actions'])
        )

    def test_bareos_templates_table_actions(self):
        table = tables.BareosTemplatesTable(self.request,
                                            data=[Empty()])

        self.assertListEqual(
            sorted([action.name for action in table.get_table_actions()]),
            sorted(['create', 'filter', 'delete'])
        )

    def test_bareos_templates_table_row_actions(self):
        table = tables.BareosTemplatesTable(self.request)

        template = Empty(assigned_servers=[])

        self.assertListEqual(
            [action.name for action in table.get_row_actions(template)],
            ['delete']
        )

        template = Empty(assigned_servers=[Empty()])

        self.assertListEqual(
            [action.name for action in table.get_row_actions(template)],
            ['delete', 'unassign']
        )
