# coding: utf-8

from collections import OrderedDict

from django.utils.translation import ugettext_lazy as _

from tionix_dashboard.helpers.base import BaseEnumerate


class MetricsTypes(BaseEnumerate):
    """
    Enumerate metrics types.
    """
    INSTANCE = 1

    values = OrderedDict([
        (INSTANCE, _('Instance')),
    ])


class MetricsEnum(BaseEnumerate):
    MEMORY_USAGE = 'memory.usage'
    CPU_UTIL = 'cpu_util'
    DISK_READ_REQUESTS_RATE = 'disk.read.requests.rate'
    DISK_WRITE_REQUESTS_RATE = 'disk.write.requests.rate'
    DISK_READ_BYTES_RATE = 'disk.read.bytes.rate'
    DISK_WRITE_BYTES_RATE = 'disk.write.bytes.rate'
    DISK_LATENCY = 'disk.latency'
    DISK_IOPS = 'disk.iops'
    NETWORK_INCOMING_BYTES_RATE = 'network.incoming.bytes.rate'
    NETWORK_OUTGOING_BYTES_RATE = 'network.outgoing.bytes.rate'
    NETWORK_INCOMING_PACKETS_RATE = 'network.incoming.packets.rate'
    NETWORK_OUTGOING_PACKETS_RATE = 'network.outgoing.packets.rate'

    values = {
        MEMORY_USAGE: _('MEM utilization, %'),
        CPU_UTIL: _('CPU utilization, %'),
        DISK_READ_REQUESTS_RATE: _('Rate of read requests, request/s'),
        DISK_WRITE_REQUESTS_RATE: _('Rate of write requests, request/s'),
        DISK_READ_BYTES_RATE: _('Rate of reads, B/s'),
        DISK_WRITE_BYTES_RATE: _('Rate of writes, B/s'),
        DISK_LATENCY: _('Disk latency, ms'),
        DISK_IOPS: _('Disk IOPS, count/s'),
        NETWORK_INCOMING_BYTES_RATE: _('Rate of incoming bytes, B/s'),
        NETWORK_OUTGOING_BYTES_RATE: _('Rate of outgoing bytes, B/s'),
        NETWORK_INCOMING_PACKETS_RATE: _('Rate of incoming packets, packet/s'),
        NETWORK_OUTGOING_PACKETS_RATE: _('Rate of outcoming packets, '
                                         'packet/s'),
    }


class LevelTypes(BaseEnumerate):
    """
    Enumerate bareos template's level types.
    """
    INCREMENTAL = '0'
    DIFFERENTIAL = '1'
    FULL = '2'

    values = OrderedDict([
        (INCREMENTAL, _('Incremental')),
        (DIFFERENTIAL, _('Differential')),
        (FULL, _('Full'))
    ])
