# coding: utf-8
from django.core.urlresolvers import reverse
from django.utils.translation import ugettext_lazy as _

from horizon import tables

from openstack_dashboard import api

from tionix_dashboard.dashboards.license import LicenseController
from tionix_dashboard.dashboards.project.project_instances import (
    actions as project_actions)
from tionix_dashboard.dashboards.tionix.metrics.api import (
    is_ceilometer_available, is_zabbix_available, is_bareos_available)
from tionix_dashboard.dashboards.tionix.metrics.constants import (
    METRICS_INSTANCE_SHOW, METRICS_INSTANCE_SETTINGS,
    METRICS_INSTANCE_MANAGE_TEMPLATE)
from tionix_dashboard.dashboards.utils import TABLE_OBJECT_ID_SEP
from tionix_dashboard.helpers.actions import LinkBatchAction


# noinspection PyAbstractClass,PyClassHasNoInit
class MetricsInstanceFilterAction(project_actions.TnxInstancesFilterAction):
    name = "filter_metrics_instances"
    filter_type = "server"
    filter_choices = (('tenant', _("Project"), False),
                      ('name', _("Name"), True),
                      ('host', _("Host ="), True),
                      ('tnx_node_title', _("Host title"), False),
                      ('tnx_type', _("Type"), True),
                      ('ip', _("IPv4 Address ="), True),
                      ('ip6', _("IPv6 Address ="), True),
                      ('task', _("Task"), False),
                      ('status', _("Status ="), True),
                      ('power_state', _("Power state"), True),)


# noinspection PyAbstractClass
class InstanceShowMetricAction(tables.LinkAction):
    name = 'show_instance_metrics'
    verbose_name = _('Show metrics')
    url = METRICS_INSTANCE_SHOW

    def allowed(self, request, datum):
        return (
            LicenseController.is_valid(request, LicenseController.MONITOR) and
            is_ceilometer_available(request)
        )


# noinspection PyAbstractClass
class MetricsInstanceShowMetricAction(InstanceShowMetricAction):
    def get_link_url(self, datum=None):
        project_id, instance_id = ((datum.tenant_id, datum.id)
                                   if datum else ('', ''))
        return reverse(self.url,
                       args=(TABLE_OBJECT_ID_SEP.join([project_id,
                                                       instance_id]),))


# noinspection PyAbstractClass
class MetricsInstanceSettingsAction(tables.LinkAction):
    name = 'settings_instance_metrics'
    verbose_name = _('Settings')
    classes = ("ajax-modal", )
    url = METRICS_INSTANCE_SETTINGS

    def allowed(self, request, datum):
        return is_ceilometer_available(
            request) and api.keystone.is_domain_admin(request)


# noinspection PyAbstractClass,PyUnusedLocal
class MetricsManageTemplatesAction(LinkBatchAction):
    """Manage template multi action"""
    name = 'manage_template'
    multiple_next_view_name = METRICS_INSTANCE_MANAGE_TEMPLATE

    def action_present(self, count):
        return _('Manage templates')

    def allowed(self, request, datum):
        return is_zabbix_available(request) or is_bareos_available(request)
