# coding: utf-8
from django.core.urlresolvers import reverse
from django.utils import http
from django.utils.translation import ugettext_lazy as _

from horizon import tables

from openstack_dashboard import api

from tionix_dashboard.dashboards.admin.instances import tables as admin_tables
from tionix_dashboard.dashboards.tionix.metrics.instances import actions
from tionix_dashboard.dashboards.utils import TABLE_OBJECT_ID_SEP
from tionix_dashboard.url_resolve_map import (
    ADMIN_SERVERS_DETAIL, PROJECT_SERVERS_DETAIL)


class MetricsInstancesTable(admin_tables.TnxAdminInstancesTable):

    name = tables.Column(
        "name",
        link="horizon:admin:instances:detail",
        verbose_name=_("Name")
    )
    node_title = tables.Column("tnx_node_title",
                               verbose_name=_("Host title"))

    # pylint: disable=no-member
    # noinspection PyProtectedMember
    def __init__(self, request, data=None, needs_form_wrapper=None, **kwargs):
        super(MetricsInstancesTable, self).__init__(
            request, data=data, needs_form_wrapper=needs_form_wrapper, **kwargs
        )

        self.is_domain_admin = api.keystone.is_domain_admin(request)

        self.columns['name'].get_link_url = self.get_instance_detail_link

        # Host and node title columns and filters are visible only for admin
        if not self.is_domain_admin:
            self.server_pagination = True
            self.columns.pop('host')
            self.columns.pop('node_title')
            self.columns['tenant'].link = None

            self._meta._filter_action.filter_choices = (
                (actions.MetricsInstanceFilterAction.filter_choices[:2] +
                 actions.MetricsInstanceFilterAction.filter_choices[3:])
            )
        else:
            self.server_pagination = False
            self._meta._filter_action.filter_choices = (
                actions.MetricsInstanceFilterAction.filter_choices[:]
            )

    def get_full_url(self):
        return self.request.get_full_path().split('?')[0]

    def get_instance_detail_link(self, instance):
        link = None
        if self.is_domain_admin:
            link = reverse(ADMIN_SERVERS_DETAIL, args=(instance.id,))
        elif self.request.user.project_id == instance.tenant_id:
            link = reverse(PROJECT_SERVERS_DETAIL, args=(instance.id,))
        return link

    def get_object_id(self, datum):
        return ''.join([datum.tenant_id, TABLE_OBJECT_ID_SEP, datum.id])

    def get_marker(self):
        """Returns the identifier for the last object in the current data set
                for APIs that use marker/limit-based paging."""
        if self.server_pagination:
            return http.urlquote_plus(self.data[-1].id) if self.data else ''

        return super(MetricsInstancesTable, self).get_marker()

    def get_prev_marker(self):
        """Returns the identifier for the first object in the current data set
        for APIs that use marker/limit-based paging.
        """
        if self.server_pagination:
            return http.urlquote_plus(self.data[0].id) if self.data else ''

        return super(MetricsInstancesTable, self).get_prev_marker()

    class Meta(object):
        name = 'instances_metrics'
        verbose_name = _('Instance')
        table_actions = (actions.MetricsInstanceFilterAction,
                         actions.MetricsInstanceSettingsAction,
                         actions.MetricsManageTemplatesAction)
        row_actions = (actions.MetricsInstanceShowMetricAction,
                       actions.MetricsManageTemplatesAction)
        no_data_message = _('No items to display.')
