(function(){
    'use strict';

    var chartsData;

    angular.module('tionix.metrics.instances')
      .controller('InstanceMetricsController', InstanceMetricsController)
      .directive('lineChart', lineChart);

    InstanceMetricsController.$inject = ['$scope', '$window'];

    function InstanceMetricsController($scope, $window) {
        chartsData = $window.metricsData;

        $scope.metrics = chartsData;
        $scope.dataIsEmpty = (!angular.isObject(chartsData) ||
            angular.equals({}, chartsData));
    }

    lineChart.$inject = ['$compile', 'tionix.metrics.instances.basePath'];

    function lineChart($compile, basePath) {
        var chartOptions = {
            animation: false,
            maintainAspectRatio: false,
            responsive: true,
            spanGaps: false,
            scales: {
                xAxes: [{
                    stacked: true,
                    gridLines: {
                        color: '#aaa',
                        drawOnChartArea: false,
                        drawTicks: false
                    },
                    position: "bottom",
                    ticks: {
                        fontSize: 11,
                        autoSkipPadding: 15,
                        callback: function(value){
                            return Array.isArray(value) ? value : value + '  ';
                        }
                    }
                }],
                yAxes: [{
                    gridLines: {
                        color: '#aaa',
                        drawOnChartArea: false
                    },
                    ticks: {
                        fontSize: 11,
                        beginAtZero:true
                    }
                }]
            },
            elements: {
                point: {
                    radius: 1.5,
                    hoverRadius: 2,
                    hitRadius: 0.5
                },
                line: {
                    tension: 0
                }
            },
            tooltips: {
                mode: 'label'
            },
            legend: {
                position: 'bottom',
                onClick: angular.noop
            },
            legendCallback: function(chart) {
                var text = [];
                text.push('<ul class="chart-line-legend">');
                for (var i = 0; i < chart.data.datasets.length; i++) {
                    text.push('<li><span style="background-color:' +
                            chart.data.datasets[i].backgroundColor + '"></span>');
                    if (chart.data.datasets[i].label) {
                        text.push(chart.data.datasets[i].label);
                    }
                    text.push('</li>');
                }
                text.push('</ul>');

                return text.join("");
            },
            onClick: function(event) {
                var parentElement = event.target.parentElement.parentElement;

                if (parentElement.getAttribute('id') == 'chartId') {
                    return false;
                }

                var cloneElement = parentElement.cloneNode(false);
                var chartLabelElems = parentElement.getElementsByClassName("metric-title");
                var label = chartLabelElems.length > 0 ? chartLabelElems[0].innerText : "";

                cloneElement.setAttribute('id', 'chartId');
                cloneElement.style.height = "80%";

                var modal = createTnxModal(label, cloneElement.outerHTML,
                        gettext("OK"), 'chart-modal-fullscreen');
                modal.modal();

                var elem = $('#chartId')[0];
                $compile(elem)({});
            }
        };

        return {
            templateUrl: basePath + 'metrics.html',
            link: function(scope, element, attrs){
                scope.isNotFound = false;
                scope.notFoundMetricMessage = gettext("Metric is not found " +
                  "in TIONIX.Monitor configuration.");

                var $canvas = element.find('canvas'),
                  chartData = chartsData[attrs.chartKey];

                scope.name = chartData.name;
                if (!chartData.data) {
                    scope.isNotFound = true;
                    $canvas.closest('div').remove();
                } else {
                    var canvas = $canvas[0],
                      labels = angular.copy(chartData.data.labels, []),
                      datasets = angular.copy(chartData.data.data, []);
                    if (labels.length == 1) {
                        labels.push("");
                    }
                    if ($canvas.length) {
                        var options = {
                            type: 'line',
                            data: {
                                labels: labels,
                                datasets: datasets
                            },
                            options: chartOptions
                          };
                        new Chart(canvas.getContext("2d"), options);
                    }
                }
            }
        }
    }

})();
