(function(){
    'use strict';

    angular.module('horizon.tionix.power_devices')
      .controller('EditPowerDeviceController', EditPowerDeviceController);

    EditPowerDeviceController.$inject = ['$element', '$scope'];

    function EditPowerDeviceController($element, $scope) {
        var ctrl = this,
            protocolTypePortInitialMap = {ssh: 22},
            authPrivateKey = 'private_key',
            authTypePassword = 'password',
            sshDeviceName = 'sshdevice';

        ctrl.$form = $element.closest('form');
        ctrl.$protocolTypeField = ctrl.$form.find('#id_protocol_type');
        ctrl.$deviceNameField = ctrl.$form.find('#id_device_name');
        ctrl.$portField = ctrl.$form.find('#id_port_number');
        ctrl.$authTypeField = ctrl.$form.find('#id_auth_type');

        ctrl.$form.find('#id_title[autofocus]').focus();

        var passwordGroup = ctrl.$form.find('#id_password').closest('div.form-group'),
            sshKeyGroup = ctrl.$form.find('#id_ssh_key').closest('div.form-group'),
            privateKeySelect = ctrl.$authTypeField.find('option[value="' + authPrivateKey + '"]');


        function toggleAuthType(displayPrivateKeyAuth) {
            if (displayPrivateKeyAuth) {
                sshKeyGroup.show();
                passwordGroup.hide();
            } else {
                sshKeyGroup.hide();
                passwordGroup.show();
            }
        }
        function manageAuthTypes() {
            var deviceName = ctrl.$deviceNameField.val().toLowerCase(),
                authType = ctrl.$authTypeField.val().toLowerCase(),
                showPrivateKeyAuth = deviceName === sshDeviceName;

            if (showPrivateKeyAuth) {
                privateKeySelect.show();
            }
            else {
                privateKeySelect.hide();
                ctrl.$authTypeField.val(authTypePassword);
            }

            var showPrivateKeyField = authType === authPrivateKey && showPrivateKeyAuth;
            toggleAuthType(showPrivateKeyField);
        }

        manageAuthTypes();

        ctrl.$deviceNameField.on('change', function(event) {
            manageAuthTypes();
        });
        ctrl.$authTypeField.on('change', function(event) {
            var deviceName = ctrl.$deviceNameField.val().toLowerCase(),
                authType = ctrl.$authTypeField.val().toLowerCase();
            var showPrivateKeyAuth = authType === authPrivateKey && deviceName === sshDeviceName;
            toggleAuthType(showPrivateKeyAuth);
        });


        ctrl.$protocolTypeField.on('change', function(event) {
            var protocolType = $(event.target).val(),
                initialPort = protocolTypePortInitialMap[protocolType];
            if (initialPort && !ctrl.$portField.val()) {
                ctrl.$portField.val(initialPort)
            }
        });
    }

})();
