# coding: utf-8

from django.template import defaultfilters as filters
from django.utils.translation import ugettext_lazy as _

from horizon import tables

from tionix_dashboard.helpers.fields import EmptyCharField
from tionix_dashboard.dashboards.tionix.power_devices.actions import (
    CreatePowerDevice, PowerDeviceFilterAction, DeviceTitleUpdateCell,
    TnxInstancesUpdateRow, DeletePowerDeviceAction, ClonePowerDevice,
    UnassignHypervisorAction, UpdateEditPowerDevice)
from tionix_dashboard.url_resolve_map import POWER_DEVICES_DETAIL


class PowerDevicesTable(tables.DataTable):
    """Power devices main table."""
    id = tables.Column('id', verbose_name=_('ID'))
    title = tables.Column('title',
                          verbose_name=_('Control title'),
                          link=POWER_DEVICES_DETAIL,
                          form_field=EmptyCharField(max_length=100),
                          update_action=DeviceTitleUpdateCell)
    device_name = tables.Column('device_name', verbose_name=_('Control type'))
    protocol_type = tables.Column('protocol_type',
                                  verbose_name=_('Protocol type'))
    ports = tables.Column('coils_count', verbose_name=_('Ports'))
    used_ports = tables.Column(
        'used_coils_count', verbose_name=_('Used ports'))

    class Meta(object):
        name = 'power_devices'
        verbose_name = _('Power controls')
        table_actions = (PowerDeviceFilterAction,
                         CreatePowerDevice,
                         DeletePowerDeviceAction)
        row_actions = (DeletePowerDeviceAction,
                       UpdateEditPowerDevice,
                       ClonePowerDevice)
        row_class = TnxInstancesUpdateRow


class HypervisorsTable(tables.DataTable):
    """Hypervisors table."""
    id = tables.Column('id', verbose_name=_('Hypervisor ID'))
    hostname = tables.Column('hypervisor_hostname', verbose_name=_('Hostname'))
    title = tables.Column('tnx_node_title', verbose_name=_('Hypervisor Title'))
    port = tables.Column('port', verbose_name=_('Port'))
    is_default = tables.Column('is_default',
                               verbose_name=_('Default'),
                               filters=(filters.yesno, filters.capfirst))
    is_initialized = tables.Column('is_initialized',
                                   verbose_name=_('Initialized'),
                                   filters=(filters.yesno, filters.capfirst))

    class Meta(object):
        name = 'hypervisors'
        verbose_name = _('Connected hypervisors')
        table_actions = (UnassignHypervisorAction,)
        row_actions = (UnassignHypervisorAction,)
