# coding: utf-8
import logging

from django.utils.translation import ugettext_lazy as _

from horizon import tabs

from tionix_dashboard.clients import TNXHypervisorsClient
from tionix_dashboard.clients.exceptions import UrlNotAvailableError
from tionix_dashboard.helpers.views import ServerFilterTabMixin
from tionix_dashboard.dashboards.tionix.power_devices import (
    tables as power_devices_tables)


logger = logging.getLogger(__name__)


class OverviewTab(tabs.Tab):
    name = _("Overview")
    slug = "overview"
    template_name = "power_devices/_overview.html"

    def get_context_data(self, request, **kwargs):
        return {"power_device": self.tab_group.kwargs['power_device']}


# noinspection PyAbstractClass
class HypervisorsTab(ServerFilterTabMixin, tabs.TableTab):
    """Tab for connected hypervisors"""
    table_classes = (power_devices_tables.HypervisorsTable,)
    name = _('Connected hypervisors')
    slug = 'hypervisors'
    template_name = 'horizon/common/_detail_table.html'
    preload = False

    def get_hypervisors_data(self):
        hypervisors = []
        try:
            hypervisors = TNXHypervisorsClient.list(
                self.request,
                power_device_id=self.tab_group.kwargs['power_device_id'],
                only_compute_nodes=False
            )
        except UrlNotAvailableError:
            raise
        except Exception as err:
            logger.error(unicode(err))
        else:
            for hypervisor in hypervisors:
                if hypervisor.devices:
                    device = hypervisor.devices[0]
                    hypervisor.port = device.device_port
                    hypervisor.is_default = device.is_default
                    hypervisor.is_initialized = device.is_initialized
        return hypervisors


# noinspection PyAbstractClass
class PowerDeviceDetailTabs(tabs.TabGroup):
    """Tionix project details tab group"""
    slug = "power_device_details"
    tabs = (OverviewTab,
            HypervisorsTab,)
