# coding: utf-8

"""Scheduler enumerates"""

from collections import OrderedDict

from django.utils.translation import ugettext_lazy as _

from tionix_dashboard.helpers.base import BaseEnumerate


class TaskTypeEnum(BaseEnumerate):
    """
    Enumerate types of task.
    """
    SINGLE = 'single'
    REPEATING = 'repeating'

    values = OrderedDict(
        [(SINGLE, _('Single task')),
         (REPEATING, _('Repeating task'))]
    )


class RepeatingTypeEnum(BaseEnumerate):
    """
    Enumerate types of repeating.
    """
    DAYS = 'days'
    HOURS = 'hours'
    MINUTES = 'minutes'
    WORKING_DAYS = 'working_days'
    DAYS_OF_THE_WEEK = 'days_of_the_week'
    YEAR = 'year'

    CRONTAB = (DAYS, WORKING_DAYS, DAYS_OF_THE_WEEK, YEAR, )
    INTERVAL = (HOURS, MINUTES, )

    values = OrderedDict(
        [(MINUTES, _('Minutes')),
         (HOURS, _('Hours')),
         (DAYS, _('Days')),
         (WORKING_DAYS, _('Working days (from Monday to Friday)')),
         (DAYS_OF_THE_WEEK, _('Days of the week')),
         (YEAR, _('Year'))]
    )


class EndTypeEnum(BaseEnumerate):
    """
    Enumerate types of end.
    """
    NEVER = 'never'
    MAX_COUNT = 'max_count'
    DATE = 'date'

    values = OrderedDict(
        [(NEVER, _('Never')),
         (MAX_COUNT, _("Max number of repetitions")),
         (DATE, _('Date'))]
    )


class WeekDaysEnum(BaseEnumerate):
    """
    Enumerate week days
    """
    MONDAY = 1
    TUESDAY = 2
    WEDNESDAY = 3
    THURSDAY = 4
    FRIDAY = 5
    SATURDAY = 6
    SUNDAY = 7

    form_values = {
        MONDAY: 'repeat_mon',
        TUESDAY: 'repeat_tue',
        WEDNESDAY: 'repeat_wed',
        THURSDAY: 'repeat_thu',
        FRIDAY: 'repeat_fri',
        SATURDAY: 'repeat_sat',
        SUNDAY: 'repeat_sun'
    }

    cron_values = {
        MONDAY: '1',
        TUESDAY: '2',
        WEDNESDAY: '3',
        THURSDAY: '4',
        FRIDAY: '5',
        SATURDAY: '6',
        SUNDAY: '0'
    }

    shot_name_values = {
        MONDAY: _("Mon"),
        TUESDAY: _("Tue"),
        WEDNESDAY: _("Wed"),
        THURSDAY: _("Thu"),
        FRIDAY: _("Fri"),
        SATURDAY: _("Sat"),
        SUNDAY: _("Sun")
    }

    reverse_cron_values = {v: k for k, v in cron_values.items()}
