(function() {

  'use strict';

  angular.module('horizon.app').config(config);

  function config($windowProvider, calendarConfig) {

    var calendarUrl = $windowProvider.$get().STATIC_URL +
      '/dashboard/tionix/scheduler/js/calendar/templates/';

    moment.locale(horizon.languageCode);

    calendarConfig.dateFormatter = 'moment';

    calendarConfig.i18nStrings.weekNumber = gettext('Week {week}');

    calendarConfig.templates.calendarDayView = calendarUrl +
      'calendarDayView.html';
    calendarConfig.templates.calendarHourList = calendarUrl +
      'calendarHourList.html';
    calendarConfig.templates.calendarMonthCellEvents = calendarUrl +
      'calendarMonthCellEvents.html';
    calendarConfig.templates.calendarSlideBox = calendarUrl +
      'calendarSlideBox.html';

  }

  config.$inject = ['$windowProvider', 'calendarConfig'];

  angular.module('horizon.tionix.scheduler.calendar', [
    'mwl.calendar'
  ]);

  angular.module('horizon.tionix.scheduler.calendar')
    .filter('eventsformatter', function() {
      return function(events) {
        events.forEach(function(event) {
          if (!isNaN(Date.parse(event.fullStartsAt))) {
            var startsAt = moment.parseZone(event.fullStartsAt);
            event.startsAt = startsAt.toDate();
            event.timeZone = startsAt.format('Z');
          }
        });
        return events;
      }
    })
    .controller('schedulerCalendarController', ['$scope', '$cookies', function($scope, $cookies) {
      var vm = this;

      vm.titleViewDate = null;
      vm.calendarView = 'month';
      vm.viewDate = moment().startOf('month').toDate();

      vm.timespanClicked = function(date, cell, url, $event) {
        var isTime = !angular.isDefined(cell),
          isDay = !isTime && cell.inMonth,
          currentDate = isDay? moment().startOf('day').toDate() : moment().toDate();

        if ($event) {
          var $elem = $($event.target);
          if ($elem.closest('.events-list').length ||
              $elem.closest('.cal-day-tick').length) {
            return;
          } else {
            $event.preventDefault();
            // angular-bootstrap-calendar uses defaultPrevented instead of
            // isDefaultPrevented
            $event.defaultPrevented = true;
          }
        }

        if ((date - currentDate) < 0) {
          return;
        }

        horizon.modals._request = $.ajax(url, {
          beforeSend: function () {
            horizon.modals.modal_spinner(gettext("Loading"));
          },
          complete: function () {
            // Clear the global storage;
            horizon.modals._request = null;
            horizon.modals.spinner.modal('hide');
          },
          error: function(jqXHR) {
            if (jqXHR.status === 401){
              var redir_url = jqXHR.getResponseHeader("X-Horizon-Location");
              if (redir_url){
                location.href = redir_url;
              } else {
                location.reload(true);

              }
            }
            else {
              if (!horizon.ajax.get_messages(jqXHR)) {
                // Generic error handler. Really generic.
                horizon.alert("danger", gettext("An error occurred. Please try again later."));
              }
            }
          },
          success: function (data, textStatus, jqXHR) {
            var modal = horizon.modals.success(data, textStatus, jqXHR),
              form = modal.find('form'), momentDate = moment(date),
              momentDateStr = momentDate.format('DD.MM.YYYY');

            form.find('#id_begin_date').val(momentDateStr);

            form.find('#id_end_date').datepicker().data('datepicker')
              .setStartDate(momentDateStr);

            if (isTime) {
              form.find('#id_begin_time').val(momentDate.format('HH:mm'));
            }
          }
        });
      };

      $scope.$watch('vm.viewDate', function(val) {
        vm.titleViewDate = getTitleViewDate();
      });

      $scope.$watch('vm.calendarView', function(val) {
        vm.titleViewDate = getTitleViewDate();
      });

      function getTitleViewDate() {
        var format;
        switch(vm.calendarView) {
          case 'year': {
            format = 'YYYY';
            break;
          }
          case 'month': {
            format = 'MMMM YYYY';
            break;
          }
          case 'day': {
            format = 'DD MMMM YYYY';
            break;
          }
        }
        return moment(vm.viewDate).format(format);
      }

    }]).directive('hourChecker', [function() {
      return {
        link: function(scope, element, attrs) {
          var date = moment(attrs.hourChecker.replace(/"/g,""));
          if (date.diff(moment()) < 0) {
            element.addClass('past-time');
          }
        }
      }
    }]);

  angular.module('horizon.app').requires.push('horizon.tionix.scheduler.calendar');

})();