(function () {

    angular.module('tionix.dashboard.scheduler')
      .controller('schedulerDetailsTabController', schedulerDetailsTabController);

    schedulerDetailsTabController.$inject = [
      '$element',
      '$timeout'
    ];

    function schedulerDetailsTabController($element, $timeout){
        var $fieldset = $element.parents('fieldset').first(),
            $form = $fieldset.parents('form').first(),
            $taskTypeInput = $form.find('#id_task_type'),
            $repeatInput = $form.find('#id_repeat'),
            $intervalInput = $form.find('#id_interval'),
            $dateStartInput = $form.find('#id_begin_date'),
            $endMaxNumberInput = $form.find('#id_end_max_number'),
            $endDateInput = $form.find('#id_end_date'),
            $endRadio0 = $form.find('#id_end_0'),
            $endRadio1 = $form.find('#id_end_1'),
            $endRadio2 = $form.find('#id_end_2'),
            $weekDaysCheckbox = $form.find('.week-days-checkbox');

        $timeout(init, 10);


        $dateStartInput.on('dp.change', function(event) {
          var datepicker = $endDateInput.data('datepicker');
          if (datepicker) {
            datepicker.setStartDate(event.date.format('DD.MM.YYYY'));
          }
        });

        $taskTypeInput.on('change', activateSummary);

        $endRadio0.on('change', function() {
          $endMaxNumberInput.prop('disabled', true);
          $endDateInput.prop('disabled', true);
        });

        $endRadio1.on('change', function() {
          $endMaxNumberInput.prop('disabled', false);
          $endDateInput.prop('disabled', true);
        }).filter(':checked').trigger('change');

        $endRadio2.on('change', function() {
          $endMaxNumberInput.prop('disabled', true);
          $endDateInput.prop('disabled', false);
        }).filter(':checked').trigger('change');

        $form.on('change', function() {
          var message = '',
              template,
              repeat = $repeatInput.val(),
              interval = $intervalInput.val(),
              endMaxNumber = $endMaxNumberInput.val(),
              endDay = $endDateInput.val();

          if (repeat) {
            switch (repeat) {
              case "days": {
                if (interval === 1) {
                  message = gettext("Each day");
                } else {
                  template = ngettext("Each %s day", "Each %s days", interval);
                  message = interpolate(template, [interval]);
                }
                break;
              }
              case "minutes": {
                if (interval === 1) {
                  message = gettext("Each minute");
                } else {
                  template = ngettext("Each %s minute", "Each %s minutes", interval);
                  message = interpolate(template, [interval]);
                }
                break;
              }
              case "hours": {
                if (interval === 1) {
                  message = gettext("Each hour");
                } else {
                  template = ngettext("Each %s hour", "Each %s hours", interval);
                  message = interpolate(template, [interval]);
                }
                break;
              }
              case "working_days": {
                message = gettext("Each week - on weekdays");
                break;
              }
              case "days_of_the_week": {

               if (interval === 1) {
                  message = gettext("Each week");
                } else {
                  template = ngettext("Each %s week", "Each %s weeks", interval);
                  message = interpolate(template, [interval]);
                }

                message = appendWeekDays(message);

                break;
              }
              case "year": {
                var date = getLocalizedDate($dateStartInput.val()).format('DD MMMM');

                if (interval === 1) {
                  template = gettext("Each year - %s");
                  message = interpolate(template, [date]);
                } else {
                  template = ngettext("Each %s year - %s", "Each %s years - %s", interval);
                  message = interpolate(template, [interval, date]);
                }

                break;
              }
            }
          }

          if ($endRadio1.is(':checked') && endMaxNumber) {
            var text_template = ngettext(", %s time", ", %s times", endMaxNumber);
            message += interpolate(text_template, [endMaxNumber]);
          }

          if ($endRadio2.is(':checked') && endDay) {
            var localizedDate = getLocalizedDate(endDay);
            message += interpolate(gettext(', till %s'), [localizedDate.format('LL')]);
          }

          $('.summary').text(message);

        });

        $weekDaysCheckbox.closest('.form-group')
          .css({float: 'left', 'padding-right': '5px'});

        function appendWeekDays(message) {
          var days = $weekDaysCheckbox.filter(':checked')
            .next('label').map(function(index, span) {
                return $(span).text().trim();
              });

          if (days.length) {
            message += ' - ' + Array.prototype.join.call(days, ', ');
          }

          return message;
        }

        function getLocalizedDate(date) {
          return moment(date, 'DD.MM.YYYY').locale(horizon.languageCode);
        }

        function init() {
          var $endMaxNumber = $endMaxNumberInput.parents('.form-group'),
            $endDate = $endDateInput.parents('.form-group');

          $endMaxNumber.addClass('radio-button-field');
          $endRadio1.parent('label').append($endMaxNumber);

          $endDate.addClass('radio-button-field');
          $endRadio2.parent('label').append($endDate);

          activateSummary();
        }

        function activateSummary() {
          var $summaryDiv = $form.find('.schedule-task-summary');

          if ($taskTypeInput.val() === 'single') {
            $summaryDiv.hide();
          } else {
            $summaryDiv.show();
          }
        }

    }
}());
