/**
 * Created by user on 18.07.16.
 */
(function () {
  'use strict';

  /**
   * @ngdoc controller
   * @name LaunchVDIInstanceController
   * @description
   * The `LaunchInstanceDetailsController` controller provides functions for
   * configuring the details step of the Launch Instance Wizard.
   *
   */
  angular.module('horizon.app')
    .controller('LaunchVDIInstanceController', LaunchVDIInstanceController);

  LaunchVDIInstanceController.$inject = [
    '$scope',
    'launchInstanceModel',
    'horizon.framework.widgets.charts.donutChartSettings',
    'horizon.framework.widgets.charts.quotaChartDefaults'
  ];

  function LaunchVDIInstanceController($scope,
    launchInstanceModel,
    donutChartSettings,
    quotaChartDefaults
  ) {

    var ctrl = this;
    var quotas_pie_chart = $('#quotas-pie-chart');

    $scope.currentInstanceCount = getCurrentInstanceCount();
    $scope.currentProject = getCurrentProject();

    ctrl.model = launchInstanceModel;

    ctrl.model.initialize(true);

    // Error text for invalid fields
    ctrl.instanceNameError = gettext('A name is required for your instance.');
    ctrl.instanceCountError = gettext(
      'Instance count is required and must be an integer of at least 1'
    );
    ctrl.maxInstanceCount = 1;

    /*
     * Donut chart
     */
    ctrl.chartSettings = donutChartSettings;
    ctrl.maxInstances = 0;
    ctrl.totalInstancesUsed = 0;

    ctrl.instanceStats = {
      title: gettext('Total Instances'),
      maxLimit: ctrl.maxInstances,
      label: '100%',
      data: [
        {
          label: quotaChartDefaults.usageLabel,
          value: 1,
          colorClass: quotaChartDefaults.usageColorClass
        },
        {
          label: quotaChartDefaults.addedLabel,
          value: 1,
          colorClass: quotaChartDefaults.addedColorClass
        },
        {
          label: quotaChartDefaults.remainingLabel,
          value: 1,
          colorClass: quotaChartDefaults.remainingColorClass
        }
      ]
    };

    syncInstanceChartAndLimits();

    var specifiedInstancesWatcher = createWatcher(getInstanceCount, updateChart);
    var specifiedProjectWatcher = createWatcher(getProject, updateChart);

    // Explicitly remove watchers on desruction of this controller
    $scope.$on('$destroy', function() {
      specifiedInstancesWatcher();
      specifiedProjectWatcher();
    });

    ////////////////////

    function getInstanceCount() {
      return $scope.currentInstanceCount;
    }

    function getProject() {
      return $scope.currentProject;
    }

    function createWatcher(watchExpression, listener) {
      return $scope.$watch(
        watchExpression,
        function (newValue, oldValue) {
          if (newValue !== oldValue) {
            listener(newValue);
          }
        }
      );
    }

    function syncInstanceChartAndLimits() {
      updateChart();
      updateMaxInstanceCount();
    }

    function getTenantInfo(tenant_id) {
      if('VDIProjectsQuotas' in window)
      {
        var tenant;
        window.VDIProjectsQuotas.forEach(function(item, i, arr) {
          if (tenant_id == item.id)
            tenant = item;
        });

        return tenant;
      }
    }

    function updateChart() {

      // Initialize currentInstanceCount to 1
      if ($scope.currentInstanceCount <= 0) {
        $scope.currentInstanceCount = 1;
      }

      var data = ctrl.instanceStats.data;
      var added = $scope.currentInstanceCount || 1;

      var tenant = getTenantInfo($scope.currentProject);
      if(tenant) {
        quotas_pie_chart.show();
        ctrl.maxInstances = parseInt(tenant.instances_quota);
        ctrl.totalInstancesUsed = parseInt(tenant.instances_usage);
        var remaining = Math.max(0, ctrl.maxInstances - ctrl.totalInstancesUsed - added);

        ctrl.instanceStats.maxLimit = ctrl.maxInstances;
        data[0].value = ctrl.totalInstancesUsed;
        data[1].value = added;
        data[2].value = remaining;
        var quotaCalc = Math.round((ctrl.totalInstancesUsed + added) / ctrl.maxInstances * 100);
        ctrl.instanceStats.overMax = quotaCalc > 100 ? true : false;
        ctrl.instanceStats.label = quotaCalc + '%';
      }
      else {
        quotas_pie_chart.hide();
      }

      ctrl.instanceStats = angular.extend({}, ctrl.instanceStats);
    }

    /*
     * Validation
     */

    function updateMaxInstanceCount() {

      var tenant = getTenantInfo($scope.currentProject);
      if(tenant) {
        ctrl.maxInstances = parseInt(tenant.instances_quota);
        ctrl.totalInstancesUsed = parseInt(tenant.instances_usage);
      }
      else {
        ctrl.maxInstances = 0;
        ctrl.totalInstancesUsed = 0;
      }

      ctrl.maxInstanceCount = ctrl.maxInstances - ctrl.totalInstancesUsed;

      var instanceCountText = gettext(
        'The instance count must not exceed your quota available of %(maxInstanceCount)s instances'
      );
      var instanceCountObj = { maxInstanceCount: ctrl.maxInstanceCount };
      ctrl.instanceCountMaxError = interpolate(instanceCountText, instanceCountObj, true);
    }

    function getCurrentInstanceCount() {
      return parseInt($('#id_instances_count').val());
    }

    function getCurrentProject() {
      return $('#id_project').val();
    }
  }
})();
