/**
 * Created by user on 08.07.17.
 */
(function () {
  'use strict';

  /**
   * @ngdoc controller
   * @name CreateProjectFlavorController
   * @description
   * The `CreateProjectFlavorController` controller to manage project's flavor
   */
  angular.module('horizon.tionix.vdi.projects')
    .controller('CreateProjectFlavorController', CreateProjectFlavorController);

  CreateProjectFlavorController.$inject = [
    '$element',
    '$filter',
    'horizon.tionix.vdi.projects.constants',
    'horizon.tionix.vdi.projects.tab.service'
  ];

  function CreateProjectFlavorController(
    $element,
    $filter,
    constants,
    tabService
  ) {

    var ctrl = this,
      tab = tabService($element, constants.FLAVOR, onGetFlavors),
      available_flavors = tab.available,
      allocated_flavors = tab.allocated,
      form = tab.$form[0],
      flavorInitValue = tab.$field.val();

    ctrl.actionHeaderScrollableClass = 'action-header-scrollable';
    ctrl.columns = [
      {attrName: "name", headerName: gettext("Name")},
      {attrName: "vcpus", headerName: gettext("VCPUs")},
      {attrName: "ram", headerName: gettext("RAM"), filter: $filter('mb')},
      {attrName: "totalDisk", headerName: gettext("Total Disk"),
        filter: $filter('gb')},
      {attrName: "rootDisk", headerName: gettext("Root Disk"),
        filter: $filter('gb')},
      {attrName: "ephemeralDisk", headerName: gettext("Ephemeral Disk"),
        filter: $filter('gb')},
      {attrName: "isPublic", headerName: gettext("Public"),
        filter: $filter('yesno')}
    ];
    ctrl.model = form.flavorModel = {
      available: available_flavors,
      allocated: allocated_flavors
    };

    function onGetFlavors(data) {

      buildFlavorFacades(data.data.available, available_flavors);

      if (flavorInitValue) {
        for(var i=0; i<available_flavors.length; i++) {
         if (flavorInitValue === available_flavors[i].id) {
           allocated_flavors.push(available_flavors[i]);
           break;
         }
        }
      }

      return data;
    }

    function buildFlavorFacades(flavors ,facades) {
      var facade, flavor;

      for (var i = 0; i < flavors.length; i++) {
        flavor = flavors[i];
        facade = {
          flavor:        flavor,
          id:            flavor.id,
          name:          flavor.name,
          vcpus:         flavor.vcpus,
          ram:           flavor.ram,
          totalDisk:     flavor.disk + flavor['OS-FLV-EXT-DATA:ephemeral'],
          rootDisk:      flavor.disk,
          ephemeralDisk: flavor['OS-FLV-EXT-DATA:ephemeral'],
          isPublic:      flavor['os-flavor-access:is_public'],
          extras:        flavor.extras
        };
        facades.push(facade);
      }
    }
  }
})();
