/**
 * Created by user on 08.07.17.
 */
(function () {
  'use strict';

  var push = Array.prototype.push;

  /**
   * @ngdoc controller
   * @name CreateProjectImageController
   * @description
   * The `CreateProjectImageController` controller to manage project's image
   */
  angular.module('horizon.tionix.vdi.projects')
    .controller('CreateProjectImageController', CreateProjectImageController);

  CreateProjectImageController.$inject = [
    '$element',
    'bytesFilter',
    'dateFilter',
    'decodeFilter',
    'horizon.tionix.vdi.projects.constants',
    'horizon.tionix.vdi.projects.tab.service'
  ];

  function CreateProjectImageController(
    $element,
    bytesFilter,
    dateFilter,
    decodeFilter,
    constants,
    tabService
  ) {

    var ctrl = this,
      tab = tabService($element, constants.IMAGE, onGetImages),
      available_images = tab.available,
      allocated_images = tab.allocated,
      form = tab.$form[0],
      imageInitValue = tab.$field.val();

    ctrl.columns = [
      {attrName: "name", headerName: gettext("Name")},
      {attrName: "updated_at", headerName: gettext("Updated"),
        filter: dateFilter, filterArg: 'short'},
      {attrName: "size", headerName: gettext("Size"), filter: bytesFilter},
      {attrName: "disk_format", headerName: gettext("Type")},
      {attrName: "is_public", headerName: gettext("Visibility"),
        filter: visibilityFilter}
    ];

    ctrl.model = form.imageModel = {
      available: available_images,
      allocated: allocated_images
    };

    function onGetImages(data) {

      push.apply(available_images, data.data.available);

      if (imageInitValue) {
        for(var i=0; i<available_images.length; i++) {
         if (imageInitValue === available_images[i].id) {
           allocated_images.push(available_images[i]);
         }
        }
      }

      return data;
    }

    function visibilityFilter(value) {
      var _visibilitymap = {
        true: gettext('Public'),
        false: gettext('Private')
      };
      return decodeFilter(value, _visibilitymap);
    }
  }
})();
