/**
 * Created by user on 08.07.17.
 */
(function () {
  'use strict';

  var push = Array.prototype.push;

  /**
   * @ngdoc controller
   * @name CreateProjectNetworkController
   * @description
   * The `CreateProjectNetworkController` controller to manage project's image
   */
  angular.module('horizon.tionix.vdi.projects')
    .controller('CreateProjectNetworkController', CreateProjectNetworkController);

  CreateProjectNetworkController.$inject = [
    '$element',
    '$filter',
    'horizon.tionix.vdi.projects.constants',
    'horizon.tionix.vdi.projects.tab.service'
  ];

  function CreateProjectNetworkController(
    $element,
    $filter,
    constants,
    tabService
  ) {

    var ctrl = this,
      tab = tabService($element, constants.NETWORK, onGetNetworks),
      available_networks = tab.available,
      allocated_networks = tab.allocated,
      form = tab.$form[0],
      networkInitValue = tab.$field.val();

    ctrl.isLoaded = false;

    ctrl.networkStatuses = {
      'ACTIVE': gettext('Active'),
      'DOWN': gettext('Down'),
      'DRAFT': gettext('Draft')
    };

    ctrl.networkAdminStates = {
      'UP': gettext('Up'),
      'DOWN': gettext('Down')
    };

    ctrl.columns = [
      {attrName: "name", headerName: gettext("Network")},
      {attrName: "subnets", headerName: gettext("Subnet Associated"),
        filter: subnetFilter},
      {attrName: "shared", headerName: gettext("Shared"),
        filter: $filter('yesno')},
      {attrName: "admin_state", headerName: gettext("Admin State"),
        filter: $filter('decode'), filterArg: ctrl.networkAdminStates},
      {attrName: "status", headerName: gettext("Status"),
        filter: $filter('decode'), filterArg: ctrl.networkStatuses}
    ];

    ctrl.model = form.networkModel = {
      available: available_networks,
      allocated: allocated_networks
    };

    tab.$field.on('change', function(){
      tab.load(true);
    });

    function onGetNetworks(data) {

      push.apply(available_networks, data.data.available);

      if (networkInitValue) {
        for(var i=0; i<available_networks.length; i++) {
         if (networkInitValue === available_networks[i].id) {
           allocated_networks.push(available_networks[i]);
         }
        }
      }

      return data;
    }

    function subnetFilter(subnets) {
      return subnets.map(function(subnet){return subnet.name}).join(", ");
    }
  }
})();