/**
 * Created by user on 11.07.17.
 */
(function () {
  'use strict';

  /**
   * @ngdoc controller
   * @name CreateProjectImageController
   * @description
   * The `CreateProjectImageController` controller to manage project's image
   */
  angular.module('horizon.tionix.vdi.projects')
    .factory('horizon.tionix.vdi.projects.tab.service', CreateProjectTabService);

  CreateProjectTabService.$inject = [
    'horizon.app.core.openstack-service-api.tnx',
    'horizon.tionix.vdi.projects.constants'
  ];

  function CreateProjectTabService(
    tnxAPI,
    constants
  ) {

    var tabsApiMap = {};
    tabsApiMap[constants.IMAGE] = tnxAPI.getImagesForProject;
    tabsApiMap[constants.FLAVOR] = tnxAPI.getFlavorsForProject;
    tabsApiMap[constants.NETWORK] = tnxAPI.getNetworksForProject;

    return function($element, tabType, onGetData){
      return createTab($element, tabType, onGetData)
    };

    function createTab($element, tabType, onGetData) {

      var service = {
        init: init,
        load: load
      };

      service.init();

      return service;

      function init(){
        var self = this;

        self.isLoaded = false;
        self.allocated = [];
        self.available = [];
        self.tabType = tabType;
        self.$element = $element;
        self.tabId = $element.closest('fieldset').attr("id");
        self.$form = $element.closest('form');
        self.$field = self.$form.find('#id_default_' + self.tabType);
        self.onGetData = onGetData;


        $('a[data-toggle="tab"]').on("shown.bs.tab", function(event) {
          var $a = $(event.target);
          if (getTabId($a) === self.tabId) {
            self.load();
          }
        });

        $('.workflow.modal').on("show.bs.modal", function(event) {
          var $a = $(event.target).find('.nav li.active a');
          if (self.tabId === getTabId($a)) {
            self.load();
          }
        });

        self.$form.submit(function() {
          if (self.allocated.length) {
            self.$field.val(self.allocated[0].id);
          }
        });

      }
    }

    function load(reload) {
      var self = this;
      
      if (self.isLoaded && !reload){
        return;
      }

      self.isLoaded = true;
      self.available.length = 0;
      self.allocated.length = 0;
      var project_id = self.$form.find('#id_project_id').val(),
        apiFunc = tabsApiMap[self.tabType];
      apiFunc(project_id).then(self.onGetData);
    }

    function getTabId($a) {
      return $a.attr('data-target').slice(1);
    }
  }

})();
