#!/usr/bin/env python

import os

from getpass import getuser

import django

from tionix_dashboard import decorate_secret_key_generator, check_configuration
from tionix_dashboard.db_migrate import (get_migrations_count,
                                         set_os_dashboard_settings)
from tionix_dashboard.helpers.i18 import ugettext as _


def main(verbose=False):
    set_os_dashboard_settings()
    decorate_secret_key_generator()
    django.setup()

    if not check_configuration():
        msg = _(u'Utility could not be executed by user '
                u'"{0}"').format(getuser())
        result = os.EX_SOFTWARE, msg
    else:
        from django.db import connection
        from django.db.utils import ProgrammingError
        try:
            from django.db.migrations.recorder import MigrationRecorder
        except IOError as ex:
            result = os.EX_SOFTWARE, unicode(ex)
        else:
            recorder = MigrationRecorder(connection)
            try:
                migrations_count = get_migrations_count(recorder)
            except ProgrammingError:
                migrations_count = 0
                result = os.EX_OK, migrations_count
            except Exception as ex:
                if verbose:
                    msg = _(u'Error while getting migrate versions: '
                            u'{0}').format(unicode(ex))
                else:
                    msg = _(u'Unknown DB Error. Please contact your '
                            u'administrator.')
                result = os.EX_SOFTWARE, msg
            else:
                result = os.EX_OK, migrations_count
    return result
