# coding: utf-8

import gettext
import logging
import os

import cron_descriptor

from babel.core import LOCALE_ALIASES

from django.utils.dates import WEEKDAYS


logger = logging.getLogger(__name__)


class TnxGetText(object):
    """
    Handles language translations and Initializes global _() function copy
    of cron_descriptor.GetText + code
    """

    def __init__(self, code=None):
        """Initialize TnxGetText
        """

        cron_descriptor_base_dir = os.path.dirname(cron_descriptor.__file__)

        filename = os.path.join(
            cron_descriptor_base_dir, 'locale', '{}.mo'.format(
                LOCALE_ALIASES.get(code)
            )
        )
        locale_file = None
        try:
            locale_file = open(filename, "rb")
            trans = gettext.GNUTranslations(locale_file)
            logger.debug('{0} Loaded'.format(filename))
        except IOError:
            trans = gettext.NullTranslations()
        finally:
            if locale_file is not None:
                locale_file.close()

        trans.install()


class TnxExpressionDescriptor(cron_descriptor.ExpressionDescriptor):

    def __init__(self, expression, options=None, lang_code=None, **kwargs):
        """Initializes a new instance of the TnxExpressionDescriptor

        Args:
            expression: The cron expression string
            options: Options to control the output description
            lang_code: Language code
        Raises:
            WrongArgumentException: if kwarg is unknow

        """
        super(TnxExpressionDescriptor, self).__init__(
            expression, options=options, **kwargs
        )

        # Initializes localization
        TnxGetText(lang_code)

    def number_to_day(self, day_number):
        """Returns localized day name by its CRON number

        Args:
            day_number: Number of a day
        Returns:
            Day corresponding to day_number
        Raises:
            IndexError: When day_number is not found
        """
        return [
            str(WEEKDAYS[6]),
            str(WEEKDAYS[0]),
            str(WEEKDAYS[1]),
            str(WEEKDAYS[2]),
            str(WEEKDAYS[3]),
            str(WEEKDAYS[4]),
            str(WEEKDAYS[5])
        ][day_number]


def get_description(expression, options=None, lang_code=None):
    """Generates a human readable string for the Cron Expression

    Args:
        expression: The cron expression string
        options: Options to control the output description
        lang_code: Language code
    Returns:
        The cron expression description

    """
    descripter = TnxExpressionDescriptor(expression, options, lang_code)
    return descripter.get_description(cron_descriptor.DescriptionTypeEnum.FULL)
