# coding: utf-8

import json

import six
from jsonfield import utils as json_utils

from horizon import forms


# # noinspection PyClassHasNoInit
class JSONWidgetHidden(forms.HiddenInput):
    def render(self, name, value, attrs=None):
        if value is None:
            value = ""
        if not isinstance(value, six.string_types):
            value = json.dumps(value, ensure_ascii=False, indent=2,
                               default=json_utils.default)
        return super(JSONWidgetHidden, self).render(name, value, attrs)


class MultiManagingFormMixin(object):

    def get_json_clean_data(self, field):
        """Convert json"""
        try:
            value = json.loads(self.cleaned_data.get(field))
        except (TypeError, ValueError):
            value = []
        return value

    def clean_new_allocated(self):
        """Retrieve converted new_allocated value"""
        return self.get_json_clean_data('new_allocated')

    def clean_old_allocated(self):
        """Retrieve converted old_allocated value"""
        return self.get_json_clean_data('old_allocated')


# noinspection PyAbstractClass
class MultiManagingForm(MultiManagingFormMixin,
                        forms.SelfHandlingForm):
    """Manage host aggregates form"""

    new_allocated = forms.CharField(widget=forms.HiddenInput, required=False)
    old_allocated = forms.CharField(widget=forms.HiddenInput, required=False)
