# coding: utf-8
from django.core.context_processors import csrf
from django.utils.translation import ugettext_lazy as _
from django.template.loader import render_to_string

from horizon import tabs

from openstack_dashboard import api
from openstack_dashboard.utils.identity import IdentityMixIn


class NewTab(tabs.Tab):
    name = _('New tab')
    slug = 'new_tab'
    template_name = 'tionix_dashboard/_details.html'


# noinspection PyAbstractClass
class DynamicTabGroup(tabs.TabGroup):
    """
    TabGroup with possibility of adding new tabs
    """
    template_name = '_dynamic_tab_group.html'

    tab_class = NewTab

    delete_url = None

    def get_context_data(self):
        context = {
            'tab_group': self,
            'new_tab': self.tab_class(self, self.request),
        }
        context.update(csrf(self.request))
        return context

    def render(self):
        """
        Renders the HTML output for this tab group
        """
        return render_to_string(self.template_name,
                                self.get_context_data())


class CloudAdminTabMixin(IdentityMixIn):

    def allowed(self, request):
        allowed = super(CloudAdminTabMixin, self).allowed(request)
        if allowed:
            is_domain_admin = api.keystone.is_domain_admin(request)
            admin_roles = self.get_admin_roles()
            is_project_admin = any(role.get('name') in admin_roles
                                   for role in request.user.roles)

            allowed = (not is_domain_admin or is_domain_admin and
                       is_project_admin)
        return allowed
