# coding: utf-8

from __future__ import unicode_literals

import datetime

from django.utils.html import avoid_wrapping
from django.utils.timezone import is_aware, utc
from django.utils.translation import ugettext_lazy as _

TIMESINCE_CHUNKS = (
    (60 * 60 * 24 * 365, _('%d y')),
    (60 * 60 * 24 * 30, _('%d m')),
    (60 * 60 * 24 * 7, _('%d w')),
    (60 * 60 * 24, _('%d d')),
    (60 * 60, _('%d h')),
    (60, _('%d min'))
)


def timesince(d, now=None, reversed=False):
    """
    Copied from django.template.defaultfilters.timesince.
    Modified TIMESINCE_CHUNKS.

    Takes two datetime objects and returns the time between d and now
    as a nicely formatted string, e.g. "10 minutes".  If d occurs after now,
    then "0 minutes" is returned.

    Units used are years, months, weeks, days, hours, and minutes.
    Seconds and microseconds are ignored.  Up to two adjacent units will be
    displayed.  For example, "2 weeks, 3 days" and "1 year, 3 months" are
    possible outputs, but "2 weeks, 3 hours" and "1 year, 5 days" are not.

    Adapted from
    http://web.archive.org/web/20060617175230/http://blog.natbat.co.uk/archive/2003/Jun/14/time_since
    """
    # Convert datetime.date to datetime.datetime for comparison.
    if not isinstance(d, datetime.datetime):
        d = datetime.datetime(d.year, d.month, d.day)
    if now and not isinstance(now, datetime.datetime):
        now = datetime.datetime(now.year, now.month, now.day)

    if not now:
        now = datetime.datetime.now(utc if is_aware(d) else None)

    delta = (d - now) if reversed else (now - d)
    # ignore microseconds
    since = delta.days * 24 * 60 * 60 + delta.seconds
    name = seconds = count = i = None
    if since <= 0:
        # d is in the future compared to now, stop processing.
        return avoid_wrapping(_('0 min'))
    for i, (seconds, name) in enumerate(TIMESINCE_CHUNKS):
        count = since // seconds
        if count != 0:
            break
    result = avoid_wrapping(name % count)
    if i + 1 < len(TIMESINCE_CHUNKS):
        # Now get the second item
        seconds2, name2 = TIMESINCE_CHUNKS[i + 1]
        count2 = (since - (seconds * count)) // seconds2
        if count2 != 0:
            result = u'{0}, {1}'.format(result, avoid_wrapping(name2 % count2))
    return result
