# coding: utf-8
# pylint: disable=no-member

from django.template.loader import render_to_string

from horizon import workflows


class TnxUpdateMembersStep(workflows.UpdateMembersStep):
    move_all_allowed = True


class WorkflowVerticalViewMixin(object):
    template_name = 'horizon/common/_workflow_vertical_base.html'
    ajax_template_name = 'horizon/common/_workflow_vertical.html'


class WorkflowVerticalView(WorkflowVerticalViewMixin, workflows.WorkflowView):
    pass


class OptionalFieldsActionMixin(object):
    """Makes all fields optional"""

    def __init__(self, request, context, *args, **kwargs):
        assert isinstance(self, workflows.Action)
        super(OptionalFieldsActionMixin, self).__init__(request,
                                                        context,
                                                        *args,
                                                        **kwargs)
        for field in self.fields.values():
            field.required = False


class TransferTableAction(workflows.Action):

    def add_error(self, field, error):
        return super(TransferTableAction, self).add_error(None, error)


class TransferTableStep(workflows.Step):
    template_name = 'tionix_dashboard/_transfer_table_step.html'
    controller = None

    @property
    def controller_name(self):
        return '{0} as ctrl'.format(self.controller)


class LazyMembershipAction(workflows.MembershipAction):

    lazy_load = True
    apply_sorting = True
    is_loaded = False

    def clean(self):
        cleaned_data = super(LazyMembershipAction, self).clean()

        default_role_name = self.get_default_role_field_name()
        default_role_value = self.request.POST.get(default_role_name)
        cleaned_data[default_role_name] = default_role_value
        self.is_loaded = default_role_value is not None

        member_field_name_start = self.get_member_field_name('')
        if not self.is_loaded and 'selected_members' in self.request.session:
            members_data = self.request.session.get('selected_members')
        else:
            members_data = self.request.POST
        for key, val in members_data.items():
            if key.startswith(member_field_name_start):
                cleaned_data[key] = val

    def _populate_fields(self, request, workflow, **kwargs):
        pass

    def populate_members(self, request, workflow, **kwargs):
        self._populate_fields(request, workflow, **kwargs)

        if self.apply_sorting:
            for field_name in self.fields:
                if field_name.startswith(self.slug):
                    # sort by name
                    self.fields[field_name].choices.sort(
                        key=lambda x: x[1].lower())

        return render_to_string(
            'horizon/common/_form_fields.html',
            {"form": self}
        )


class LazyUpdateMembersStep(workflows.UpdateMembersStep):

    def _get_members(self):
        return []

    def contribute(self, data, context):
        members = self._get_members()
        if data and members:
            post = self.workflow.request.POST
            field_value_getter = (
                post.getlist if self.action.is_loaded else data.get
            )
            for member in members:
                field = self.get_member_field_name(member.id)
                context[field] = field_value_getter(field)

        return context
