# coding: utf-8
import logging

from django.utils.translation import ugettext_lazy as _

from horizon import exceptions

from openstack_dashboard import api

from tionix_dashboard.clients.base import novaclient

logger = logging.getLogger(__name__)


def get_instances(request, project_id=None, search_opts=None,
                  with_deleted=False):
    search_opts = search_opts or {}
    if project_id:
        search_opts.update({'project_id': project_id, 'all_tenants': True})
    instances = []

    try:
        nova_client = novaclient(request)
        instances = nova_client.tnx_servers.list(search_opts=search_opts)
        if with_deleted:
            search_opts.update({'deleted': True})
            instances += nova_client.tnx_servers.list(
                search_opts=search_opts
            )
    except Exception as err:
        logger.error(unicode(err))
        exceptions.handle(request, _('Unable to get project instances list.'))

    return instances


def get_tenants(request, is_admin=False):
    tenants = []
    try:
        tenants, _has_more = api.keystone.tenant_list(request, admin=is_admin)
    except Exception as err:
        logger.error(unicode(err))
        msg = _('Unable to retrieve instance project information.')
        exceptions.handle(request, msg)

    return tenants
