# coding: utf-8

import hashlib
import os

from django.contrib.staticfiles.management.commands import collectstatic
# pylint: disable=no-name-in-module,import-error
from django.utils.six.moves.urllib.parse import unquote, urlsplit


def get_file_hash(name, storage):
    parsed_name = urlsplit(unquote(name))
    clean_name = parsed_name.path.strip()

    if not storage.exists(clean_name):
        raise ValueError("The file '%s' could not be found with %r." %
                         (clean_name, storage))
    content = file_hash = None
    try:
        content = storage.open(clean_name)
    except Exception:
        raise
    else:
        if content:
            md5 = hashlib.md5()
            for chunk in content.chunks():
                md5.update(chunk)
            file_hash = md5.hexdigest()
    finally:
        if content:
            content.close()
    return file_hash


class Command(collectstatic.Command):

    def delete_file(self, path, prefixed_path, source_storage):
        """
        Checks if the target file should be deleted if it already exists
        """
        calculate_hash_error = 'Error while calculate hash of file {0} : {1}'
        delete = True
        if self.storage.exists(prefixed_path):
            try:
                target_hash = get_file_hash(prefixed_path, self.storage)
            except Exception as err:
                self.log(calculate_hash_error.format(prefixed_path, err))
                target_hash = None
            try:
                source_hash = get_file_hash(path, source_storage)
            except Exception as err:
                self.log(calculate_hash_error.format(path, err))
                source_hash = None

            # The full path of the target file
            if self.local:
                full_path = self.storage.path(prefixed_path)
            else:
                full_path = None

            # Skip the file if the source file is the same
            if target_hash and source_hash:
                if target_hash == source_hash:
                    if not ((self.symlink and full_path
                             and not os.path.islink(full_path)) or
                            (not self.symlink and full_path
                             and os.path.islink(full_path))):
                        if prefixed_path not in self.unmodified_files:
                            self.unmodified_files.append(prefixed_path)
                        self.log("Skipping '%s' (not modified)" % path)
                        delete = False
            else:
                self.log("Skipping '%s' (unable to calculate hash)" % path)
                delete = False

            # Then delete the existing file if really needed
            if delete:
                if self.dry_run:
                    self.log("Pretending to delete '%s'" % path)
                else:
                    self.log("Deleting '%s'" % path)
                    self.storage.delete(prefixed_path)
        return delete
