/**
 * Created by user on 01.02.17.
 */
(function () {
  'use strict';

  angular
    .module('horizon.dashboard.project.workflow.launch-instance')
    .controller('LaunchInstanceModalController', LaunchInstanceModalController);

  LaunchInstanceModalController.$inject = [
    'horizon.app.core.openstack-service-api.tnx',
    'horizon.dashboard.project.workflow.launch-instance.modal.service',
    'SCSI_PROPERTIES'
  ];

  function LaunchInstanceModalController(tnxAPI, modalService, SCSI_PROPERTIES) {
    var ctrl = this;

    ctrl.openLaunchInstanceWizard = openLaunchInstanceWizard;

    function openLaunchInstanceWizard(launchContext) {

      if (launchContext.isClone && angular.isDefined(launchContext.event)) {
          var event = launchContext.event,
            id = $(event.target).attr('data-object-id');

          if (id) {
            tnxAPI.getTnxServer(id)
              .then(function(response) {
                onGetServer(response, launchContext);
                modalService.open(launchContext);
              });
          }
        } else {
          modalService.open(launchContext);
      }
    }

    function isDirectScsi(metadata) {
        var is_direct_scsi = true;
        angular.forEach(SCSI_PROPERTIES, function(value, key) {
            if (metadata[key] !== value) {
                is_direct_scsi = false;
            }
        });
        return is_direct_scsi
    }

    function onGetServer(data, context) {
      var instance = data.data,
        defaults = {
          name: 'Clone of ' + instance.name,
          availability_zone: instance['OS-EXT-AZ:availability_zone'],
          description: instance['description'],
          disk_config: instance['OS-DCF:diskConfig'],
          metadata: instance.metadata,
          default_networks: instance.tnx_networks,
          default_ports: instance.tnx_ports,
          default_security_groups: instance.tnx_security_groups,
          default_key_pair: instance.key_name,
          direct_scsi: isDirectScsi(instance.metadata),
          default_volumes_to_attach: instance.tnx_volumes_to_attach
        };

      angular.extend(context,
        {defaults: defaults,
          imageId: instance.image.id,
          flavorId: instance.flavor.id});
    }

  }

})();
