(function(){

    function quicksearchHide() {
        $(this).hide();
        $(this).addClass('quicksearch-hidden');
    }

    function quicksearchShow() {
        $(this).show();
        $(this).removeClass('quicksearch-hidden');
    }


    $.tablesorter.addParser({
      id: "percentProgressBar",
      is: function() {
        return false;
      },
      format: function(s) {
        s = s.replace(/\s/g, "").replace('%', " ");
        return parseInt(s);
      },
      type: "numeric"
    });

    horizon.datatables.set_table_query_filter = function (parent) {
        // Copy-paste form static/horizon/horizon.table.js
        // with removing whitespaces from both sides of a string before filter
        horizon.datatables.qs = {};
        $(parent).find('table').each(function (index, elm) {
            var input = $($(elm).find('div.table_search.client input')),
                table_selector;
            if (input.length > 0) {
                // Disable server-side searching if we have client-side searching since
                // (for now) the client-side is actually superior. Server-side filtering
                // remains as a noscript fallback.
                // TODO(gabriel): figure out an overall strategy for making server-side
                // filtering the preferred functional method.
                input.on('keypress', function (evt) {
                    if (evt.keyCode === 13) {
                    return false;
                    }
                });
                input.next('button.btn span.search-icon').on('click keypress', function (evt) {
                    return false;
                });

                // Enable the client-side searching.
                table_selector = 'table#' + $(elm).attr('id');
                var qs = input.quicksearch(table_selector + ' tbody tr', {
                    'delay': 300,
                    'loader': 'span.loading',
                    'bind': 'keyup click',
                    'show': quicksearchShow,
                    'hide': quicksearchHide,
                    onBefore: function () {
                        var table = $(table_selector);
                        horizon.datatables.remove_no_results_row(table);
                    },
                    onAfter: function () {
                        var table = $(table_selector);
                        horizon.datatables.update_footer_count(table);
                        horizon.datatables.add_no_results_row(table);
                        horizon.datatables.fix_row_striping(table);
                        horizon.datatables.hide_pagination(table);
                    },
                    prepareQuery: function (val) {
                        return new RegExp($.trim(val), "i");
                    },
                    testQuery: function (query, txt, _row) {
                        return query.test($(_row).find('td:not(.hidden):not(.actions_column)').text());
                    }
                });
                horizon.datatables.qs[$(elm).attr('id')] = qs;
            }
        });
    };

    horizon.datatables.update_footer_count = function (el, modifier) {
        // Copy-paste form static/horizon/horizon.table.js
        // with total count footer message
        var $el = $(el),
            $browser, $footer, row_count, footer_text_template, footer_text='';
        if (!modifier) {
            modifier = 0;
        }
        // code paths for table or browser footers...
        $browser = $el.closest("#browser_wrapper");
        if ($browser.length) {
            $footer = $browser.find('.tfoot span.content_table_count');
        }
        else {
            $footer = $el.find('tfoot span.table_count');
        }
        var total_count = $el.find('>tbody >tr').length,
          hidden_count = $el.find('>tbody >tr:hidden, >tbody >tr.detail-row').length;
        row_count = (total_count - hidden_count) + modifier - $el.find('>tbody >tr.empty').length;

        if ($footer.is('[data-total-count]') && !el.find('.table_search.client input').val()) {
            footer_text_template = ngettext("Displaying %s item of %s", "Displaying %s items of %s", row_count);
            footer_text = interpolate(footer_text_template, [row_count, $footer.attr('data-total-count')]);
        } else if (row_count > 0) {
            footer_text_template = ngettext("Displaying %s item", "Displaying %s items", row_count);
            footer_text = interpolate(footer_text_template, [row_count]);
        }

        $footer.text(footer_text);
        return row_count;
    };

    horizon.datatables.hide_pagination = function (el) {
        var searchInput = el.find('.table_search.client input');
        searchInput.val() ? el.find('.pagination:visible').hide(): el.find('.pagination:hidden').show();
    };

    horizon.datatables.validate_button = function ($form) {
        // Enable or disable table batch action buttons and multi-link action based on row selection.
        $form = $form || $(".table_wrapper > form");
        $form.each(function () {
            var checkboxes = $(this).find(".table-row-multi-select:checkbox");
            var action_buttons = $(this).find('.table_actions')
                .find('button[data-batch-action="true"], a[data-batch-action="true"]');
            action_buttons.toggleClass("disabled", !checkboxes.filter(":checked").length);
        });
    };

    horizon.datatables.set_table_sorting = function (parent) {
        var $parent = $(parent);
        // Function to initialize the tablesorter plugin strictly on sortable columns (client-side sorting).
        $parent.find("table.datatable").not('.tablesorter-server').each(function () {
            var $table = $(this),
                header_options = {};
            // Disable if not sortable or has <= 1 item
            if ($table.find('tbody tr').not('.empty').length > 1){
                $table.find("thead th[class!='table_header']").each(function (i) {
                    var $th = $(this);
                    if (!$th.hasClass('sortable')) {
                      header_options[i] = {sorter: false};
                    } else if ($th.data('type') === 'size'){
                      header_options[i] = {sorter: 'sizeSorter'};
                    } else if ($th.data('type') === 'ip'){
                      header_options[i] = {sorter: 'IPv4Address'};
                    } else if ($th.data('type') === 'timesince'){
                      header_options[i] = {sorter: 'timesinceSorter'};
                    } else if ($th.data('type') === 'timestamp'){
                      header_options[i] = {sorter: 'timestampSorter'};
                    } else if ($th.data('type') == 'uuid'){
                      header_options[i] = {sorter: 'uuid'};
                    } else if ($th.data('type') == 'percentbar'){
                      header_options[i] = {sorter: 'percentProgressBar'};
                    }
                  });
                $table.tablesorter({
                    headers: header_options,
                    widgets: ['zebra'],
                    selectorHeaders: "thead th[class!='table_header']",
                    cancelSelection: false,
                    //serverSideSorting: true,
                    emptyTo: 'none'
                });
            }
        });

        // Function to initialize the tablesorter plugin strictly on sortable columns (server-side sorting).
        $parent.find("table.datatable.tablesorter.tablesorter-server").each(function(){
            var $table = $(this);
            $table.servertablesorter({});
        });

    };

    horizon.datatables.add_no_results_row = function ($table) {
        // Copy-paste form static/horizon/horizon.table.js
        // diff: checks quicksearch hidden rows, because if tabbed view table
        // can be not visible

        // Add a "no results" row if there are no results.
        var template = horizon.templates.compiled_templates["#empty_row_template"];
        var total_count = $table.find('tbody tr').length,
          hidden_count = $table.find('tbody tr.quicksearch-hidden').length;
        if (total_count == hidden_count && typeof(template) !== "undefined") {
            var colspan = $table.find('.table_column_header th').length;
            var params = {
                "colspan": colspan,
                no_items_label: gettext("No items to display.")
            };
            $table.find("tbody").append(template.render(params));
        }
    };

    horizon.datatables.set_multi_select_pagination = function(tableId, objectIdsJson) {

        var table = $('#' + tableId),
            links = table.find('ul.pagination li a'),
            form = table.parents('form').first(),
            objectIds = objectIdsJson ? angular.fromJson(objectIdsJson) : [];

        if (objectIds.length) {
            var checkboxes = table.find('.table-row-multi-select:checkbox'),
                findString = objectIds.map(function(i){
                    return '[value=' + i + ']';
                }, '').join(','),
                excludeIds = $.map(checkboxes, function(i) {return parseInt(i.value)});

            objectIds.forEach(function(i) {
                if (excludeIds.indexOf(i) == -1) {
                    var html = "<tr class='hidden-checkbox' data-display=" + i + "><td><input class='table-row-multi-select' " +
                        "type='checkbox' name='object_ids' value='" + i + "'/></tr></td>";
                    table.find('tbody').append(html);
                }
            });

            table.ready(function() {
                table.find('.table-row-multi-select:checkbox').filter(findString).not(':checked').click();
            });
        }

        links.on('click', function(e){

            e.preventDefault();

            form.attr('action', $(e.target).attr('href'));

            form.submit();
        });
    };

    horizon.datatables.set_link_batch_action = function() {

      var linkBatchActions = $('button.btn-link-batch');

      linkBatchActions.each(function (index, action) {

        var $action = $(action);

        action.onclick = function (event) {

          event.preventDefault();

          var $form = $action.parents('form').first(),
            data = $form.serializeArray();

          data.push({name: 'action', value: $action.val()});
          horizon.modals._request = $.ajax({
            url: $form.attr('action'),
            method: "POST",
            data: data,
            beforeSend: function () {
              horizon.modals.modal_spinner(gettext("Loading"));
            },
            complete: function () {
              // Clear the global storage;
              horizon.modals._request = null;
              horizon.modals.spinner.modal('hide');
            },
            error: function (jqXHR, status, errorThrown) {
              if (jqXHR.status === 401) {
                var redir_url = jqXHR.getResponseHeader("X-Horizon-Location");
                if (redir_url) {
                  location.href = redir_url;
                } else {
                  location.reload(true);
                }
              } else {
                if (!horizon.ajax.get_messages(jqXHR)) {
                  // Generic error handler. Really generic.
                  horizon.alert("danger", gettext("An error occurred. Please try again later."));
                }
              }
            },
            success: function (data, textStatus, jqXHR) {
              var redirctUrl = jqXHR.getResponseHeader("X-Horizon-Location");
              if (redirctUrl) {
                location.href = redirctUrl;
              }
              var update_field_id = $action.attr('data-add-to-field'),
                modal,
                form;
              modal = horizon.modals.success(data, textStatus, jqXHR);
              if (update_field_id) {
                form = modal.find("form");
                if (form.length) {
                  form.attr("data-add-to-field", update_field_id);
                }
              }
            }
          });
        }
      });
    };

    horizon.datatables.on_table_update = function() {
        $('table.datatable').on('update', function(event) {
            var $table = $(event.target);

            if (!$table.find('thead th.multi_select_column').hasClass('hidden')) {
                $table.find('tbody td.multi_select_column').removeClass('hidden');
            }
        });
    };

    horizon.datatables.disable_actions_on_submit = function($form) {
        // This applies changes to the table form when a user takes an action that
        // submits the form. It relies on the form being re-rendered after the
        // submit is completed to remove these changes.
        $form = $form || $(".table_wrapper > form");
        $form.on("submit", function () {
            var $this = $(this),
              $currentRow = $(document.activeElement).parents('tr');

            // Add the 'submitted' flag to the form so the row update interval knows
            // not to update the row and therefore re-enable the actions that we are
            // disabling here.
            $this.attr('data-submitted', 'true');
            // Disable row action buttons. This prevents multiple form submission.
            $currentRow.find('td.actions_column button[type="submit"]').addClass("disabled");
            // Use CSS to update the cursor so it's very clear that an action is
            // in progress.
            $this.addClass('wait');
        });
    };

    /* Generates a confirmation modal dialog for the given action. */
    horizon.datatables.confirm = function (action) {
      var $action = $(action),
        $modal_parent = $(action).closest('.modal'),
        name_array = [],
        closest_table_id, action_string, name_string, action_confirm_header,
        help_text,
        title, body, modal, form, displayAttrs;
      if($action.hasClass("disabled")) {
        return;
      }
      action_string = $action.text();
      action_confirm_header = $action.attr("data-confirm-header") || action_string;
      help_text = $action.attr("help_text") || "";
      name_string = "";
      // Add the display name defined by table.get_object_display(datum)
      closest_table_id = $(action).closest("table").attr("id");
      // Check if data-display attribute is available
      displayAttrs = $("#"+closest_table_id+" tr[data-display]");
      if (displayAttrs.length > 0) {
        var actions_div = $(action).closest("div");
        if(actions_div.hasClass("table_actions") || actions_div.hasClass("table_actions_menu")) {
          // One or more checkboxes selected
          displayAttrs.has(".table-row-multi-select:checked").each(function() {
            name_array.push(" \"" + $(this).attr("data-display") + "\"");
          });
          name_array.join(", ");
          name_string = name_array.toString();
        } else {
          // If no checkbox is selected
          name_string = " \"" + $(action).closest("tr").attr("data-display") + "\"";
        }
        name_string = interpolate(gettext("You have selected %s. "), [name_string]);
      }
      title = interpolate(gettext("Confirm %s"), [action_confirm_header]);
      body = name_string + gettext("Please confirm your selection. ") + help_text;
      modal = horizon.modals.create(title, body, action_string);
      modal.modal();
      if($modal_parent.length) {
        var child_backdrop = modal.next('.modal-backdrop');
        // re-arrange z-index for these stacking modal
        child_backdrop.css('z-index', $modal_parent.css('z-index')+10);
        modal.css('z-index', child_backdrop.css('z-index')+10);
      }
      modal.find('.btn-primary').click(function () {
        form = $action.closest('form');
        var el = document.createElement("input");
        el.type='hidden';
        el.name = $action.attr('name');
        el.value = $action.attr('value');
        form.append(el);
        form.submit();
        modal.modal('hide');
        horizon.modals.modal_spinner(gettext("Working"));
        return false;
      });
      return modal;
    };

    horizon.datatables.set_link_batch_action();
    horizon.datatables.on_table_update();

    horizon.modals.addModalInitFunction(horizon.datatables.set_link_batch_action);
    horizon.modals.addModalInitFunction(horizon.datatables.on_table_update);

    // Also apply on tables in tabs views for lazy-loaded data.
    horizon.tabs.addTabLoadFunction(horizon.datatables.set_link_batch_action);
    horizon.tabs.addTabLoadFunction(horizon.datatables.on_table_update);

}());