# coding: utf-8

import logging

from tionix_dashboard.tasks.helpers import (
    add_nova_client, launch_instances)
from tionix_dashboard.tasks.validation import validate_task

logger = logging.getLogger(__name__)

# unique name of task-module
unique_code = 'launch_base_vm'

# human-readable localized name of task
locale = {
    'en': 'Launch Base Instance',
    'ru': u'Запустить базовую машину'
}

subject_type = 'project'
subject_groups = ['identity']


# noinspection PyUnusedLocal
@validate_task(('image', 'network_id', 'flavor_id'))
@add_nova_client
def launch_base_vm(nova_client, *args, **kwargs):
    """
    :lang:ru Позволяет создать заданное количество новых базовых виртуальных
    машин
    """
    image_id = kwargs['image']
    network_id = kwargs['network_id']
    flavor_id = kwargs['flavor_id']
    name = kwargs.get('name')
    timetable_id = kwargs.get("timetable_id")
    instances_count = kwargs.get('count') or 1

    nics = [{"net-id": network_id, "v4-fixed-ip": ""}]
    server_descr = (u'Object creation was initiated by the task'
                    u' with id {0}.'.format(timetable_id))

    result = launch_instances(nova_client, image_id, flavor_id, nics,
                              instances_count, server_descr,
                              instance_name=name)
    return result
