# coding: utf-8

import logging

from neutronclient.common import exceptions as neutron_exceptions

from tionix_dashboard.tasks.helpers import (
    add_nova_neutron_clients, launch_instances)
from tionix_dashboard.tasks.validation import validate_task

logger = logging.getLogger(__name__)

# unique name of task-module
unique_code = 'launch_vm'

# human-readable localized name of task
locale = {
    'en': 'Launch Instance',
    'ru': u'Запустить машину'
}

subject_type = 'project'
subject_groups = ['identity']


# noinspection PyUnusedLocal
@validate_task(('image_id', 'flavor_id', 'networks'))
@add_nova_neutron_clients
def launch_vm(nova_client, neutron_client, *args, **kwargs):
    """
    :lang:ru Позволяет создавать заданное количество новых виртуальных машин.
    """
    availability_zone = kwargs.get('availability_zone')
    image_id = kwargs['image_id']
    flavor_id = kwargs['flavor_id']
    networks = kwargs['networks']
    timetable_id = kwargs.get("timetable_id")

    try:
        instances_count = int(kwargs.get('count'))
    except ValueError:
        instances_count = 1

    nics = []
    for network_id in networks:
        try:
            neutron_client.show_network(network_id).get('network')

        except neutron_exceptions.NotFound as err:
            logger.error(unicode(err))
        else:
            nics.append({"net-id": network_id, "v4-fixed-ip": ""})

    if not nics:
        return u'Available network is not found.', False

    server_descr = (u'Object creation was initiated by the task'
                    u' with id {0}.'.format(timetable_id))

    result = launch_instances(nova_client, image_id, flavor_id, nics,
                              instances_count, server_descr,
                              availability_zone=availability_zone)

    return result
