# coding: utf-8

from functools import wraps

from django.utils.translation import ugettext_lazy as _


def validate(username, password, tenant_id, object_id, user_domain_name):
    """Validate username, password, tenant_id"""
    if not (username and password and tenant_id and user_domain_name):
        msg = _(u'Authentication parameters are invalid, '
                u'please check parameters.')
        raise ValueError(msg)


def validate_kw_keys(keys, kwargs):
    """Key arguments validation"""
    empty_keys = [key for key in keys if not kwargs.get(key)]
    if empty_keys:
        raise ValueError(
            _(u'{0} must be provided.').format(u', '.join(empty_keys))
        )


def validate_task(kw_keys):
    """Decorator to validate task's arguments"""
    def _decorator(fn):
        @wraps(fn)
        def wrapper(username, password, tenant_id, object_id, object_name,
                    user_domain_name, *args, **kwargs):
            validate(username, password, tenant_id, object_id,
                     user_domain_name)
            if kw_keys:
                validate_kw_keys(kw_keys, kwargs)
            return fn(username, password, tenant_id, object_id, object_name,
                      user_domain_name, *args, **kwargs)
        return wrapper
    return _decorator
