# coding: utf-8

"""
module contain fake cloud state, with hypervisors, servers e.t.c
"""
from collections import defaultdict

from openstack_dashboard.api.keystone import DEFAULT_DOMAIN

cloud_state = {
    'hypervisors': [
        {
            'id': 1,
            'hypervisor_hostname': 'Host1',
            'tnx_node_title': 'Host1',
            'tnx_devices': [('device 1', 'port 1', True, True, 1, 'ssh')],
            'has_default_ssh_device': True,
            'tnx_power_state': None,
            'hypervisor_type': None,
            'tnx_image_name': 'image name',
            'tnx_is_reserved': False,
            'running_vms': 0,
            'state': 'up',
            'status': 'enabled',
            'cpu_info': '',
            'service': {'host': 'Host1', 'zone': 'nova'},
            'tnx_node_id': '1',
            'tnx_controller_id': 1
        }, {
            'id': 2,
            'hypervisor_hostname': 'Host2',
            'tnx_devices': [('device 2', 'port 1', True, True, 1, 'ssh')],
            'has_ssh_device': True,
            'tnx_power_state': 'power_on',
            'state': 'up',
            'service': {'host': 'Host2', 'zone': 'nova'},
            'running_vms': 0,
            'vcpus': 10,
            'vcpus_used': 2,
            'memory_mb': 10,
            'memory_mb_used': 2,
            'local_gb': 10,
            'local_gb_used': 2,
            'tnx_node_id': None
        }, {
            'id': 3,
            'hypervisor_hostname': 'Host3',
            'tnx_devices': [('device 2', 'port 1', True, True, 1, 'ssh')],
            'has_ssh_device': True,
            'tnx_power_state': None,
            'running_vms': 0,
            'state': 'down',
            'service': {'host': 'Host3'}
        }, {
            'id': 4,
            'hypervisor_hostname': 'Host4',
            'tnx_node_title': 'Host4',
            'tnx_devices': [('device 2', 'port 1', True, True, 1, 'ssh')],
            'has_ssh_device': True,
            'running_vms': 0,
            'tnx_power_state': 'power_off',
            'state': 'down',
            'status': 'enabled',
            'service': {'host': 'Host4'}
        },
        # hypervisors without tnx fields
        {
            'id': 5,
            'hypervisor_hostname': 'Host5',
            'hypervisor_type': None,
            'tnx_devices': [],
            'running_vms': 0,
            'state': 'up',
            'status': 'enabled',
            'cpu_info': '',
            'service': {'host': 'Host5'},
            'has_ssh_device': False,
        }, {
            'id': 6,
            'hypervisor_hostname': 'Host6',
            'running_vms': 0,
            'tnx_devices': [],
            'state': 'up',
            'service': {'host': 'Host6'},
            'has_ssh_device': False,
        }, {
            'id': 7,
            'hypervisor_hostname': 'Host7',
            'running_vms': 0,
            'state': 'down',
            'service': {'host': 'Host7'},
            'tnx_devices': [],
            'has_ssh_device': False,
        }, {
            'id': 8,
            'hypervisor_hostname': 'Host8',
            'running_vms': 0,
            'state': 'down',
            'status': 'enabled',
            'service': {'host': 'Host8'},
            'tnx_devices': [],
            'has_ssh_device': False,
        },
    ],
    'hypervisor_images': [
        'default'
    ],
    'servers': [
        {
            'id': u'c8934ca4-8882-4cbe-976c-0de5fb553a17',
            'OS-EXT-AZ:availability_zone': 'nova',
            'OS-EXT-SRV-ATTR:host': 'Host1',
            'OS-EXT-STS:power_state': 1,
            'OS-EXT-STS:task_state': None,
            'tenant_id': '1',
            'flavor': {
                'id': 1
            },
            'image': {
                'id': 1
            },
            'addresses': {},
            'status': 'ACTIVE',
            'created': '2016-06-10 10:30:00',
            'tnx_type': '1',
            'tnx_node_title': 'Node1',
            'node_id': 10,
            'tnx_movable': False,
            'log_output': 'Test data',
            'key_name': 'test key name',
            'availability_zone': 'nova',
            'tnx_users': [{'id': 1}],
            'description': 'desc'
        },
        {
            'id': u'03894d08-36a7-4271-85fd-230c7227840c',
            'OS-EXT-AZ:availability_zone': 'nova',
            'OS-EXT-SRV-ATTR:host': 'Host1',
            'OS-EXT-STS:power_state': 0,
            'tenant_id': '1',
            'flavor': {
                'id': 1
            },
            'image': {
                'id': 1
            },
            'addresses': {
                'test_net': [{
                    'addr': '192.0.0.1'
                }]
            },
            'status': 'ACTIVE',
            'created': '2016-06-10 10:30:00',
            'tnx_type': '1'
        },
        {
            'id': u'376b5ec4-c0a5-47b3-92bb-c7cc5112f316',
            'OS-EXT-AZ:availability_zone': 'nova',
            'OS-EXT-SRV-ATTR:host': 'Host1',
            'OS-EXT-STS:power_state': 1,
            'tenant_id': '1',
            'flavor': {
                'id': 1
            },
            'image': {
                'id': 1
            },
            'addresses': {},
            'status': 'ERROR',
            'created': '2016-06-10 10:30:00',
            'tnx_type': '1'
        },
        {
            'id': u'c8257281-d9b0-4e42-a4a5-7fce632a365d',
            'OS-EXT-AZ:availability_zone': 'nova',
            'OS-EXT-SRV-ATTR:host': 'Host1',
            'OS-EXT-STS:power_state': 0,
            'tenant_id': '1',
            'flavor': {
                'id': 1
            },
            'image': {
                'id': 1
            },
            'addresses': {},
            'status': 'PAUSED',
            'created': '2016-06-10 10:30:00',
            'tnx_type': '1'
        },
        {
            'id': u'27765a70-158c-44ea-be85-edaeebc5909f',
            'OS-EXT-SRV-ATTR:host': 'Host1',
            'OS-EXT-STS:power_state': 0,
            'tenant_id': '1',
            'flavor': {
                'id': 1
            },
            'image': {
                'id': 1
            },
            'addresses': {},
            'status': 'SUSPENDED',
            'created': '2016-06-10 10:30:00',
            'tnx_type': '1'
        },
        {
            'id': u'e38b85bb-748f-49db-8d2a-7e1f42a5077b',
            'OS-EXT-SRV-ATTR:host': 'Host1',
            'OS-EXT-STS:power_state': 0,
            'tenant_id': '1',
            'flavor': {
                'id': 1
            },
            'image': {
                'id': 1
            },
            'addresses': {},
            'status': 'SHELVED_OFFLOADED',
            'created': '2016-06-10 10:30:00',
            'tnx_type': '1'
        },
        {
            'id': u'a4835f40-8332-4643-8ddb-e5b8a8c4cec9',
            'OS-EXT-SRV-ATTR:host': 'Host1',
            'OS-EXT-STS:power_state': 3,
            'tenant_id': '1',
            'flavor': {
                'id': 1
            },
            'image': {
                'id': 1
            },
            'addresses': {},
            'status': 'PAUSED',
            'created': '2016-06-10 10:30:00',
            'tnx_type': '1'
        },
        {
            'id': u'e81b0326-ef7d-4018-8bb2-e00b93b07c30',
            'OS-EXT-SRV-ATTR:host': 'Host1',
            'OS-EXT-STS:power_state': 7,
            'tenant_id': '1',
            'flavor': {
                'id': 1
            },
            'image': {
                'id': 1
            },
            'addresses': {},
            'status': 'SUSPENDED',
            'created': '2016-06-10 10:30:00',
            'tnx_type': '1'
        },
        {
            'id': u'ef21f1db-2b70-41cc-a80e-afa0d355de10',
            'OS-EXT-SRV-ATTR:host': 'Host1',
            'OS-EXT-STS:power_state': 7,
            'tenant_id': '2',
            'flavor': {
                'id': 1
            },
            'image': {
                'id': 1
            },
            'addresses': {},
            'status': 'VERIFY_RESIZE',
            'created': '2016-06-10 10:30:00',
            'tnx_type': '1'
        },
        {
            'id': u'5bfe1ff6-7cf8-4803-b396-2bd17b14ee8e',
            'OS-EXT-SRV-ATTR:host': 'Host2',
            'OS-EXT-STS:power_state': 1,
            'tenant_id': '2',
            'flavor': {
                'id': 1
            },
            'image': {
                'id': 1
            },
            'addresses': {},
            'status': 'SHUTOFF',
            'created': '2016-06-10 10:30:00',
            'tnx_type': '1'
        },
        {
            'id': u'ab45bb11-1bc4-4cc6-8dda-a81c5ed709a1',
            'OS-EXT-AZ:availability_zone': 'nova',
            'OS-EXT-SRV-ATTR:host': 'Host5',
            'OS-EXT-STS:power_state': 1,
            'OS-EXT-STS:task_state': None,
            'tenant_id': '2',
            'flavor': {
                'id': 1
            },
            'image': {
                'id': 2
            },
            'addresses': {},
            'status': 'ACTIVE',
            'created': '2016-07-10 10:30:00',
            'node_id': 10,
            'log_output': 'Test data',
            'key_name': 'test key name',
            'availability_zone': 'nova',
            'description': 'desc'
        },
        {
            'id': u'd011e65f-b519-4a08-a8f2-125bbed5460c',
            'OS-EXT-AZ:availability_zone': 'nova',
            'OS-EXT-SRV-ATTR:host': 'Host5',
            'OS-EXT-STS:power_state': 1,
            'OS-EXT-STS:task_state': None,
            'tenant_id': '2',
            'flavor': {
                'id': 1
            },
            'image': {
                'id': 3
            },
            'addresses': {},
            'status': 'PAUSED',
            'created': '2016-07-10 10:40:00',
            'node_id': 10,
            'log_output': 'Test data',
            'key_name': 'test key name',
            'availability_zone': 'nova',
        },
        {
            'id': u'6440e720-afc2-4d07-a5bb-9e2dcaa6b759',
            'OS-EXT-AZ:availability_zone': 'nova',
            'OS-EXT-SRV-ATTR:host': 'Host5',
            'OS-EXT-STS:power_state': 1,
            'OS-EXT-STS:task_state': None,
            'tenant_id': '2',
            'flavor': {
                'id': 1
            },
            'image': {
                'id': 3
            },
            'addresses': {},
            'status': 'ERROR',
            'created': '2016-07-10 10:40:00',
            'node_id': 10,
            'log_output': 'Test data',
            'key_name': 'test key name',
            'availability_zone': 'nova',
        },
    ],
    'flavors': [
        {
            'id': 1,
            'name': 'Flavor 1',
            'ram': 512,
            'disk': 50,
            'vcpus': 1,
            'is_public': True
        },
        {
            'id': 2,
            'name': 'Flavor 2',
            'ram': 512,
            'disk': 50,
            'vcpus': 1,
            'is_public': False

        }
    ],
    'images': [
        {
            'id': 1,
            'name': 'Image 1',
            'container_format': '',
            'size': 1,
            'min_disk': 1,
            'protected': False,
            'status': 'active',
            'owner': '1',
            'is_public': True
        },
        {
            'id': 2,
            'name': 'Image 2',
            'container_format': 'aki',
            'size': 1,
            'min_disk': 1,
            'protected': True,
            'status': 'not active',
            'owner': '2',
            'is_public': False
        },
        {
            'id': 3,
            'name': 'Image 3',
            'container_format': 'aki',
            'size': 1,
            'min_disk': 1,
            'protected': False,
            'status': 'not active',
            'owner': '1',
            'is_public': True
        }
    ],
    'power_devices': [
        {
            'id': 1,
            'name': 'Power control 1',
            'title': 'Power control 1',
            'device_name': 'type 1',
            'protocol_type': 'protocol 1',
            'coils_count': '1',
            'used_coils_count': '1',
            'assigned_nodes': [
                {'id': 1}
            ]
        },
        {
            'id': 2,
            'name': 'Power control 2',
            'title': 'Power control 2',
            'device_name': 'type 1',
            'protocol_type': 'protocol 1',
            'coils_count': '1',
            'used_coils_count': '0',
            'assigned_nodes': []
        },
        {
            'id': 3,
            'name': 'New device',
            'title': 'New device',
            'device_name': 'type 2',
            'protocol_type': 'protocol 3',
            'coils_count': '2',
            'used_coils_count': '1',
            'assigned_nodes': []
        },

    ],
    'tenants': [
        {'id': '1',
         'name': 'Tenant 1',
         'tnx_operation_mode': 1,
         'tnx_flavor_id': 1,
         'tnx_network_id': 1,
         'tnx_image_id': 1,
         'description': 'description',
         'domain_id': 1,
         'domain_name': 'domain name',
         'enabled': 'yes',
         'tnx_project_type': 'vdi type'},
        {'id': '2',
         'name': 'Tenant 2',
         'domain_id': 2,
         'tnx_operation_mode': 1,
         'tnx_flavor_id': 2,
         'tnx_network_id': 2,
         'tnx_image_id': 1},
        {'id': '3',
         'name': 'Tenant 3',
         'domain_id': 2,
         'tnx_operation_mode': 1,
         'tnx_flavor_id': 1,
         'tnx_network_id': 3,
         'tnx_image_id': 1},
        {'id': '4',
         'name': 'Tenant 4',
         'domain_id': 1,
         'tnx_operation_mode': 1,
         'tnx_flavor_id': 1,
         'tnx_network_id': 3,
         'tnx_image_id': 2}
    ],

    'networks': [
        {'id': 1,
         'tenant_id': 1,
         'shared': True},
        {'id': 2,
         'tenant_id': 1,
         'shared': False},
        {'id': 3,
         'tenant_id': 1,
         'shared': True},
    ],
    'quotas': [
        {'id': 1,
         'instances': 10},
        {'id': 2,
         'instances': 10},
        {'id': 3,
         'instances': 10},
        {'id': 4,
         'instances': 5},
    ],

    'host_classes': [
        {'id': 1,
         'name': 'hypervisor',
         'is_default': True},
        {'id': 2,
         'name': 'host class 2',
         'is_default': False},
        {'id': 3,
         'name': 'host class 3',
         'is_default': False}
    ]
}

keystone_state = {
    'domains': [
        {'id': 1,
         'name': 'domain 1',
         'enabled': True},
        {'id': 2,
         'name': 'domain 2',
         'enabled': False},
        {'id': DEFAULT_DOMAIN,
         'name': 'domain_3',
         'enabled': True}
    ],

    'users': [
        {'id': 1,
         'name': 'user 1',
         'domain_id': 1},
        {'id': 2,
         'name': 'user 2',
         'domain_id': 1},
        {'id': 3,
         'name': 'user 3',
         'domain_id': 2},
        {'id': 4,
         'name': 'user 4',
         'domain_id': 3}
    ]
}

HYPERVISOR_COUNT = len(cloud_state['hypervisors'])
ALL_SERVERS_COUNT = len(cloud_state['servers'])
SERVERS_COUNT = {}
domain_tenant_dict = {t['id']: t['domain_id'] for t in cloud_state['tenants']}
for hypervisor in cloud_state['hypervisors']:
    hypervisor_hostname = hypervisor['hypervisor_hostname']
    count_by_domain = defaultdict(int)
    for server in cloud_state['servers']:
        if server['OS-EXT-SRV-ATTR:host'] == hypervisor_hostname:
            count_by_domain[domain_tenant_dict.get(server['tenant_id'])] += 1
    SERVERS_COUNT[hypervisor_hostname] = count_by_domain
POWER_DEVICE_COUNT = len(cloud_state['power_devices'])
