# coding: utf-8
# pylint: disable=no-name-in-module,import-error,no-member

from itertools import chain
from pkg_resources import iter_entry_points
from _socket import error

from tionix_client.tests.functional.base import ServiceType

from tionix_dashboard.helpers.i18 import ugettext as _
from tionix_dashboard.tests.functional.helpers import BaseDashTestCase


class TasksTest(BaseDashTestCase):
    extra_msg = _(
        u"Please try to reload Supervisor processes: supervisorctl reload")

    def get_celery_tasks(self, broker_url):
        celery_tasks = []
        try:
            from celery import Celery
            from celery.app.control import Inspect
        except ImportError:
            self.skipTest(_(u'Celery is not installed.'))
        else:
            app = Celery(broker=broker_url)
            registered_tasks = Inspect(app=app).registered_tasks()
            if registered_tasks:
                celery_tasks = registered_tasks.values()

        return celery_tasks

    def test_registered_tasks_to_schedule(self):
        """Check all schedulable tasks are registered in Celery.

        :lang:ru Проверка на то, что все задачи с возможностью планирования
        зарегистрированы в Celery.
        """

        # TODO remake registered tasks test
        try:
            # pylint: disable=unused-variable
            from tionix_scheduler.settings import (
                CONF as scheduler_conf, get_rabbit_broker_url)
            # TODO necessary to change the connection parameters to rabbit
            self.config.RABBIT_QUEUES = scheduler_conf.RABBIT_QUEUES
        except ImportError:
            self.skipTest(_(u'TIONIX.Scheduler is not installed.'))
        else:
            sched_rabbit_broker_url = get_rabbit_broker_url(scheduler_conf)
            celery_tasks = []
            try:
                # pylint: disable=attribute-defined-outside-init
                self.rabbit_params = scheduler_conf.RABBIT_QUEUES
                celery_tasks = self.get_celery_tasks(sched_rabbit_broker_url)
            except error:
                self.skip_with_params(ServiceType.RABBIT,
                                      self.service_connection_msg)
            if not celery_tasks:
                objects = _(u'scheduling tasks')
                self.fail_with_params(ServiceType.RABBIT,
                                      self.objects_list_msg,
                                      objects=objects)

            registered_tasks = u';'.join(chain.from_iterable(celery_tasks))

            dashboard_tasks = []
            for group in scheduler_conf.ENTRY_GROUPS:
                for task_entry_point in iter_entry_points(group=group):
                    task_module = task_entry_point.module_name

                    if u'tionix_dashboard' in task_module:
                        dashboard_tasks.append(task_module)

            for dashboard_task in dashboard_tasks:
                self.assertIn(
                    dashboard_task, registered_tasks,
                    _(u"Task is not available to schedule: "
                      u"{0}. {1}").format(dashboard_task, self.extra_msg))
