# coding: utf-8

from django.db.migrations.executor import MigrationExecutor
from django.db import connections, DEFAULT_DB_ALIAS

from tionix_client.tests.functional.base import ServiceType

from tionix_dashboard.helpers.i18 import ugettext as _
from tionix_dashboard.dashboards.tionix.frames.models import Frame
from tionix_dashboard.tests.functional.helpers import BaseDashTestCase


class DBTest(BaseDashTestCase):

    def test_db_connection(self):
        """Check tionix_frames table existence.

        :lang:ru Проверка существования таблицы tionix_frames.
        """

        self.check_configuration()
        # noinspection PyBroadException
        try:
            Frame.objects.exists()  # pylint: disable=no-member
        except Exception:
            self.fail_with_params(ServiceType.DB, self.service_connection_msg)

    @staticmethod
    def is_database_synchronized(database):
        connection = connections[database]
        connection.prepare_database()
        executor = MigrationExecutor(connection)
        targets = executor.loader.graph.leaf_nodes()
        return not executor.migration_plan(targets)

    def test_migrations_applied(self):
        """Check for all available versions are applied

        :lang:ru Проверка последней примененной версии миграций в БД.
        """

        self.check_configuration()
        # noinspection PyBroadException
        try:
            synchronized = self.is_database_synchronized(DEFAULT_DB_ALIAS)
        except Exception:
            self.fail_with_params(ServiceType.DB, self.service_connection_msg)
        else:
            self.assertTrue(
                synchronized,
                msg=_(u"Not all migrations applied, please,"
                      u" run 'openstack tnx db migrate'"))
