# coding: utf-8

from tionix_client.tests.functional.base import ServiceType

from tionix_dashboard.helpers.i18 import ugettext as _
from tionix_dashboard.tests.functional.helpers import BaseDashTestCase


class OpenstackConnectionTest(BaseDashTestCase):
    def test_dashboard_installed(self):
        """Verify that TIONIX.Dashboard is loaded by openstack_dashboard.

         :lang:ru Проверка на то, что модуль TIONIX.Dashboard импортируется в
         openstack_dashboard.
        """

        self.check_configuration()
        try:
            from openstack_dashboard import settings as os_settings
        except Exception:
            self.fail(_(u'There is a problem with OpenStack dashboard.'))
        else:
            for app in os_settings.INSTALLED_APPS:
                if 'tionix_dashboard' in app:
                    break
            else:
                self.fail(_(u'TIONIX.Dashboard is not registered in '
                            u'OpenStack dashboard.'))

    def test_connection_to_neutron(self):
        """Check connection to Neutron service.

        :lang:ru Проверка соединения со службой Neutron.
        """

        try:
            self.neutron_client.list_networks()
        except Exception:
            self.fail_with_params(ServiceType.NEUTRON,
                                  self.service_connection_msg)

    def test_available_images(self):
        """Check images existence available in current project.

        :lang:ru Проверка наличия образов доступных в текущем проекте.
        """
        public_filter = {
            'visibility': 'public',
            'status': 'active',
        }
        project_filter = {
            'owner': self.keystone_client.project_id,
            'status': 'active',
        }
        public_images = list(self.glance_client.images.list(
            filters=public_filter))
        project_images = list(self.glance_client.images.list(
            filters=project_filter))
        if not (public_images or project_images):
            token_data = self.keystone_client.tokens.get_token_data(
                self.keystone_client.auth_token)
            project = token_data['token']['project']['name']
            domain = token_data['token']['project']['domain']['name']
            self.fail(_(
                u'There are no images available for the current '
                u'project "{0}" ("{1}" domain). '
                u'Need to create one first.').format(project, domain))
