# coding: utf-8
# pylint: disable=no-member

from django.conf import settings

from openstack_auth import user, utils

from novaclient.exceptions import ClientException

from openstack_dashboard.test import helpers as test

from tionix_dashboard.clients.base import novaclient, keystoneclient


class ClientTestMixin(object):

    tnx_hypervisors = None
    tnx_servers = None
    tnx_flavors = None
    tnx_images = None
    power_devices = None
    tnx_networks = None
    tnx_tenants = None
    host_classes = None

    tnx_domains = None
    tnx_users = None

    # noinspection PyUnresolvedReferences,PyPep8Naming
    def setUp(self):
        super(ClientTestMixin, self).setUp()

        nova_client = novaclient(None)

        self.tnx_hypervisors = nova_client.tnx_hypervisors
        self.tnx_servers = nova_client.tnx_servers
        self.tnx_flavors = nova_client.flavors
        self.tnx_images = nova_client.images
        self.power_devices = nova_client.power_controls
        self.tnx_networks = nova_client.networks
        self.tnx_tenants = nova_client.tnx_tenants
        self.host_classes = nova_client.host_classes

        keystone_client = keystoneclient(None)

        self.tnx_domains = keystone_client.domains
        self.tnx_users = keystone_client.users


class BaseClientTestCase(ClientTestMixin, test.TestCase):
    pass


class BaseAdminClientTestCase(ClientTestMixin, test.BaseAdminViewTests):
    # pylint: disable=arguments-differ
    # noinspection PyShadowingBuiltins
    def setActiveUser(self, id=None, token=None, username=None, tenant_id=None,
                      service_catalog=None, tenant_name=None, roles=None,
                      authorized_tenants=None, enabled=True, domain_id=None,
                      user_domain_name=None):

        if roles is None:
            roles = [self.roles.admin.to_dict()]

        # noinspection PyUnusedLocal
        def get_user(request):
            return user.User(id=id,
                             token=token,
                             user=username,
                             domain_id=domain_id,
                             user_domain_id=domain_id,
                             user_domain_name=user_domain_name,
                             tenant_id=tenant_id,
                             service_catalog=service_catalog,
                             roles=roles,
                             enabled=enabled,
                             authorized_tenants=authorized_tenants,
                             endpoint=settings.OPENSTACK_KEYSTONE_URL)

        utils.get_user = get_user


class FakeUser(object):

    username = 'fake'

    def __init__(self, **kwargs):
        for k, v in kwargs.iteritems():
            setattr(self, k, v)

    # noinspection PyUnusedLocal
    @staticmethod
    def has_perms(*args, **kwargs):
        return True


def patch_resource_get(resource, not_found_obj_id=None):
    # noinspection PyUnusedLocal
    def inner(request, obj_id):
        if not_found_obj_id and obj_id == not_found_obj_id:
            raise ClientException(code=404)
        try:
            return resource.get(id=obj_id)
        except TypeError:
            return resource.get(obj_id)
    return inner
