# coding: utf-8

import datetime
import unittest

import pytz

from babel import dates

from tionix_dashboard.templatetags.tionix_tags import format_date


class ViewsTestCase(unittest.TestCase):
    def test_format_date(self):
        locale = 'en_us'
        format_pattern = 'medium'
        tz_in_moscow = pytz.timezone('Europe/Moscow')
        now_time = datetime.datetime.now(tz=pytz.utc)
        now_time_str = now_time.strftime("%Y-%m-%d %H:%M:%S")
        now_in_moscow = now_time.astimezone(tz_in_moscow)

        date_before_format = dates.format_datetime(
            now_in_moscow, tzinfo=tz_in_moscow, format=format_pattern,
            locale=locale)
        date_after_format = format_date(
            date_string=now_time_str, format_pattern=format_pattern,
            tz=tz_in_moscow, locale=locale)

        self.assertEqual(date_before_format, date_after_format)

    def test_format_date_parse(self):
        locale = 'en_us'
        format_pattern = 'medium'
        tz_in_moscow = pytz.timezone('Europe/Moscow')

        date_strings = [
            "1.01.2017 12:13:14",
            "2017-01-01T12:13:14.123456",
            "2017-01-01 12:13:14.123456",
            "2017-01-01T12:13:14",
            "2017-01-01 12:13:14",
            "2017-01-01T12:13:14.123456Z",
            "2017-01-01 12:13:14.123456Z",
            "2017-01-01T12:13:14Z",
            "2017-01-01 12:13:14Z",
        ]

        for date_str in date_strings:
            date_after_format = format_date(
                date_string=date_str, format_pattern=format_pattern,
                tz=tz_in_moscow, locale=locale)

            self.assertNotEqual(date_after_format, date_str)
