# coding: utf-8

from _socket import error as socket_error

from mock import patch, Mock

from tionix_client.tests.test_diagnostic.base import BaseTestDiagnostic

from tionix_dashboard.tests.functional import func_test_dashboard_amqp


class TasksTestCase(BaseTestDiagnostic):
    case = func_test_dashboard_amqp.TasksTest

    @patch.dict('sys.modules', {
        'tionix_scheduler': None,
        'tionix_scheduler.settings': None})
    def test_registered_tasks_to_schedule_no_scheduler(self):
        test_name = "test_registered_tasks_to_schedule"
        self.assert_test_skipped(test_name)

    @patch.dict('sys.modules', {
        'tionix_scheduler': Mock(),
        'tionix_scheduler.settings': Mock(
            CONF=Mock(
                ENTRY_GROUPS=['<entry_group>'],
                RABBIT_QUEUES={
                    'username': 'user',
                    'password': 'password',
                    'host': 'localhost',
                    'broker_type': 'amqp',
                    'port': '5672',
                    'vhost': 'tionix_vhost'
                }),
            get_rabbit_broker_url=Mock(return_value='<broker_url>'),
        )})
    @patch(
        'tionix_dashboard.tests.functional.func_test_dashboard_amqp.'
        'TasksTest.get_celery_tasks',
        new=Mock(side_effect=socket_error))
    def test_registered_tasks_to_schedule_connection_failed(self):
        test_name = "test_registered_tasks_to_schedule"
        self.assert_test_skipped(test_name)

    @patch.dict('sys.modules', {
        'tionix_scheduler': Mock(),
        'tionix_scheduler.settings': Mock(
            CONF=Mock(
                ENTRY_GROUPS=['<entry_group>'],
                RABBIT_QUEUES={
                    'username': 'user',
                    'password': 'password',
                    'host': 'localhost',
                    'broker_type': 'amqp',
                    'port': '5672',
                    'vhost': 'tionix_vhost'
                }),
            get_rabbit_broker_url=Mock(return_value='<broker_url>'),
        )})
    @patch(
        'tionix_dashboard.tests.functional.func_test_dashboard_amqp.'
        'TasksTest.get_celery_tasks',
        new=Mock(return_value=[]))
    def test_registered_tasks_to_schedule_empty_task_list(self):
        test_name = "test_registered_tasks_to_schedule"
        self.assert_test_fails(test_name)

    @patch.dict('sys.modules', {
        'tionix_scheduler': Mock(),
        'tionix_scheduler.settings': Mock(
            CONF=Mock(
                ENTRY_GROUPS=['<entry_group>'],
                RABBIT_QUEUES={
                    'username': 'user',
                    'password': 'password',
                    'host': 'localhost',
                    'broker_type': 'amqp',
                    'port': '5672',
                    'vhost': 'tionix_vhost'
                }),
            get_rabbit_broker_url=Mock(return_value='<broker_url>'),
        )})
    @patch(
        'tionix_dashboard.tests.functional.func_test_dashboard_amqp.'
        'TasksTest.get_celery_tasks',
        new=Mock(return_value=[['test_task']]))
    @patch(
        'tionix_dashboard.tests.functional.func_test_dashboard_amqp.'
        'iter_entry_points',
        new=Mock(return_value=[Mock(
            module_name='tionix_dashboard.test_task')]))
    def test_registered_tasks_to_schedule_not_registered(self):
        test_name = "test_registered_tasks_to_schedule"
        self.assert_test_fails(test_name)
