# coding: utf-8

from mock import patch, Mock

from tionix_client.tests.test_diagnostic.base import BaseTestDiagnostic

from tionix_dashboard.tests.functional import func_test_dashboard_db


class DBTestCase(BaseTestDiagnostic):
    case = func_test_dashboard_db.DBTest

    @patch('tionix_dashboard.tests.functional.helpers.check_configuration',
           new=Mock(return_value=False))
    @patch('tionix_dashboard.tests.functional.helpers.getpass.getuser',
           new=Mock(return_value='<user>'))
    def test_db_connection_forbidden(self):
        test_name = "test_db_connection"
        self.assert_test_skipped(test_name)

    @patch('tionix_dashboard.tests.functional.helpers.check_configuration',
           new=Mock(return_value=True))
    @patch('tionix_dashboard.tests.functional.func_test_dashboard_db.'
           'Frame.objects.exists',
           new=Mock(side_effect=Exception()))
    def test_db_connection_failed(self):
        test_name = "test_db_connection"
        self.assert_test_fails(test_name)

    @patch('tionix_dashboard.tests.functional.helpers.check_configuration',
           new=Mock(return_value=False))
    @patch('tionix_dashboard.tests.functional.helpers.getpass.getuser',
           new=Mock(return_value='<user>'))
    def test_migrations_applied_forbidden(self):
        test_name = "test_migrations_applied"
        self.assert_test_skipped(test_name)

    @patch('tionix_dashboard.tests.functional.helpers.check_configuration',
           new=Mock(return_value=True))
    @patch('tionix_dashboard.tests.functional.func_test_dashboard_db.'
           'DBTest.is_database_synchronized',
           new=Mock(return_value=False))
    def test_migrations_applied_failed(self):
        test_name = "test_migrations_applied"
        self.assert_test_fails(test_name)

    @patch('tionix_dashboard.tests.functional.helpers.check_configuration',
           new=Mock(return_value=True))
    @patch('tionix_dashboard.tests.functional.func_test_dashboard_db.'
           'DBTest.is_database_synchronized',
           new=Mock(side_effect=Exception))
    def test_migrations_applied_db_error(self):
        test_name = "test_migrations_applied"
        self.assert_test_fails(test_name)
