# coding: utf-8

from mock import patch, Mock

from tionix_client.tests.test_diagnostic.base import BaseTestDiagnostic

from tionix_dashboard.tests.functional import func_test_dashboard_os


class OpenstackConnectionTestCase(BaseTestDiagnostic):
    case = func_test_dashboard_os.OpenstackConnectionTest

    @patch('tionix_dashboard.tests.functional.helpers.check_configuration',
           new=Mock(return_value=False))
    @patch('tionix_dashboard.tests.functional.helpers.getpass.getuser',
           new=Mock(return_value='<user>'))
    def test_dashboard_installed_forbidden(self):
        test_name = "test_dashboard_installed"
        self.assert_test_skipped(test_name)

    @patch('tionix_dashboard.tests.functional.helpers.check_configuration',
           new=Mock(return_value=True))
    @patch.dict('sys.modules', {'openstack_dashboard': None})
    def test_dashboard_installed_no_openstack(self):
        test_name = "test_dashboard_installed"
        self.assert_test_fails(test_name)

    @patch('tionix_dashboard.tests.functional.helpers.check_configuration',
           new=Mock(return_value=True))
    @patch.dict('sys.modules', {
        'openstack_dashboard': Mock(
            settings=Mock(INSTALLED_APPS=[])
        )})
    def test_dashboard_installed_not_configured(self):
        test_name = "test_dashboard_installed"
        self.assert_test_fails(test_name)

    @patch('tionix_client.tests.functional.base.get_neutron_client',
           new=Mock(side_effect=Exception()))
    def test_connection_to_neutron_failed(self):
        test_name = "test_connection_to_neutron"
        self.assert_test_fails(test_name)

    @patch('tionix_dashboard.tests.functional.helpers.'
           'BaseDashTestCase.get_auth_params',
           new=Mock(return_value={}))
    @patch('tionix_dashboard.tests.functional.helpers.get_keystone_client',
           new=Mock(side_effect=Exception()))
    def test_available_images_no_keystone_connection(self):
        test_name = "test_available_images"
        self.assert_test_fails(test_name)

    @patch('tionix_dashboard.tests.functional.helpers.'
           'BaseDashTestCase.get_auth_params',
           new=Mock(return_value={}))
    @patch('tionix_dashboard.tests.functional.helpers.get_keystone_client',
           new=Mock())
    @patch('tionix_dashboard.tests.functional.helpers.get_glance_client',
           new=Mock(side_effect=Exception()))
    def test_available_images_no_glance_connection(self):
        test_name = "test_available_images"
        self.assert_test_fails(test_name)

    @patch('tionix_dashboard.tests.functional.helpers.'
           'BaseDashTestCase.get_auth_params',
           new=Mock(return_value={}))
    @patch('tionix_dashboard.tests.functional.helpers.get_glance_client')
    @patch('tionix_dashboard.tests.functional.helpers.get_keystone_client')
    def test_available_images_no_image(self, get_keytone_client,
                                       get_glance_client):
        test_name = "test_available_images"

        keystone_client = Mock(
            project_id='<project_id>',
            auth_token='<auth_token>'
        )
        keystone_client.tokens.get_token_data.return_value = {
            'token': {
                'project': {
                    'name': '<project_name>',
                    'domain': {
                        'name': '<domain_name>'
                    }
                }
            }
        }
        get_keytone_client.return_value = keystone_client

        glance_client = Mock()
        glance_client.images.list.return_value = []
        get_glance_client.return_value = glance_client

        self.assert_test_fails(test_name)
