# coding: utf-8

from mock import patch, Mock

from tionix_client.tests.test_diagnostic.base import BaseTestDiagnostic

from tionix_dashboard.tests.functional import func_test_dashboard_tnx


@patch('tionix_dashboard.tests.functional.helpers.'
       'BaseDashTestCase.get_auth_params',
       new=Mock(return_value={}))
class TionixConnectionTestCase(BaseTestDiagnostic):
    case = func_test_dashboard_tnx.TionixConnectionTest

    @patch("tionix_dashboard.tests.functional.helpers.get_keystone_client")
    def test_nova_plugins_installed_not_admin(self, get_keystone_client):
        test_name = "test_nova_plugins_installed"

        client = Mock()
        client.tokens.get_token_data.return_value = {'token': {'roles': []}}
        get_keystone_client.return_value = client
        self.assert_test_skipped(test_name)

    @patch("tionix_dashboard.tests.functional.helpers.get_keystone_client",
           new=Mock(side_effect=Exception()))
    def test_nova_plugins_installed_keystone_error(self):
        test_name = "test_nova_plugins_installed"
        self.assert_test_fails(test_name)

    @patch("tionix_dashboard.tests.functional.func_test_dashboard_tnx."
           "TionixConnectionTest.check_is_admin_role",
           new=Mock())
    @patch("tionix_dashboard.tests.functional.func_test_dashboard_tnx."
           "TionixConnectionTest.check_extension",
           new=Mock(side_effect=Exception()))
    def test_nova_plugins_installed_failed(self):
        test_name = "test_nova_plugins_installed"
        self.assert_test_fails(test_name)

    @patch("tionix_dashboard.tests.functional.helpers.get_keystone_client")
    def test_node_control_extensions_not_admin(self, get_keystone_client):
        test_name = "test_node_control_extensions"

        client = Mock()
        client.tokens.get_token_data.return_value = {'token': {'roles': []}}
        get_keystone_client.return_value = client

        self.assert_test_skipped(test_name)

    @patch("tionix_dashboard.tests.functional.helpers.get_keystone_client",
           new=Mock(side_effect=Exception()))
    def test_node_control_extensions_keystone_error(self):
        test_name = "test_node_control_extensions"
        self.assert_test_fails(test_name)

    @patch("tionix_dashboard.tests.functional.func_test_dashboard_tnx."
           "TionixConnectionTest.check_is_admin_role",
           new=Mock())
    @patch("tionix_dashboard.tests.functional.func_test_dashboard_tnx."
           "TionixConnectionTest.check_extension",
           new=Mock(side_effect=Exception()))
    def test_node_control_extensions_failed(self):
        test_name = "test_node_control_extensions"
        self.assert_test_fails(test_name)

    @patch("tionix_dashboard.tests.functional.helpers.get_keystone_client",
           new=Mock(side_effect=Exception()))
    def test_scheduler_connection_keystone_error(self):
        test_name = "test_scheduler_connection"
        self.assert_test_fails(test_name)

    @patch("tionix_dashboard.tests.functional.helpers.get_keystone_client",
           new=Mock())
    @patch("tionix_dashboard.tests.functional.func_test_dashboard_tnx."
           "SchedulerClient")
    def test_scheduler_connection_failed(self, client_class):
        test_name = "test_scheduler_connection"

        client = Mock()
        client.get_tasks_list.side_effect = Exception()
        client_class.return_value = client

        self.assert_test_fails(test_name)
