# coding: utf-8

import logging
import pkgutil

from django.db import backends

from tionix_client.settings import validators as client_validators


logger = logging.getLogger(__name__)


ENGINE_PREFIX = 'django.db.backends.'


def get_available_db_engines():
    return [
        ENGINE_PREFIX + name
        for _importer, name, ispkg in pkgutil.iter_modules(backends.__path__)
        if ispkg and name != 'dummy']


# noinspection PyUnusedLocal
def get_valid_db_engine(key, value, default_db_engine):
    processed_value = value.lower()
    available_engines = get_available_db_engines()

    if not processed_value.startswith(ENGINE_PREFIX):
        processed_value = ENGINE_PREFIX + processed_value

    if processed_value not in available_engines:
        logger.error(
            u'Invalid DB engine: {0}. '
            u'Supporting DB engines: "{1}". '
            u'DB engine set to: {2}'.format(
                value, available_engines, default_db_engine))

        processed_value = default_db_engine
    return processed_value


validators_map = {
    'LOG_LEVEL': client_validators.get_valid_log_level,
    'NEUTRON_VERSION': client_validators.get_valid_neutron_api_version,
    'auth_url': client_validators.get_valid_keystone_auth_url,
    'auth_version': client_validators.get_valid_keystone_auth_version,
    'ENGINE': get_valid_db_engine,
    'PORT': client_validators.get_valid_port,
    'LOG_CONSOLE_TIMEOUT': client_validators.get_valid_int,
    'auth_password': client_validators.get_valid_str,
    'password': client_validators.get_valid_str,
    'PASSWORD': client_validators.get_valid_str,
}
